#!/usr/bin/env python
# flake8: noqa
#
# tiatoolbox documentation build configuration file, created by
# sphinx-quickstart on Fri Jun  9 13:47:02 2017.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# auto generated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another
# directory, add these directories to sys.path here. If the directory is
# relative to the documentation root, use os.path.abspath to make it
# absolute, like shown here.
#
import os
import pathlib
import shutil
import sys

sys.path.insert(0, os.path.abspath(".."))

import tiatoolbox  # noqa: E402

# -- General configuration ---------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# requires sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.autosummary",  # Create neat summary tables
    "sphinx.ext.viewcode",
    "sphinx.ext.napoleon",
    "sphinx.ext.intersphinx",
    "sphinx.ext.mathjax",
    "sphinx_copybutton",
    "sphinx_toolbox.collapse",
    "myst_nb",
    "sphinx_design",
]

autosummary_generate = True  # Turn on sphinx.ext.autosummary
autodoc_inherit_docstrings = False
autoclass_content = "both"  # Add __init__ doc (i.e., params) to class summaries
# Remove 'view source code' from top of page (for html, not python)
html_show_sourcelink = False
# If no docstring, inherit from base class
# ! only nice for our ABC but it looks ridiculous when inherit from
# ! grand-nth ancestors
autodoc_inherit_docstrings = False
add_module_names = False  # Remove namespaces from class/method signatures

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
source_suffix = {
    ".rst": "restructuredtext",
    ".txt": "myst-nb",
    ".md": "myst-nb",
    ".ipynb": "myst-nb",
    ".myst": "myst-nb",
}

suppress_warnings = ["misc.highlighting_failure"]

myst_commonmark_only = True
myst_enable_extensions = ["colon_fence"]
nb_execution_mode = "off"

# The master toctree document.
master_doc = "index"

# General information about the project.
project = "TIA Toolbox"
copyright = "2022, TIA Lab"
author = "TIA Lab"

# The version info for the project you're documenting, acts as replacement
# for |version| and |release|, also used in various other places throughout
# the built documents.
#
# The short X.Y version.
version = tiatoolbox.__version__
# The full version, including alpha/beta/rc tags.
release = tiatoolbox.__version__

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = "en"

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# These patterns also affect html_static_path and html_extra_path
exclude_patterns = [
    "_build",
    "Thumbs.db",
    ".DS_Store",
    "requirements*.txt",
]

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "sphinx"

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# -- Options for HTML output -------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "furo"
html_title = f"TIA Toolbox {tiatoolbox.__version__} Documentation"

# Theme options are theme-specific and customize the look and feel of a
# theme further.  For a list of options available for each theme, see the
# documentation.
#
html_theme_options = {
    "navigation_with_keys": True,
    "top_of_page_button": None,
    "footer_icons": [
        {
            "name": "TIA",
            "url": "https://warwick.ac.uk/fac/cross_fac/tia/",
            "html": """
                <svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                     viewBox="0 0 173 175" style="enable-background:new 0 0 173 175;" xml:space="preserve">
                <image style="overflow:visible;" width="519" height="525" xlink:href="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAgcAAAINCAYAAACqOtxdAAABemlDQ1BJQ0MgUHJvZmlsZQAAKJF9
                kE0rRFEYx38GjbxEsbCwuHlbDTFKbJSZNKYsNChvmzvXnRllrtudK2RjoWwVJTbeFnwCNhbKWilF
                Sna+ALGRrufMjMZLeeo5z+885zn/zvmDL6Db9lxJB6Qt14lFQtr4xKTmf8KHnxqqqNeNjN0/PDyE
                xFf9GW+3FKl606a0/p7/GxUzZsaAojLhPsN2XOFB4aZF11as9OoceZTwquJkjrcUx3N8kp0ZjYWF
                z4U1I6XPCD8IB4yUkwaf0m+Of5tJfuP03IKRf4/6SaVpjY1IbZRsIEOMCCE0ogwQpptOemXtpo0g
                7bLDNZdcdTk8by87s8mUq/WLE6YWtYz2gBbsCMqM8vW3X4Xe/D70vELxRqEX34azdai/L/Sa96B6
                DU4vbd3Rs61iSV8iAc/HUDUBtddQPpVJdAVzP6oMQemj5720gH8TPjY87/3A8z4O5bJ4dGHlPMpr
                cXQHoyswdAU7u9Aq2tXTn9MNZwWYZzn0AAAAeGVYSWZNTQAqAAAACAAFARIAAwAAAAEAAQAAARoA
                BQAAAAEAAABKARsABQAAAAEAAABSASgAAwAAAAEAAgAAh2kABAAAAAEAAABaAAAAAAAAANgAAAAB
                AAAA2AAAAAEAAqACAAQAAAABAAACB6ADAAQAAAABAAACDQAAAADINjxfAAAACXBIWXMAACE4AAAh
                OAFFljFgAAABWWlUWHRYTUw6Y29tLmFkb2JlLnhtcAAAAAAAPHg6eG1wbWV0YSB4bWxuczp4PSJh
                ZG9iZTpuczptZXRhLyIgeDp4bXB0az0iWE1QIENvcmUgNi4wLjAiPgogICA8cmRmOlJERiB4bWxu
                czpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiPgogICAg
                ICA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgICAgICAgICB4bWxuczp0aWZmPSJo
                dHRwOi8vbnMuYWRvYmUuY29tL3RpZmYvMS4wLyI+CiAgICAgICAgIDx0aWZmOk9yaWVudGF0aW9u
                PjE8L3RpZmY6T3JpZW50YXRpb24+CiAgICAgIDwvcmRmOkRlc2NyaXB0aW9uPgogICA8L3JkZjpS
                REY+CjwveDp4bXBtZXRhPgoZXuEHAABAAElEQVR4AeydBZxc1fXHZzYOQSM4BC0Opbg0BIfiWigU
                StEW+QMtkGCLRCgUClWkxUpLkeIOSfBSKMWlQAkWIIIGie38v790FzabnZ1598m97805n/yyM/Ou
                nPO799173rVXKpkYA8aAMWAMGAPGgDFgDBgDxoAxYAwYA8aAMWAMGAPGgDFgDBgDxoAxYAwYA8aA
                MWAMGAPGgDFgDBgDxoAxYAwYA8aAMWAMGAPGgDFgDBgDxoAxYAwYA8aAMWAMGAPGgDFgDBgDxoAx
                YAwYA8aAMWAMGAPGgDFgDBgDxoAxYAwYA8aAMWAMGAPGgDFgDBgDxoAxYAwYA8aAMWAMGAPGgDFg
                DBgDxoAxYAwYA8aAMWAMGAPGgDFgDBgDxoAxYAwYA8aAMWAMGAPGgDFgDBgDxoAxYAwYA8aAMWAM
                GAPGgDFgDBgDxoAxYAwYA8aAMWAMGAPGgDFgDBgDxoAxYAwYA8aAMWAMGAPGgDFgDBgDxoAxYAwY
                A8aAMWAMGAPGgDFgDBgDxoAxYAwYA8aAMWAMGAPGgDFgDBgDxoAxYAwYA8aAMWAMGAPGgDFgDBgD
                xoAxYAy4MFB2iWRxjAFjIP8MVCqVHljRE/Tq8FfGTQNT2/8tl8vTdcHEGDAGis+AOQfFL2OzsGAM
                0Knrvp0f9AP9W/+2/9z2W9vfuQnTmRMQ9f5vIR05CLM5DXyfAia3YlJXf3EwPua6iTFgDATOQNTG
                IXBzTD1jIP8M0Pl3x4olwdJgUOvfts/6vhDoBvIoM1D6AzCuFW/wV9B3/X0bB0JhTIwBY8AjA+Yc
                eCTfsm5cBlodgG/BwGpAf9X5tzkAi/E5r50/qseSmcR+B7R3GF7h+3PgFRwHXTcxBoyBlBkw5yBl
                gi15YwBHYBFYWB3IEdBfYSWgoX6T+hn4iqAvATkKz7YBh0EjESbGgDGQIAPmHCRIpiXV2Ay0rgVY
                ERbWB2sAOQPCAGCSHgMTSLrNYXiGz//AYdBog4kxYAw4MmDOgSNxFs0YwBnoDQtrg43BRmBDsCAw
                8c+AFkY+Ch4BD4N/4TBoIaWJMWAM1MGAOQd1kGRBjAExgDOgEQA5AW34Dp9tagASciByDJ4EchZm
                AWdhcg70NhWNAS8MmHPghXbLNA8M4AzMg55bgG3ApmAFYFIMBiqYoamHseBOMBpnQVsyTYwBYwAG
                zDmwamAMtGMAh0CLBbcFcgg0QqCDgkyKz4AOfdL0gxyFO3EUXii+yWahMVCdAXMOqnNjVxqAAZyB
                +TBzSyBnQFgMmBgDb0PBXUDOwn04C58ZJcZAIzFgzkEjlbbZOosBHIKl+bAH2B5sALoDE2OgGgPT
                uaDFjbeB63AU3qwW0H43BorCgDkHRSlJs6NLBnAIdOLgnmAvoB0GJsaAKwOPE/FvQI7CO66JWDxj
                IGQGzDkIuXRMt1gM4BBoikAjBHII1gNW3yEB0WI8zbHP8XIlfmvb7teLz9qJ0fGvfjMeIQERjxpR
                kKNwPY7Ce/w1MQYKwYDd5IUoRjOijQEcgoX5vDuQQ6AFhUWt43qBUWcvOerst48Iq9MF1fFPoxPT
                MLmzwLEWabY5Dr35rLMd+oN+Nf4qjNZ4FFH0UqqHgByFG+BYBzOZGAO5ZaCoDWduC8QUj84AnZWe
                bncBB4EhoAnkXdSht3+/wLh238fR+XyeRwMpq77oPagVS3fyV2+bzLvo/Q/3g0vBTXGdsbyTYfrn
                kwFzDvJZbqY1DNDRrMSfg8EPgZ5a8yYa1n8Z6D0BzwHtux8H3qBD+ZS/DSeUqZyDQa34Fn/b3kWh
                z3ncVqoRhCvApZTpf/hrYgzkggFzDnJRTKZkGwN0Hn34rIWFcgo0bZAXeRdF25wA/RVetqfK+oqP
                ctc0xoqgzVlo+7tIfSkEEepBtLgEaH2CpnlMjIFgGTDnINiiMcXaM0DnsCbf5RD8AIQ+b62nxUda
                8S/+Pktn8CF/TRJmgHqhdQx6udXaQM6ioN9CFk0ZXQUuoV48H7KiplvjMmDOQeOWffCWtz4t7oOi
                PwVq/EMUrVh/CbQ5A4/Q4L8WoqKNohP1ZgVsbXMU9FIsTUmEKo+j2G/A36g300NV0vRqPAbMOWi8
                Mg/eYhr3BVDyMHAkCG3YWOsE1KC3OQOP2qgAbAQsraMLG6Jim8OwLp97BKayzku4EFxEffo0MN1M
                nQZkwJyDBiz0UE2mEV8a3Y4BB4K5A9JzHLrcCe4C9oIeSMizUM/0Qq3NwbatWCIge3RMs3Y5/Aon
                4a2A9DJVGowBcw4arMBDNJfGWk9yPwO7gm4B6KjzAB4AsxwCGmntKDApKAPUv5Uxrc1R2ITPWvzo
                W2agwHXgXOrfU76VsfwbjwFzDhqvzIOwmAZZdW8HIKdADbJv0ZkCdwA5BGNokL/wrZDlnz0D1EuN
                WG0G5CxsB5YCvmUMCpwL9LZIrXExMQaMAWOgWAzQ+DaBvcFLwLe8gQJng7WKxbJZkxQD1I11wLng
                LeBbnkeBPYA91CVVwJaOMWAM+GVADRrYDaiB8ylvk/kvwXp+GbHc88QA9UX1d0NwAXgX+JSnyXzH
                PPFnuhoDxoAxMAcDNGTbg6c8tqbjyftCsBGwp645Ssh+iMIAdUijX98FvwUfAF/yTzLeJoruFtYY
                MAaMAe8M0HBtBf7hqeX8nHz/BAaDJu9kmAKFZIC61Q1sBq4AXwAf8jCZDikkwWaUMWAMFIcBGqrB
                4EHgQ/5FpoeBeYvDqFmSBwaoc/ODnwIN+/uQ0WSqsxxMjAFjwBgIhwEapjXBfR5axU/I83fAFhaG
                Ux0aWhPqohYyXgw+A1nLnWSoI6VNjAFjwBjwxwAN0UBwCZgJspRHyOwAMJc/6y1nY6A6A9TNvuAg
                8DjIUmaQmRzm/tW1syvGgDFgDKTAAA1PT/BzoCf3rETzumr0VknBJEvSGEiNAers6kCjCV+CrOQj
                Mvo/0D01wyxhY8AYMAbaGKCx2Qm8CrISrQo/BfRr08H+GgN5ZIA6rJG2M8AkkJXoXBEd7GRiDBgD
                xkDyDNDArAruzapFIx81ageD3slbYykaA/4YoE73AYeD/4Cs5A4yWtGf1ZazMWAMFIoBGpR+QPu6
                NZeZhTxAJjsAO5egUDXJjOnIAHVc5ybsArSGJguZRibng/k76mLfjQFjwBiomwEakQPBZJC2yPG4
                Bqxdt3IW0BgoEAPU/fXB9SCLxb0TyGffAtFnphgDxkAWDNBwLAuy2JqohvAv4FtZ2GV5GAOhM8C9
                sAq4DrSAtEVbH0N4wVToxWL6GQONzQANhU590y4E7QxIU9Tw3QBs50FjVzmzvgoD3Bs6O+QWkLZM
                IYOjgZ0mWqUs7GdjoKEZoHFQY6RTBtOWW8ng2w1NthlvDNTJAPfKuuCutG9K0tdx56vWqZYFMwaM
                gaIzQIPQG4wC00GacjeJ2xsRi16hzL5UGODe2QjomOQ0RQsWzwS9UjHCEjUGjIF8MEAjsClI+8wC
                7T7YJB+MmJbGQNgMcC8NAWnvbniRPOxdDWFXBdPOGEieAW78ucDvQZqLnl4n/V2S195SNAaMAe6t
                PcE4kJaobbgA2DkjVt2MgUZggJt9LfAySEs+JeETgA1NNkKFMhu9McA9pilBnR6qRYVpyfMkvLo3
                Iy1jY8AYSJcBbnAduKJOW/OKaYieNP4EFk7XkvBSx2ZxuzDQos5NQJ/wtDSNisoA9W0xcBVIayTw
                K9I+BtjBZEWtRGZXYzLATb04GA3SkodJ+DuNwi626sVTGwM9td0POm79/JzfbgJbNQonZqd/Bqhv
                64M03wJ5F+k3nPPvv2RNA2MgBQa4mXcHH4I05C0S/X4KageXJHYuBzTyosOh1PnXI3qSOzk4Y0yh
                wjJAfSuD/cC7IA2ZSKI7FpZAM8wYKDoD3MB6n/xlIA3RtseRoNDD59i3PBgG/g3iyO+LXt/MvrAY
                oLLODX4JZsSpuF3E/QPX5grLatPGGDAGumSAm1YHp7zWxY0d59KTRF6jSwVyfBHb2hyCp+OQ1CGu
                RhDs4Kcc14u8qk69WxskWZfbV+2XrF7ntWaY3g3HADfrESCNRYcaSj8OdCsaqdi0AjgJpNWIknTl
                7qLxlnd7KBONruk9IhuBRfJuTzX9sa07GAq+BEmLFiseXC1v+90YMAY8M8ANqnfEa8VyGnIPiS7t
                2cREs8eeNofgmTQIq5LmgokaYYlFYoAy0fke24HfgP+CjqIjhOUA94iUcE4CY5dGxcaCNOQSErXt
                yzmpC6ZmgzDATbkMSOOpV69r3r8oNGJLP3A8yNIhILuvxV40lXFlgnndGxpNuwPU++SsnT39MlY1
                k+ywSwsWDwYfgaTlnyS4ZCaGWCbGgDHQNQPcjNuCNHYj/JV0B3adez6uYse3wZ9AvZ0DQVORzfPB
                WH61pNS0zXRzcB54GbiKRhYWyC8TXWuObYsAvRk1adFuBqvnXdNvV42B9BjgBtQTwKlgJkhSNFqw
                W3qaZ5MyNmiedS+gMxhCETtpLoXip3BV1luBP4Ikn4hHpaBuUEnC197gY5CkaIfECUEZasoYA43A
                ADfe/ECvPk5adKDPYnnmEP0XAnKa3gUhyRt55jU03SnYbmAw+D2YANIQjTTl+n6op9ywcSnwIEha
                NDIxTz06WBhjwBiIyQA322rg1YTv4qmkp7n4ppjqeYuO7isCLciULSHK+d7IKUjGFKpGy9YHvwJZ
                OX9HFIS+Ls2ATzlbJ4PpIEl5icRW6jJzu2gMGAPxGOAm00rrz5K8c0lLN+9a8TTzFxvdteDsSpDW
                YS8kHVt05kRh56/TLn24Wx2cDdJ8CyHJdypnpW1fSOnDgM5ISfrhQ9MWtg4hpII2XYrDADfX4SDp
                DvAPpJnLU87QewlwMUj6SYckExW9pXLl4tTEbCyBM51BcBB4HPiUS7OxOJxcIFvcawFvkqKzV34U
                jpWmiTGQcwa4oTSUek6Sdylp5fZ8dHRfGFwIvgKhi7bPrZbzKpiZ+nCluq4T/S4CSY+QkaSTnJMZ
                AYFlBFt7gKR3Qp0ZmJmmjjGQPwa4MfW+9utAkvIAieXuNDh01hkFvwD1vvSIoN7kIXLeNH81zo/G
                cDUf0MjYUyA02dgPK2HkSmEsDh5LuFD+THo9w7DQtDAGcsYAN88A8GjCN+X5pNc9T1Sgrxyk04CG
                50OXu1Fwkzzx60tXeNIowQZAw9ehOnzaBdHNF0eh5AsHOjtCu0KSFJ3UaOtwQilk0yMfDHDTrAC0
                iC0pUeO7dz6s/0ZLdB4Ckl4clRSn7dPRFtB1vtHcPlVjAJ4WBEeB50HoslM1OxrxdwrrAKDtnUmJ
                FkMX6lj2RqwXZnNGDHCzbAJ0EFFSos41V/Pe6LsA+GNSBKSYjjq47TKqGrnOBp5WAholyMNaEdSs
                nJRrwlNSHl7WAm+ApOQDElovJXUtWWOgGAxwk+wGkmw8byW9+fLEDvruCd4HIct4lNNK+oYfcq5V
                t+BofXATyIu8jaIHgnIt2xr1Otxo9EdTaEnJFyS0faPyaXYbA10ywM3xQ5DUVsWZpHUKyE0Dh65L
                ADkzIctnKHcqmLvLwmzwi/Cj9QQ6k0OLX/Mib6HocaBPgxdfXebDUxM4C7SAJERbHfesK3MLZAw0
                CgPcFFqpndRNpq1H2+SFO3RVI6O35oW84FBO2x/Awnnh1Yee8NMD7AueBXkRvY58Z5Crhbo+yrez
                POFtR6BDjpIQPdTYWQidEW2/NR4D3Aw/S+Kuak1DixhXyAuL6LoySHpHRisVif0ZTUp2/GsXlQp+
                5gJHAh8nGJJtZFFnpp073+rCLLtUJwPwqPs4qbLXQ1JDHFldJ70WrBEZ4CY4HSQl6mT754VHdN0b
                aK4xVNFIxmEgN1MzWZc93PQDp4FJIA/yNEoeDGxaKOHKAqcLgydAUmJvdUy4jCy5nDDAHXRuUncR
                6VwLeufBdPTUNMIoELJoqHmpPPDpQ0e4WRL8CoR6PgGqzSa38e27wBy9FCsM/GoE6WaQlDTUey1S
                LBpLOg8McNdosVaSB4r8QmnmxPZ50VUNdajyCYodlAcufegIN8uBK8B0ELpo/vpqsLoPrho1T/iW
                838BSErsbaaNWpkayW7uFr0WVY1rEqJFcoflhT90XR7o0JNQ5U4UWyIvfGapJ7xo65rm6LWiPHTR
                VuDfgWWy5Mjymp0B+D8ayEFLQi4mkdy+Tn52ZuybMdCBAVVu8Nck7hTS0Ja6bTtkEexXdN0afARC
                FOl1QLDkeVQMXnqBY0GoZYdqX4tGfUaAhTxSZlm3Y4Cy2BkkNfV0OWnlYoS0HQX20RjomgFVavAn
                kIS8QyJrdp1jOFfRVXvHNcoRotyKUouGw1YYmsCJ6uvu4HUQumgx5IkgV4d9hVHS6WtBuawDkjrU
                7Lfpa2w5GAMZMsDN8WuQhGirYi4WyqGnnjqTmkJJgrv2aegsiP0yrAK5yQpe1gePtCcr0M/aTXIa
                mDc35DaoopTRsiCprY6/aFAazeyiMcBNkdTK/BdIKxevWkbPfuAfIES5BaXsMKMONxqcLA2uCbHA
                OuikNQXa6ZObbbsdqG7Ir5TXEuA/IAk5tSFJNKOLwwB3wclJ3Amk8RTIRWOInguAf4PQRFMbxxen
                diVjCZzMD84BU0HIovLTwrTFk7HcUsmaAcpuYfAcSEKOy1p/y88YSIQBav//JXEHkIYON8rFfKr0
                BEkehEJyichEUtkskYItSCLw0QPoVMM8HGCkhby5OfmzIFUkFTMoR40qPgmSkNzs1kqFTEs0fwxQ
                6w9OouaTxv0gF6e5oec84DEQmvwThWyLYuttBBdabLgTeAWELrejYG4W3+avpfKjMWWq804eTqDy
                6ahlWzvkpxgt16gMUFl/AJLY36vDgvJy6uHc6JrEzU4yicolpNYrahkWNTxcfAc8kCjD6ST2EMlu
                XNRyMLtKJcpXpynem0D10XTTrsapMRA0A1TSHcD0BCr8taTRI2hjW5VDT53fENqph1q0ZicdflNG
                ct7OA3rSClm0TXcPYPvZ83Dzx9SRctaOJi0QjitaL7NVTHUsujGQDgNUzrXB53FrOfGvBt3S0TL5
                VNF1ZAI2J5mEDuzZJHlL85kiXGwB/pskwSmkpZMXtaunbz5ZNq1dGaDMu4MbQFzRIVirueph8YyB
                VBigUi4F3gNx5e8kkJv3yqOr3qwYkryLMtZAUMvhQbtG/hhS4VTR5R5+t1cnp9Iy5SNRyr8nuKNK
                /Yjy81sEtkPN8lHsxdeSyqgV+jqDIK7cRQI988IYumr+OqRXLmuB3aC88JemnvCwK0jCWSWZ1EQN
                +W7AphDSrAw5SZt60AeMAXFF275tBCon5V5YNamE2g6mHQVxRYvE+uSFKHQdCNS4hyLakZCLcyDS
                LGM40D7y60MplCp6aApB70DIxS6cNMvL0p6dAepEX/AYiCva5ZKbqdnZWbBvhWCACnhZ3FpM/MfB
                PHkiBH1vTcDupJLQsHTDPynAgRbyfZgUqSmlo9ExO68gTzd7xrpSP3Qo178TqH+/y1h1y84Y+B8D
                VN5TE6jAz5DGAnniFH0PSMDupJL4CwnlYldHWmWM/dqJEPragjfRcRdgUwhpVYQCpUs9GQBeBHHl
                ZwWixUzJAwPU2H3j1lrivwwG5sHeNh3Rd3HwMQhBrkOJhn7HO/avBUI+zEhbzM4Cc7XVIftrDNTD
                AHVmUfA6iCPaurt7PflZGGMgNgNUtsFAjV4c0dayxWIrk3EC6Kxh4RBkLEo07OFG2K6zJY4Fmr8P
                VTQ0vErGVdSyKxAD1J9B4O2YFfxL4m9QIFrMlBAZaK2scc+in0A6y4ZoX1c6oXNSR0KTVCx5lti5
                eNdEV3y6XsN2LToMxUnrrCBn8qMWHOZm541rWVi89BmgHq0I4q6l+YA0cvcwlj67lkMiDFC5egNt
                k4kj8mLXT0ShDBNB535Ahwv5Fs1dN+xNju3bAjV0oYqGgTfKsGpaVg3AAHVqMIg7WqtdEOawNkB9
                ydxEKtblII7kdv4Lo8+LY3hCcSeTzkqZF3wAGWJ3N6Cn8ZBF77HI1a6bAIrWVKiTAepWEuu8fl9n
                dhbMGKiPASrm4Qm0yj+vL7ewQmG35v3ieu1x6dNhSxuGxUw22mC3DtkK7d0V7ctT02Q7ZsOG5dLI
                DFDPktghdkAjc2i2J8gAFXJ9ELdzzO2eW2zXux58ygwyb8jOB7tXAC/5JL9G3jdzPVc7bhJsGiwp
                DwxQ3y6rUSdrXdbU7loeVLcsi8QAlWghoDfFxZHcntaF0doqp+kQn3JqkepUvbZA+DYglG2jHcv/
                M374MbBzC+otUAuXCAPUuSROpX2DdBZMRCFLpPEYoPLobWHaMhdHtIAxt6f3obvvVfHamdBQhxxh
                bxn8HGjVf4jyMEot03gtQrEtpkx7gS3AOeBuoAPatPj1CXAyWDkUBtBFU23PgzgiGxv6nJRQyjN3
                elBx4i7C0/7c3L4hDN1XAT5F0wlr567ixFAYe/uAP/skvYu8p3NtKLAz62OUcUhRKctlwZFAo5uf
                g1oiJyGI0SL0WArEfbnY8JDKw3TJAQNUur1AHNGNtkYOTK2qIvr/Pg4BCcQ9p6pyBbwAX4uAJxPg
                LY0kXiLRbxeQ9oYziXJcCaiTfxq4yLVECmJLIHqsC75yMaI1jqZMd264SmAGuzFAZZE3rTnVOLKP
                W+5hxMJwvfxkShwCYsZ9lfi5eUtl3FLDVtW5/8bkLK3oesnWvHFttPh+GKDsNE21GjgdvACSkJ/4
                sWbOXDHmoJgG6fyWJedM2X4xBtoxQCXpDv4Rs7Jd0C7JXH7E/mNichAnurz5TXNJnIPS2KqGO+7w
                aBy+u4p7NhdtGsGhXH1GoczkEHwH6GyM/4Ck5X0SDGYtFbrojI048gCRbf2Bz0obet5UkDPj1DDi
                PgRyvYAO/XVu/2vAl1wUej1JSj8I3gCEcPJkx7Keyg8/TMpOSyd9Bigv3bfadq0FhW+AtOXw9K2q
                LwcM1WLKf8Y0eFh9uVmohmOAirUxmBGjgo0n7sJ5Jw4btorBQdyo75BAQwxht/JczyKwuJxGja8V
                6vaimpzcyJSV1hD8ErwNspRfhEQRhi8BdCCXq+glZuuEZJMvXWwIpR3zVAq9yOfPwHUIdTpx9yiX
                y++3SzavH32+4nQoHH6aV+Lq1Zv6tgdhbwOhvcr4GXRahzJ4rF5bLFz2DFB/5gL7g4fJ/UVwLFg8
                Y02CehCizr6N/d8HMx150IivDnyb2zG+RSsiA1SIuKcAHlEEXuBBQ5N6cvQhevLpXgQeu7IBGw8G
                WlcRmvwdhYKZR+6Kw0a9RvmsAX4DQjgc628hlgPcHA/iyKUh2mU6eWCAWvSDODWJuFd5UDuVLLFF
                Uyu+JJfvnohSEBD7M1/k1sj3DK7baGKUwswoLOXSF2hF/uMgJDkwIwoiZwNJ18UkatfImVqEYjFA
                BdJLhT6JUZF0ilhhttxhi+YufcinZKqpncIK9h3ug9gaeX7JdQ3FmgTEAGWi3QZrg4tB3G3VJJG4
                aOQr2HdqoJscqhdjWD2ZuA37aviAbgU/qlD43cDDMSqQ3hS4kh/t08kVe16PwUecqLnf/tlViUDM
                90FoUwlaQGsLsLoquIyvUR46Fvgn4N8gZLk4Y2oiZwd5moLRrhtXuZ+IQZwGGdl4ixCPAQr+RNda
                0xovmK088Zj4X2xsWjUmH3Gib5SEDSGmASnbAR09HJLovHx7MgqgwlAOGiXYEFwG9MARujyCgr0C
                oK6mCuh5bEwy/69mJhagWAxQYVYAGlJ1lVuKxUipBBGHuZIRM54OVCnkfDd2aQ1HaA3+X9GpMFNh
                eb0PKYMFwdHgeZAXuQdFg9ql0FX5o6scL+nsKlOIOKirPOxagRigsFVhHnCtLcTTaXYDCkTJLFOw
                6TLgQy4pGpeyByLXBCGsKm9fpsP5YkOlHisc/H8bXAXivBOA6JmKRpq28Eibc9borXeWTIrB1l3O
                mVvEfDFAJTkkRkXRvPHW+bK4Pm2xK6lz16PS+736NMxPKAhYHvjaElqN/5Pyw2CxNKVA9ECyBYjz
                FFutXNP6XU/NOpZ4XZBrhxL9dwZxZL9i1UizZg4GqB3yIuM8zRVy4RyczANmgqxFc/G95yioHP+A
                PYuBcVkTWSO/43JMaW5Vp0y6g73Av2qUT0iXpavO4pgnt8R3ojj2XByDZI08FG60uBOaGvcnClgH
                vbjKs0TMxUKcqCWMXZu5khIznk53K4zARR/wVExOko7+08IQnBNDWuuBdh342v0TtQ5pRPRG8F2Q
                61GCalUEu3Sq5MvAVa6ulrb9nnMGqBG7udYK4mnx4mo5p6Cq+tgWd+eGK7XXVlUqZxcgQEPHV7gS
                kUI8NfgH5YzGXKsL31pkeAqYAPIgOkPhArBsromvU3ns1JsqpwFX2a7OrCxYXhigJswPtK/bVY7J
                i60uekLKn12JiRnvVBd9Q4wDD3pSDEU0RWTzpBlVFLheAvwKaJ4+D/ImSh4H5s+IomCyweahMQpI
                vNkR48GUZgKKUKBaWOMqjxGxkFvt2qjFvgdcyYkZb5c2HfL8Fw42BFo/EYLMQIk988xnXnSH54XB
                hSDOYTtEz0zUlu0JCv8Ok2p1SLaDOFN/F1ZL237PGQNUhE2BhlhdRENQq+TM5MjqYuN/XchJIM4a
                kZUNLAIcaJFrnFGpBGicLYkDAqOocOrAtqYPRoIQX7k9W2Xgi5zFv4H1C1cQjgbBxVqtvPAnsmhU
                zrh05D6YaBSivMQ4h4ycEYwxKSkCP2Xg68lnhZTMyiRZeOsJHgahSOFfXpVJwVbJhELWrp5TQZz3
                sWRVV+QU/AksXcWchv4ZXs6JURDa0VHo0eTCVw4K8IgYFeBF4vYsOknYqKFRX7JknvmFNA0phyLn
                5JnLkHWngLULRXP0cQ7TyaqeaJRUa4iWD5lT37rBj8r0NeAqP/Ztg+XvyAAlrqG/yY4lrxussOf9
                t6cUO9dx5CiJaMG+2a09R519xvh9kyAgoTQuJx17kumsoGL8BqcaGTocvAvyINei5MoxTG6oqHC1
                eYxC1bHv8zYUYUUxloL7dYyC/11ReKhlBxztGoOnuFFzedAKRi8FPotrfELxbyWdHrXK2a7XzwB8
                ajpyf/AGyIPcjJJr1m+hhWxjAN4ui1HAZ7elY39zwgCFvTJwXT3+NnFz2Wm5FA+26jQ0H6LRmdyt
                mkZnrdG4xwdhneSp9Q5zuZS7xanOAJyuCPIwhXAnetprt6sXZc0r8LcA0CiAi2it1nI1M8lZgKIP
                QZ5Pebh2PD8pl8uf5aw846jr6w19E+B5RhzFPcU9kHy39JR3+2x1uuQOcPhF+x/tc3wG4PRlUtkc
                TI6fWiopjCHVjdFzW/BEKjk0SKLw9xGmHuVortaknesYN9horh1nsAa1KYYntwOft2r7HvHvdVSW
                WyPGyXtwX0+e7+SNOOrW4uh8XgB6f4wOO7U2bAGo464CnJY/GfXw/DPL0xdl093c5VL39xYcMPf7
                5UPXnu6eavyYcPsMum1GSveD/vFTTCSFR0jlFHSTc2CSEAPwqbUaOjRse4ckdyLu5qShelIIKer5
                2fLkngcuK3W/JN63KOS3C1HCdRpBxT6doD5OKrwZrneuU03vweBJ98xtwPcRqi3SAe7u9k5KBAU+
                HHXvfDMrPbbjXdbrlkrlRfm7aKnM3xJ/S6VOXr5VnsC190rl0vhSpTS+UuIsjqbS7QNPGPIstlci
                ZB0rKOW+GgmMBj4dhCfJ/xRwd5a2k1/DCOWs6YEXgMsONfU5a1I2M4tAWFGdg59ROK5buk6ncJuL
                ULhRbOCmEF/iLWv5LXwfkXWmrvnB0w+Je4Vr/ATjHQ9vrnU8QTVqJzX57DGLc/zYji2Vpp3KpcoQ
                YvSoHatmiDfL5dJNeAc39Z9aerjcPCT1qSnKfj20ehC4dBw1DeoiwDNck+N+K2WemUPUhT6FvkQ5
                /wIDXc8K+SllVIiF7IVzDijYARTsa8Ble4mGuDVq0HDzt/CmDk8dX9YyFL5HZZ2pS35wtAjxXgS+
                z6K/Bh32Cbmj0AhBS6X7YZVKaTd0TXmxXPlDxnNuK5Urlww8ccjD5JeaUAf2J/HLU8tg9oTH8/UE
                8BfKumX2S/YtLQYoYy1EfxUs5JCH1qcsT3lpDUOupYgLEodRIi6OgQryBAq14RyD1hq8euvfrP/k
                Ys0BDYYcaT0R+HYMnkaHH4fqGLx64R29Jgwfc/SMlu6v4xjI6UvZMSCHUmVBto78kO7zoYkjx9wy
                ecR9K+vXNATe5URroXOaMo3ERwA9qPwZmGOQJtsd0oZvLUQ/qcPP9X7tR0AfI7D16ld3uEKNHNCA
                L4blGjXoZO6yJiePUik2qhmqgAHgrTtmTQG9PJi3Ibw/5iHfSFnCkdZF3BgpUvKBPybJb8PXuOST
                jpdipbm5aVKvTfdiDcFwUlo6XmpxY1foTMuXlVtaTut/8ubvxk2tY/zW++UOft+y47UEvt9EGsdR
                xv9NIC1LwpEBylgPzlrj8W2HJNSWLk0ZTnKIG0yUojkHv4XZnziwq3m8dSlMVYaGE26EVTD6eQ+G
                a554XnjXItBgpbUzED/f8qzk9+Hqb551mCP7icPHDmFIX+sfvjPHRb8/fEnZ/arb9K9G9Wve7tMk
                VSFdPSG+AFyGnjtTRdNVR1O+93V20X7LngHKeBNy1RoTFzmXsvy5S8RQ4hRmWoGCXBJSD3Ik9koK
                siEdg1a+fE0pPA/vQTsGrfwcwF/fjoGGl4NyDDRaMHHE2NNxDEbDT2iOgYquD5wNbenZ5/EJZz6w
                vH5ISkhXc8suDyIdVdBo0NFAq9zNMejIjsfvlMdDZH+towo/pU9a2DFuENEK4xzAprb4uKwi1hDQ
                0CBKw58SG3vK+glP+dadLTf4XARurjtCOgHfItkj0knaLdX3z7l77sk9BtNwVk51SyHTWCuWu7U8
                PmnkmC0oz8RGS+k8/o4VNzhaotHKi8AKpHMhmO6YjkVLl4HjSf4rhyx0qJzWv+VWCuEccMMvSwkc
                4FgKI7gx33OMm/torY3lLp4MCd45gJcjgday+BJ1IvtRRz/xpUDHfD866/6luk3v+Qjd7G4drwX8
                neNxS3dNHjVWT3SJOQjYK6fto4h2P0v49SjTw8DEiHEteIYMUD5vkp2mzFzkEOraEi4RQ4iT5E3i
                zR4K4Eoy389BAW0VWpYK4OIZOmQXXhS42xCtHvGkmYZStYc7SIGbBVBMC8Pm96jgKDgKZmTrgxGj
                N2oqlbUwc4BHTuJlXSlf3H/6hCPLzXtqV0BsoZ7Uu71xKpmdAc6hTG2kIDbz2SRA+fYlpzdAf4cc
                L6KsD3OI5z1K7kcOKLgVYfEHjkxq1KBhHYNWznyNGnxB/lrQFbKciHI+HQM5TqeFQpCG5XEMxqBP
                fh0DkVmuHDKp58AbK2PGaJdOEnIVidRych8kzBq0N2pzzDFIgvWM0qC8NPX8C8fsDqSPWtoxrtdo
                uXcOYK8ZuNjxFvEuAQ0rVFqNHO3qiYDR3HTarRCkwM3iKHaUZ+UOh6NEnm7j2qEFfQzLX0c6PeKm
                FUb8ynaTHiufnYQulFEL6VRz4rRL4lAwhHCvJJGfpeGFgd+Q6/sOOet+ycO6nDlMc+lU50jE1w80
                4KuR956O+Z8VSsPrqH8S0bYlkWWSSMghDe3nDlnU2Lucl5GUTZdRPx9LKrE46XzUPGb+cveWW0nD
                5yhKHBOqxK0cO2HEmB9XuRj151uI8FSHSDfzfWXK8WIgB8IkpwxQftpVNdJR/f3oq1ZwjOstWq7X
                HED4X2Bubwf2XifOihR4sE+uDjZFjgJ/Y4k0OHLE+BHUUC4M/0EuxoKXQeinOuLLef6EvLWKfQJ/
                vUrl2mu7TXptwG0osY1XRdLLfDrH3WyWxLHL1Jvvoaa40hOmFir+nTKs8NekAAxQvr0w4zWgUcWo
                Imf/wKiRfIb31fjFtpmCWopE9nBM6AwKqtEdg3XgzodjoCJ7FP6DdAxa69Nh/PV5b+h1vN4dA3Ex
                6bWBmmstqmMgE3uUW8o3vDdyzCB9iSl3EH8o0GjBDcAcg5iEhhSd8pyKPsMddfoBfdbCjnG9RPPZ
                AMY1WAeHuCwoeoV4V8fNvADxtX/XlwQ7pcAN3BtSDvJFDPlqm9vvPeb/ddYTh4/5PucYHPv1D4X9
                UBnYvVK6sXLRk7HWU8gZANpdEnVrY2GZLaBhf8SmcQ526QwebYvOjeTSOaABnw+GXRvwZm7embkp
                oRQUhb91SXbXFJKuN0nNxYYqe6GYjsb1JXrlq/dRrfHNt85VKpfO9UWCh3zXnPzRFNc2xYO6lqUP
                Brg3tdPkDMe8eUtpZW7HuJlHy6VzAEuHgnkc2HqeOEEdQetgQ6woVE55sJcBX2X/GDeY5u1ClZ96
                VExz1A97zP/rrHv27KudGot9/UMDfKi0VE6b0DxGe9pNjIGuGLiSi692FaDKtQX5/cAq14L72VcH
                4UwEnZuG/ly3mGnUoNHnAU+Fv5WdCyB+RG0JClJaR1S0FsOXnOkr4/b5fjrivn7cJDrjodFkoXLP
                RphGabRiTdZe+hCNPJ/hmOr/0c50c4ybabTcOQewszdweaKRp6eT3RpWqJTfxvgTPBKgVdzXecy/
                VtY+Rw1updF5upaCWVyfWm46iXw0ddeAUv45740Y2ICGm8nRGLiG4G9FizIr9DL873NKt26V8+gc
                HFe3dbMHPJ/GV1voGlJaR1w0ndDdIwGXUAbTPeZfNWv40al/Wm/gS4IYNZi1ar/S5NNJ8sV/W759
                m6b3PKXti/01BjpjgHZM64Iu6OxaHb+59mF1JJ1ckFw5BzTgW2L66g7mTyLO5Q7xihRFw8RreDRI
                N9MfPOZfK2sdhqN9zD7kbhqbJ3xk3DHPHhW9ZXHWupSOlxrmO4e/HKaXSzWMwWaoKwOXEFFnkkSV
                9ejLNo4aKevwuXIOIOdnjgT9jsb3S8e4uY9GRVwFI072bMiNlMF4zzp0mj386D44rNOL2fwYxKjB
                qxfe0atSKrueHZINU9nk0n1GuWn3bLKyXPLKAO3ZZ+h+saP+rn2ZY3bRo+XGOWjt4LaKbuKsd3EH
                uwjOwZ5IUeBNi180naBdCr5E0zln+cq8jny1tdPXk+IYGplH6tAx9SDzfd5nCJnYav3/Mb1z6oRb
                BkVgQFMLLlOlO9A2LxcyAblxDiDxEEcir6LxnegYtwjRRmGEzxX44vDPlMGzAZO5k0fdfu0x79my
                Zh+PdYhtjJQrG9rCxDYy7G81BmjX3uWay/Z49b0HVUs3hN9z4RzgYfWGrP0cCKsQ55cO8QoRBd6O
                wRDfw1c6cjT0BV6+nAOthbk9hMpWaW5WW7BjCLqEoUO5qWlaj+3D0MW0CJyBcx31O4A2uodj3NSj
                5cI5gIXdwAIObNyGZ6fjkhtOqHT7YHQIjtFvKYO3Qi0AeFoe3VbypJ9GVIJ4JfPknt/V6NIinngI
                MttyucmX0xgkH6ZU5wxwDz/Dlfs6v9rlrwtxdYcuQ3i8mBfn4GBHjlw9OsfswohGh7clmlwOfL91
                82N0GA5CFp9Py1oLEoS0lMo2pTBHSVS2Ymph7jl+th+MgTkZcO1rXPu2OTVI+JfgnQM6uhWwebCD
                3f/Co3vQIV6uo8DXdzDg76BHAIacRRl8GIAeXang6+nwKbgJZh1GuVTerCuSGvRa7+4zem7QoLab
                2REY4F6+m+AvRIjSFnQr2mxfi6HbdOj0b/DOAVq7Ltq4qFOLC/wjlUyrX+8AfQMw8x/ocH4AelRV
                Ab76c3GjqgHSvRDMqEGrmYuna25OU684ncaaU2NN7ZgMuGxrVB98YMx8U4ketHNA462n3/0dLJ9C
                nL86xMttFLjS/JW81xCOfv0KPQ7Amw79RMrvoaePe0DrDP4CgpDKtdey3bVl4SCUCU2JcnnR0FQy
                fYJl4Co0U9sXVQ6k/daW86DER8MYhQAN+bp0dn+lY5KD0BBCxVLDfg9YJhCDT4H/VwLRpSs1fE0p
                3A8/wUy3THp1Ye6xcuhtQVflmNq1lkrFnIPU2C1WwtzTH2HR9Q5WadRuG4d4qUYJvUFwXayhYy0b
                QnAMlsXQR8DqgRj8KHqcF4guVdWANx2VvHXVAOleuDfd5COm3jTDOsCqlNnIQVVq7EJnDLj2Pa59
                XWc6JPJbsM4BjfcgLNzSwcpn8OCecIiXuyhw9G2UlmMQyojB5+jyI/gPfTpBZS1nai598CBhOQcz
                m8w5qFYJyjZyUI0a+31OBmj7HuRXl1HT79GeLzJniv5+CdY5gBKtNXDZiufqufkrBYecqUg66nYs
                0FqDEKSCEj/k5vhPCMrUoYN2dfiQ98nUZVVzero2WQdYjdxyxUYOqnFjv1dl4NKqV6pf6M4ll4P+
                qqcY80rIzsFeDrZ9SZyrHeLlKgqOgQ6FuhPMG5DiZ+IY/D0gfWqpsnatACldvw+e5EgFI5VSpV8w
                yoSniHa0mBgDURi4gsDTokRoDevS5zlkU1+UIJ0DOr/VUN/l1LrraHh18E5hBW4OxbhrgebMQ5Gb
                UKQ5FGXq1MPXyIHLSWp1muQWjDMOJrvFbIhYkxrCSjMyMQbog/Qun5sdElyL9l3b0YOQIJ0DmHH1
                oAo7pUClaQIj4eYPIKRyex599gvtaRidqgo86l0dq1YNkO6F4JyDUkuYr9JOtxjqS71SroyvL6SF
                MgZmY8C1L3Lt+2bLPIkvIXUy7e3Zs/2XOj+/TAf1cJ1hcxWMzkzDvneBEwNT/AP02Rne87ZtVCNT
                muPLWl6Bq3ezzrRmft1arAOsRlLFHKdq1NjvXTKgh4A3ugzR+UVzDjrnpVSiI9QK/OWrXe/i9790
                cS23l1r5eBIDtgzMCA2dbU5n93pgetWjjq8phWCOS56NpJbu5hzMRkj7LzZy0J4N+1wfA7SLWld0
                TX2hZwu1Gm3+irP94ulLiCMHrp6T5uELJVQSrV59BAwKzLAP0WcLboCwVt3XT5KvxYgv169idiH7
                L//+BNzyPGw/zY6U1pyayjZykDnpxcnQtU9y7QMTZS5E58BlSkFnG7jsLU2UzKQSwynoAX5NeleC
                Pkmlm1A6WvC5JXyH+RRcn5G+Rg6CdA7Ke+45k13DmiIy6cBAS0vlvQ4/2dfAGKCtXBwcDK4C94MX
                wHNgFFgfeOnnaCOfhiqXrd1BOAc+5l2rVi0KcV0uLl01QPULrh5a9RQ9XYGDJcn6arCxJxW6yvYz
                Lm5DpX+qq0AhX4Nfn4sRg3QOWsvrHf4GdQhLCPWoqakkXkwCYoB7WP3WBmC7VqxeRT0tOj4B3Ewc
                LZpW+5W1qG86OWKmK6Hvauj7XMR4iQb34lF1YYHLqIGS+1sXaebmEhXiEJTV6v8QHQMtrtmICvt4
                bgjtXNHl+FmNiw9xeYrIRE8mSO/PJKN8ZfLVjO7THsuXysXUlrZxIPghUFuv9U4PAi3QruYYcOlr
                0TtUHiPuUl//kt0H177JtS9MzLJgnAMKroxVLoT8iw4rj4vivi5EbF8C3M0PF4F5vr4QzoexqLKO
                b082IToWTiidqMm8DX/B7upoKlV0VoVJewbKpXsX/vnWOhLcxAMDtImDwAngn2T/AdDhQuoj5gdR
                ZRUi/CZqpLjhuef1sPeiQzrepxaCcQ4gb22whAOJuZ5SoOIfhM2qQFs52J5FlN+SidYYFOWgHF9D
                5yFPKZT6TXvwCcrZ5tfb3VGVFnOY2tGRyUfaw8XA/4F/kKFGK0eBdRLKfHvS3SShtKIk49JHLY+u
                2nLtTUJyDrZzZMGFeMeskotGwWsRzV2kqMMy5k0u5cRSmk5Kh+AUHAFmJJaq/4R8jRy85t/06hqU
                m5u1W+GW6iEa7kqlpef02xrOag8G0w5qyuBw8ADZvw3OB+ulpMrQlNLtKlnXqYVtu0o07WshOQcu
                RDxOxzUubZKSTp+b4EDS1GjB1kmnnVB6bWcYuJ7ylZAaqSTja+Tg01SsSTBRJvZsaqGNz0rpEaYU
                JrR9tb/JMkAbuAD4MbiHlDVi9TvwXaDp5TRFa44yFfoojRq67O5y6RMTs83XwqzZDKCC9OMHl6Gj
                XI0aYOdi2KkO12uhz0b+nF+0/WYnKvRbc14qxC++Rg6mhM7eJ3N/OWb+KX20ojvEdS/Z0ld2Ohs/
                Wx1zlhvtnx5GtwAHAy0S7AGyFl/3v/qqehZPtudjIzibh7bYxy6LYM7o13y7yyjGje2ZDPkzhfwj
                9HsBhOwYqAJrR0JRHQNVEV8jB8E7B8sftd3Ucrl0g0hqcJkxo1y6vsE5SMx82r5FgbbzaeH43WB3
                4MMxINtSb3Tppg8Zy98d8hNHmzvESySKS4ecSMYdEnHpMHVOvRasBC1URC2wuR0l/wTmC1RZrS8Y
                Bp97gS8C1TEptXw9OXyelAFppkNFOJ2RXZfXzaapVqZps63zokWGDhmXaaYFy0wdMPge0NsJ9bBx
                JhgEfMto2riZWStBni+Rp8tDl0vfmIh53p0DKo/mmFzm3u9MhIGUEsGuucCpJP8K2C6lbJJI9jES
                +TaVd2QSieUgDRs56KKQZnWK5ZbfdhGk6JemtPSYdkbRjUzLPtq8JUEz6Y8Dt4EdgY8ndbLtVHyu
                q3Hps7bp1IoMfvTuHGDjWmCgg60uRDtkEy0KN0YZ7E8sHXjDU1hp7mgpZBZaC+SOABvjGGi6o/BC
                ufTBSF+jN7kYOVAl6FVpGc6fT/S58aRyji1EjFbq3Fc67n1ncAcxx4HTwOIgNHkbha7zqJRLnyVn
                a2UfOofgHLgMm2jo+wEfhHWVJ4U4hOv/ApeDxUCooqG+lXEKfgu0ha1RZCGPhga/5qCNm3mHbTGZ
                4TztL280+aAyrXxeoxntai/tnaZM5Ui+BbT+S205VSdI+RKttNB6skft7idvlyk7lz4ytpl5dQ7G
                UMhTY1ufUALcIN8Ct5DcaKBXTocq76HY7nC3M3g3VCVT1MtlhCopdXLjHMjgL3v3uoA/jVVHyqXm
                gc1DclVOSVXOKOnQ1q0I/kgcrfkaBnyt46lX7Q8IqPVU/643QhrhyF9162GHtBvPOaCCLQBR6zmQ
                dZdDnMSjoH8/8GsSfh7skHgGySXIGqvSxUCjBY28Gn3B5CiNnJLOjsiNLHHshl+WKqWf5Ubh+Io+
                03/BedThmVRhgLZObzjUCMGL4EDQo0rQUH7WFsBTwHK0e7cGopRL37UJvGc+Pe175EDbNFwWq7jM
                3SRWNyioBcGZJPg60Lx9EOdFVDFQCyI35eY4FHxcJUyj/OzTOdDTS65kwElDrimVK+fnSmk3ZSd2
                b2nZqXzo2tq1Y9KOAdo5raHaFozl58fAziDUqQNUmyUv8b/a5cVp884CIY0GufRdPbFlU5Cp+HYO
                NnGw9lUKW51y5sIN0h+MJONxQPt25wOhihbfHAJWha8HQ1UyY736ZZxfW3ZTKAOtk8md9J9aPh6l
                XZ528mLr9JZSZZcFTt78zbwonIWetHPdwT7kpaH4O8DgLPKNkcdM4upsiiFgFe43rafSouugBJ00
                yvyOg1IufaVDNt9E8e0cbPSNKnV/cvG86k68s4DcJHODU7gmp+REME9n4QL5TesKjgTLUxEvATMC
                0SsENXyNHORu1KCtsMrNQ3hrcWlvnhU1AlU44b4+bKFhmz1SOMMcDYIPbcHWU/er4GqwhmNSWUVT
                e3c6WIq2bg8wFmgaNWRx6cNc+spYHHhzDqiAmkNxqXiZPsWgp468fA2cAeYFoYrmtDVHvCw3x29A
                MAs2AyLMnAOHwligecjHlRlNWlNTrGkppkwGnrSZDidreKGd01SpHoA0gqJ1VINAyPI4yu0F5BQ0
                gzwtnnXpw9amfDS9kJl4cw6wcD0Qda5+JnFcVns6EUph9Ceitv0t7JRANpE+IhutGF6GG+SX4Mts
                ss1lLr6cg/dzyVY7pQeeMvjVpkp5T34qyLx8+Y7WKZN2VjbeR9q4JYC2b74F9ACkNi9kuRvlNgUb
                0NZdC/JYHx90ILg3cb7jEM85SpNzzPgRXYZJnqMyfBY/67pTuIqQg+oOnW1AzadpOG1pOBkJpmSb
                fS5z8+Uc5HZaoX0p9ztp03t5dc5m/JarnRftbfjf58ol/adN2EVTJnNea4xfcAjmB+dgrUZFjwEa
                yQ1VdBbL38BatHPbgAdA6FMHVblE90lcdJmmc+kzq+pR60LenIPM5ga5cRaHvK1rEejhum7mY0Hb
                cNonHnTIa5bmHMQsuYEnDnmYlf3rkMwzMZPyEX0mi++P6j90yKHl5j2n+VDAd560azrNUGuS1I5o
                GjLToeqI9quMLgbfokP9PtDiyKKIS19WfOeAyimnZAOHUnYh1CGbWVF25P+ya+SE48lz1ophvaNh
                BW6S80Gx5n8TJqxKcuYcVCEmys9a2V+ZVtq4Uir/PUo8z2E/Zlpk24Enbfpr7p3cPnW6ckibqy2J
                2oaoo9IvBL527tRjgkZBNaoxiLLSFmw5MkUTl76s+M4BpbwacFnc50Koa6Va3zVigvG0nkDzgXII
                vgfuBA3XsCXIpzkHCZGpkwQHTBu7B/7zGQklmV4ys3ZazFxP0yLpZRJuyjgFa6PdGHAjWD5cTUta
                L3U20Kjo8UA7EYoqLn3ZAMpyhawI8TWt4OIBvUNleSsrYshHHbMveZaMdUaBDvE4DmgLpUkMBrip
                tPh1gRhJxIlayPIrNze3DBi26Wk8km4BOSEO+X6FJz2qaeqX6w4YtsV/4hRgHuNS57XYUOumngCD
                A7ZhBrr9Hmin1Yngw4B1TUQ1bNSaA609iCoufWfUPGaFz5Nz4OJpOZHSGinrFeZqvEYALbpZA+iM
                gi/iGGBxZ2Ngdb51m+2XbL5MJZuXssnKTy79T9rs/v7THli7VC7vgwZv+NGifa4VTcP9sdzSstzA
                YUOG9mve7tP2V4v+GYdgXqC2RG3KvgHbi+9W+jPQmoKfgCKPFHRWDI929mON3zJzDvQ05UNcDMza
                OcjiSUidhk71uo4b4zkfBdFAebrUuSToeZ6ynZ5EQiGnoVEE9Pvrqxfe8ff5PutzGKt1TmHBTvbz
                2uXSrU3l0tB+Jw7R3HpDCQ6B2vODgHYxDQzc+JvR75QGb/fUp+0YsZwya8cyX3BHBe4PGRMjEqLg
                eqLOosP+WjV0fZgvSRfG86TZ5hC8+HVm9iFVBijLv5LB91PNpPPE/0i9VYPdUPLhqHvna2npfjiP
                hrtiuHY3pCkfVfRinUrp0oHDNn0ozYxCTJu6rXZci5W1iG+lEHVsp9MYPg/jnvhHu98a8iPltiGG
                R33o1WjLvPCnRZupig/nYDMsuj+iVSJifgjRIUiZCYW3MZkl0dho21ebQ+CyvzUzm4uaEWWp9SpL
                eLDvSOrtbzzk22WW8CEu3kU3PfGnKpPPHrN4paWyY0ulaadyqaL7X0+4ceXNcrl0Ey3lTf2nlh5u
                1DMLKMc1IfJcsHlcQlOO/yTpDwX3U+fUwTW8UHa9IOEToL9RZEM4fCxKBJewPpyD/0PR8yMqOxoy
                vFR+CvBH6PoH0DOizk8RXg7B9ej+asS4FjxBBlo7QjkHPmRjyj/q00HqesLJtWSiA8UOQb/MnO6P
                msfMP6NXeVuchPV44F2kVKksylqFRUsl/pZKOgWug5QncO09pinGMzIwvlKq/JeN0LcPPGHIs+jd
                sJ0M5TcfRI0Ch4LM2/EOhdTV17e5eBxQO9iw5VWNIMpRbYNGEKLIYXB5UZQILmGT8OCj5qttjFHl
                6agRkgpPIVxGAb5MeteAJaukq0qv6YIHWvEg8WjUTAJhIOrNl6Ta2nkSlFCf+6OQ9rz3EPj+I+pr
                Jg6C3tNAnn9tBX/+J+hQ/mTUw/PPrExdpNJS7lsudX9vwRkffFD1sKIT22I23l+40nsutLp/sYCt
                n4ZuGtEYQd36PGA9faumUeWo7ZNLHxrZTh/OgVaNRxWvDSyV+zFuyEEovS7YCSwL3m+FFhU+k7r3
                gQAAQABJREFURJjJ/DUJk4GoN19SVrxGvdDTeWiyHwrJMZDM+kz93g9dtaXMi5C3HOyPWuFFh9Az
                pYy0yPAC4GPtTBR67ibwUZTpf6JEatCwLn2bSx8aNr1U7ibwBYgqa4VtmWkXMgNUtiejVriEwl8X
                Gi/YpZPyXujEvuv5rc1hCE3thtantcz25e+kTsotpJ/eRJldQMjTHEHVJbjayKEA5USnLk2p5zB7
                Bsvztc/sP9X8puHOhtuWVJMVC1AXA9x4cxNwzboCJx/I23RYF6asx7WVO7m+G79dB19R789OkrKf
                kmKA8tBU5u3gKtAvqXQTTkdTCGeBlRgtuLF1FCjhLAqb3HNYFnUthl6aVW2KOzGisnYOXIZD/kNl
                m5qYxZZQozGgqaBunowe6ynfrrI9qIuLmjL7Jw3PKl2EsUsZMEAZaITncLLSg9G2GWTpmsWdRFyV
                NlpnFnzhmkijxoOzT7H9TQf7XfrSSNlk7Ry4LKRwmZOJRIIFLjQDX2KdFv1kLRr6ezzrTLvKj85m
                Hq7Xmq9elTBPEPZgdVBdpWfX0mEA3geQ8i3gd6BvOrnETlUdmha16p0vthsrHp0ufZxLXxpJy6yd
                AxdvR8MuJsaAEwM0XP8g4rfB+uBy8BXIQu4mb28L/KoYuCe/a5qllmhq4WJwDR3VfLUC2/XkGIDv
                LUhNzuz2yaWaaEoaxT0TrEz9vhlEHRJPVJmCJObSx7n0peHSRcX/L4gqO4RrkWmWNwaofAuAo8FL
                UStixPDaBRCUoL923USVN4igdQomKTIAxz3B2aAFhCoPoNhyKdLQkEnD6Z4OBV6cdXgYPzdwqfhL
                NWSNMaNTZYC6qDndzcFTIGlRPR+YqgERE0ef5WMYOZ24vwELR8zWgtfBQGvZaConVJmKYj8Dvtbu
                1MFifoPA64oOBa97MurBfGGShCGrORCgA1NMjIHUGKBOdgOHgckO9bNalKDWGog8FNVoSVz5nATO
                AjbVkECNhEc5qPuDKSBUeRbFijWEnUDZJZkE/KoN+tKhAqQ6ipPlmoOlHQgtztCJg/EWJX0GmDOd
                Cf5ATisA/U1iDvWO9DWPnEMSK97nIteTgKYH9SSptQkmDgzAndZ+/BlcDupZB0KwTEX3wTlgHe4P
                lwVzmSqb58zUBqH/Sw42uPSpdWeTpXMwqG6tvgn4+jcf7ZMxkB4D3KCTweHksDZwec96e+WCcg7o
                iNSpb9pewZifFyS+Oo5XSfsnYIGY6TVUdPgahMGqY/sEarh2Igzhfjge2DbybArJpa8blKZqWToH
                Ll7OuDSNt7SNgY4M0Bg+xW96G+dxoKXj9Tq+TyTMv+oIl2WQIWQW9c1v9eins/1/C96nw/s72A30
                ridio4aBn8HY/gQIdaj+CunGffBAo5aRJ7vHOeTr0qfWnU3ozsEbdVtiAY2BhBigYayA80huG6Dz
                CqLIrcR1cSqi5BE1bBJTCl3lqYVRu4DrgRyFP4IhIMv2pSv9vF+DC60v+AmK3Af04qvQZDIK7Ubd
                PQB8GppyDaCPS183qBC8cGM8DaLKpoUw3ozILQNU2GXB8xEq7oYhGYve6pS0RsCHHB8SF750gXht
                U7zIRwHUmefthLOdKL4qCPnC/7Z1llX7YI+lqXKWnv0gB0PGOcSxKMZAYgzwFKW5wA3AjXUk+iJh
                Ur1h69ChYxAttEx1+LFjhu2+39/uc0N+pCVfCMNHg0MCJOALdDoMbE89fz9A/RpJpXEOxg5yiFN3
                lEycA24QLViKuv1Jp8u9XbclFtAYSIkBGs7PSHp3cFqNLC4hbKVGmKwvb5d1hq35TeDvvz3lHUS2
                tHtroYjWF2wUhEKzK/E4X9ekvl4UYJ2dXdPG+DbOwcyFqWOp7RjKxDnAaJcnl3eotDMdCLMoxkDi
                DFAXW8AZJPyzKonrzXRXVbnm8+e01xtUs+1OcVbtYtF/p9HeChsfAksEaOv56LQx5WPvRAikcCgL
                vQPmAwd1lnKIU1eU7nWFih/IxTlwWaARX1NLwTsDNKzl9345tl+3qTMXLZWaFil3q3xZqjSNnzF1
                yvhFm3fQUKg34Sb+JfppQdmJHZS4gWta1BWMoKd2Dgz2pNCdnvL1ni2874ESV4Me3pWZXYHpfD2M
                evqn2X+2b4EwoD5P01BRRH3ry1Ei1Bs2K+dgUL0KtQtnzkE7Mor4sdI8pvuknpWNSuXS91jYvmyp
                XFmUfQKLTho5dhFa1R6lcutprS3lWeb36Nm3NHHEmE84pmg8ccazjGd8pVR6skdL5eYFTt78zQw5
                GkZechAOapfnJe0+h/JxFRTp6UEZjRjc4yFf71niGByMEheB/1Va7xp9rcAkPu2CY/Dw17/Yh9AY
                UJ+3fkSlBkUMX3fwrJyDJevW6JuA4775aJ+KwsD45lvn6tmz71b0HjtzIMD25VK5n84kLOs//tVx
                QOF8BNb6lZUUixZ4vxlN5QtwGp4m/s2VpqabB5z43adpBGellgZvShvRQi4dBrQreA2MBaHJmp4U
                +iccfeQpb2/ZUidOIPNR3hSonrHe+rcjZTKuehC7EgADLuWzVFp6Z+UcDHAwwIUoh2wsStoM0GiW
                J44cs2251HQonf9W9Nq9U3isWhNPYc1ypeU0Rh7enDhy9N+bmsrn9TthyDtp2EdDOxO7fkDat4N7
                5DCkkU/MNH05B4/H1DtX0VW/UVhOQYhbN29Br32pn1pUaxI2A284qKcRzFQkqwWJLga4LM5IhSRL
                1J2BSWfdvy6d9Rie8elEKzuSkubB05alSpXyMS0zS69OGDFm5EfNY+ZPI0Ma3K9Id2dwaRrpJ5Dm
                Ggmk4ZLEky6R8hgHx0BzXxeDEB2DkeilqQRzDPJRubTDJ6q49K115ZHCA9yc+XID6ThZbeuJIt+h
                UusoW5McMjBh5JjlmiqlETxOa3GWZyl/yJTDWR/P88Xvlj9qu4Y4K557To7/x2AeD+SvxL2byiIp
                D7ZUzRKOe3Hxz2D3qoH8XFAd/zFloEWRJjlhgPq0Eao+HFHdhynnTSLGqSt4Vs7Bm2gTdd3BIIxW
                PJMcMfDpiPv6fVXqdjoViymEUlbTVnUxhE7jOBd5WP8TB19D3QpxGqAuO+oJREOzDOFerydswmGm
                kN588KtFiYWVVufrbxgYmmPwPjrtDP8NNbVThIpGnVoRO16KaMvLlPVKEePUFTyraYV+dWkzeyCt
                rjXJEQMfDh+z6tRStyfohH+K2kE5BqIRb2AQ55T+ZdKIsRdXmq/1sYo/y9L0td7gXw3gGFDFS3r3
                RmiOwb/RaV1zDLK8zRLNy6XP65+oBu0SS905wBvSHPPc7fKs5+NXVPDP6wloYcJgYOKI0TvOLM86
                OnjpMDTqQoty6aBJPQfc996IBwd0ESrvl3w5B42w3uBYKsfRgVWQ69FnE9rNtwPTy9SpnwHt8Ik6
                4rYAfayc1cQldecAjV1GDYI6TCZx1guUoCrmpBFjTmRb4U2Y1TdHpm3SvTTziQ9Gjfa1aC9tqnzZ
                FXVYNG0eEk2f+r43CZ6baKLxE2smib3sgSo+kT5ToPx0IrDWCUURLYjV6wkSlyycA5dhD3MOEi/q
                5BN8o3lMb3YiXMVwvVZFp+K9Jq/1bCku1dRSfgTnZufZfi3GF18jB28Wg745rcAx2Ixfr5jzirdf
                tPBQTsHpIOoTpzelLeMuGXDp+1wewLtUQhezcA5cFJ9UU3ML4JWBykVP9ujbs3QrSmivf55lbpyb
                GyeOHKsnwkIInVgfDIm6ADgp299KKqGQ0oHT1dHnRhDKkchfossOOAXXhsST6RKbAZe+z+UBvKai
                WTgHLoq7eE81jbUAyTEwcfJnWpC1RXIpek6pUvkToyDreNYiqewXSiohh3QKN+eNYyBH604wrwMf
                aUSZQqLb4hjcm0bilqZXBlz6PpcH8JpGZuEcuCju4j3VNNYCJMMARxUfyhzCEcmkFkwqvSuV0k0T
                z76Hlz3lXnw5BxPosPREWxjBMVgQY+4CodSLT9FlK3h+oDAkmyHtGXDp+1wewNvn2ennLJwDl8US
                Lt5Tpwbaj8kywDHIm5Lib5JNNZTUKouWZva4afxFT84VikaOevhyDgo1pYBjoJ1WWmibyj5yh7LV
                avbNcQwec4hrUfLBgEvf59LH1mQjC+dAN1hUkXdsEhgDH4y8bxmerq9HreDOMEiQqnV6TJ5yCR0D
                gyO5FXMOYhYd5a9V4FeBVE6fc1BPT5RDcAyedIhrUfLDwCcOqrr0sTWzycI5cDlsRqtwTQJiQAsQ
                u1W63USP6TJNFJAl9ahS2Wfi2WOPqidkoGF8OQdRt2EFSV+rY3g+yu0eiILvo8dgHINnAtHH1EiP
                gWkOSesY78QlC+fARXFzDhIv6ngJTp485SBW9a8WL5X8xGZjWPMnzXdpvjmP4ss5+DKPZHWi8zH8
                dmQnv/v4ScPMm+EYvOgjc8szcwZcnAOXB/CahmXhHLgo7kJQTWMtgBsDE5rH9K2UKqe5xc5trPmn
                9ew1NKfam3PgWHCMGmxA1F84Rk86mk6J3Q7H4KWkE7b0gmXA5cHYpY+tSUAWzoGNHNQshrADlHuV
                jkNDXx2OT3KO/HDUvb7OC4hjt6+y+jKO0r7j4hjMjw5/BVpv4Fumo8CuOAb/9K2I5Z8pAy4Pxi59
                bE2jsnAOXLwaF4JqGmsBojPwwfD7FuKNRT+LHrMQMXrNqPQ4M4eWDPSkc26dg9Z1BpfA21KeuGuf
                LTN4pf1xDO5p/6N9bggGGmrkwMU5cCGoIWpO1kaWy91OIc++WecbSn7lSmW/HL5/wdfIwVehlJuD
                HgcTJ5QFiEfhGGgEw6TxGHB5MM7tyIGL4i4ENV41StliDamzO+HQlLMJPfly08zy6aEr2aYfT8Da
                ZprKvue2PLr4m8uRAzhbFZsu6MKuLC+dgWNQ0HNEsqQxt3m5PBi7PIDXJCiLaQUX58CFoJrGWoBo
                DMxs6b4rMYp8pkF9hJRL201uviOUo3Nr6exzlMflAJda9qR6HcdAB179DaSyVzyi8n8gfHPEOBa8
                WAy4PBi79LE1WcvCOXDxalwIqmmsBYjMwM6RYxQzQo+ZvfpsmxPT5vGo5wce83bNWrtwVnaNnGC8
                +0nrSEYNtN7ApHEZcHkwduljazKchXPg4tW4EFTTWAtQPwOfjriPw44qoZwOV7/iKYWkyc6Lo+TT
                OdBhPbkRRg3WRFntxPEt76DA3jgGM3wrYvl7Z8Dlwdilj61paBbOgcsrTrWNx8QjA9NK3bYvlcpZ
                1A+PVkbJurxdpfnaVDz0KFrUEdanc5CbkQMcA21X1O4E39sW1dbtjmMwsY6ytSDFZ8DFOXDpY2sy
                mUXjP7OmFnMGsHnuOTnJ9JeWSmmnTDMMPrPKvB/26rdp8Gr621mi0b48vRPlCPRdO4Dy1M6ExwPQ
                w1QIgwGXvs+lj61pbRbOgcsUQSrDJDXZsACzGHj7vEf70GBtbXTMzkBLpZyHqQVfIwfvU2dyMV/O
                qIEOtho+e+l6+XYFuV7kJWfLNFQGXPo+lz62pv1ZOAcuwyR5GL6tSW5eA/T6ahpPVLNWcefVhHT0
                rpQ3TSfhRFP15RzkYkoBx4DduaXfgbkTZT16Ys8Q5Sd5caiim2cxHBlw6ftc+tia6mXhHLh4NS7e
                U01jLUB9DHDwz2L1hWywUOXSojmw2JdzkJfFiLtQht/zXI4fk/9uOAZfeNbDsg+PAZe+z6WPrWl5
                Fs6Bi1fj4j3VNNYC1MlAuZKHTrBOYxINNt/759zt+4mzlkHz1wqQ0vXgRw4YNdDCrVEp2R8l2X1x
                DF6PEsHCNgwDLn2fSx9bk9AsnAMXr8bFe6pprAWok4Fy2ZyDKlQ1zei5SJVLofy8vCdF8jBy8GO4
                8cVPW7GchWNwe9sX+2sMdGDApe9z6WM7ZDvn1yycAxevxsV7mtM6+8WNgYqNHFQlrtwSuuO0UlXd
                070Q9MgBowY6ObI5XQpqpv4sIc6oGcoCNDIDLn2fSx9bk+MsnAMXr8bFe6pprAWolwEbOajGVHlm
                U7DOQetiO1+n/QXtHFCexwBfL6RSddJOjkMZNbAzXMSGSTUGXPo+lz62Wv5f/56Fc+Di1bh4T18b
                ZR9iMpCPhXcxjXSMHvZ6DDkuvhYkvujIaOrRcJoGkMnxqWfUdQa/xzH4R9dB7KoxUHLp+1z62JpU
                Z+EcuHg1Lt5TTWMtQJ0MtHh7q1+dCvoLVq6UF/SXe82cfY0a6G2Mr9TUzl+Ak8na5wuptB5jmD/z
                LeccMeDS97n0sTUpycI5cPFqXLynmsZagLoZsKNcq1DVUq5MqHIphJ99rTd4mqfiVE5pi0sqowZL
                kMbhcdOJGf9o+PkkZhoWvTEYcOn7XPrYmmxm4Rx8VVOLOQP49PLn1KbRfimXxjeayfXbWw6ZG1/O
                wb/q5y/zkEeRo7Yw+pI7yfg6X5lbvrljwGWrdG5HDlw8Zt4IaOKPgUrIHaA/Wsi50tISMje+phWe
                8looVTJn1GBeLh1S5XIWP2u65aeMGuTiWOksCLE8ajLQv2aIOQPoUK3EJYuRg8kOWptz4EBaUlE4
                YTbkDjApM53SaenWFCQ3dIR6u+BqTkbFjxSkc4BZOtdADoIvacYxeMNX5pZvLhlw6ftc+tia5ITq
                HLh4TzWNtQB1M/Be3SEbLOBXU0uhHvbzbYpiAQ/FoSHN4HYq4Czp7XZHe+CjLcvn+HB+2xf7awzU
                yYBL3zepzrQjBcvCOXBR3MV7imS4Be6CgSYbOeicnfKHSzcPcVlD03lyyf66VbLJ1Z3aszwdh7h3
                fzcsWKpuK5IPqFcxh8hL8pZaikky4NL32chBkiVgaVVnoKnS8lb1q418pfJ2wNb7cg6Cm1Jg1EBv
                XjzOY1k9Rt4PeMzfss4vAzZyUKPsXLynGkna5XoZ6NdvXjX4qSxyqVeHIMOVK/eEqBed4TzotaEn
                3YJzDuBhA7COJz6U7dm2CNEj+/nOOuo5Klrs+mEaJqc+rcBNMgXFo2616EuD53IYRBocNVya5UPX
                nl4ql25rOMNrGNxSKd1cI4ivy4PJ2Nd2vRCdg/19FQT5vgxu9Zi/ZZ1TBujz9EZVrZWJIp/Qx86I
                EqHesKk7B62KuMyJ2OhBvaWYQrhKuB1hCtbWk2R5wsDlJoV6/K2vKYXPYe65etjLKkzrQ8WeWeXX
                ST7n0Fi3dPK7/WQM1GLApc9z6Vtr6THresjOgcvcS11GW6DaDJS79bibUFFHfGonnNcQlcot5T33
                DPIUQCj15RzcQ0cYWh35HnzoCcyHjCfTq31kbHkWggGXPs9lwX9dZGXlHLgY4OJF1WW0BarNwIAT
                Nv6sVC6Prh2yQUKUw5xS4ElZK/K/5akUbvGUb1fZ7tvVxZSvnR+gs5SyyZZ8ggy49HkufWtdKmfl
                HLgMfehNaiZeGWi5yWv24WT++Ve9e90fjjqzafKD2b5l90ULoW7PLrvaOeEoaTGXRg58iE6CvdhH
                xpZnYRhw6fNc+ta6CMvKOZhYlzazB9ITkYlHBmZUut9I9ppXbmihF7x+iWM31FG4QQmdobbsHehJ
                qUd5Sna5r9NUdw8S75lmBl2krVcyf9rFdbtkDNRiwKXPy/3Iwbu1WOnk+tKd/GY/ZcjAIsO+S+Nf
                /mWGWQaYVXnazHKpOUDFpNJ3wbKedLMphW+I17qLC775ap+MAScGXPq8d5xyqiNSViMHb9ShS8cg
                LkR1TMO+x2WgW/dzcRBCfk1xXAtrxf/NIkOHjKsVyNN1X6MGMjco54BRlIXQaWNP5XA1owahHqvt
                iRLL1oEBlz7PpW+tS7WQnYNBdVlggVJlQAsTy5XKGalmEm7in/QqzRgRonp0hvOhl4bRfcirZPqK
                j4y7yHPLLq6lfem6tDOw9JNngHtoYbALOAKcBUaATUBW/WJHowZ1/KGO7+PqCOMUJOqBC06ZEGmc
                Q8RBFBIOub3u1IG7RKP06z/PxZMmf/Z/JLpcogkHnli5XBo579AtUlvwE9P87xO/T8w0XKPfGuB9
                ubWrMTHjaU3O2JhpWPQMGKA/0RbXTcHmYDPQ2SvOh/L7RMKeSR3/NZ8zEfJTX7y4Q2a5HznQkFvU
                F9b0Jo6GCk08M6ATE3HThnlWI+vs3/myV68Ls840Qn4HRgibdNDQphT0pLdV0kbWmd69dCJR27Y6
                k7ZgcRjQwyVYB2hU4AnS0uI9LbI+AnTmGPDzLBnA/xcS54+gZ+tvaf9Zggy6RczkY+qedsmkIrqp
                UpfWp4w3HTJymYNxyMai1GJgwImDrydMqNv5aqkf+TrO0LEh7lCQITRYq/Fn3chGJRPhI5J5JJmk
                EktlDVIamFhq0RK6NVpwC50mA9wbPcBW4Hfkoxel/ROcBNYGUTtfOeBZPSC49HWpjRpgdykT50AZ
                IS6GuBD2v9zs/1kMcJMsAE4CUW+M2RiUg9erNHMvFif+d7YLBfxSKZVGDRy6acjzyD/3SPsN1IVU
                znKPYZOvKQWpfHsMvS1qAgzQtvUGu4O/kBw7rEp3g8PBYiCu/Jh0V4ibSB3xXfq6cXWk6xwkS+fA
                xZBBzpY1eEQqdHegG0SLx84CdOzxZN5hW0xuamrZkVQ+i5dSwLHLpVsHTHtATxpBCmW6PIr9wKNy
                v/WYd7WsfTkH/8RR+qCaUvZ7egxwH2jK4LvgUnLRtLWc+b2BFuomKVoLcEaSCVZJa1CV37v62eWB
                u6v0Zrsmw7MSF0NcvKms7Ak2H26YISj3K7B6OyVP4/dr4z719TtxsxcmDh+9N0crazi13C79Inx8
                odTU4wfl5uaQX5wjxyVLp759uT5G/Xm6/Q++P1One6DDdHAD0FNjR2ie+XPQF8wD5m2FOpFBYCWg
                +edlQFRebUoB0rIUylvO8Q/BvmAQyEKyeB360g6GjHOIU3cUcw7qpir8gNw4qmDngN060VZDY/uA
                Kzu5FumnASdtdvvE4WNPKJUrv4gUMeDATCVMrpRn7rjQCUOCHRWhfJeFQjWKviS4UQOcFTkGW8Ul
                BG61AFodz3fAlq0YwN+uxJyDrthJ6BplsyBJaeRTTsH6CSUbJZksFsYPiqJQa1iXB+66synXHTJm
                QAp4HZLQ4pAo8j43/yJRIjRiWLidG7u1BednoFcXHLzOtZVaG9QugtW+RJ7lyaMeuJS/B9YOHXyI
                rxgD2XbA0CFjQ9YUrv+Ifr741hP5EtSdqSFzlJRucK1RBI28yfHYAWwM2osWuy0FH/iVJmkwQBl8
                m3SPBtq221W7lkb2HdOcn7JObWcAtn5EhtpqGUVWQ6fno0SIElY3QFbispBNh1TU8t6z0j+4fOBG
                826af34FaLi51g2kJ0/dbLFFjWK/qWMPplNtjp2Y3wTeZQRk4xw4BhoV0pOTL7mUMm8Ix0AEY2sL
                eBr8AmzCTxp5GwXeA5Lb+N0cg/9xkdj/tGfdwG7gQRJ9CuwParVrieVfJaE3KOs0HYMlyTeqYyBV
                izFyIEsocC3eibrlaHMKZrTim3zDAFxqa4622Wzwza91ffqSUPI4NYqQiEwYMWZ3hqCuJLE+iSSY
                XSKPlyrddhlw0nfbGvzsco6YE+V9CVEOihgtqeAtJLQMdebNpBLMazqUg6ZitwXvwoc6L5MEGIBX
                dY4Hg5+CpRJIMskkfkVZH5Nkgu3Twvbv8f229r/V8flNdBpURzjnIFmOHEjJZx001dCeSSsDVCSN
                pvyJr0+AqI6BUlEHfglp0J8nIwOHDbm+Um7aiNQ01JoTqVw1ZVpp05w4BstB6gEeidVTcsM7BuIf
                HmYAnRBpjkECFZJ2aEWgMwneAVrDFJpjIMf4LyBNcenjXPrSSDaYcxCJLn+BuYF6gePR4D/gRzE1
                GUL8H8dMY7boA4cO/jfPVOtWSqXHZrsQ3he8osoJ/YcO2X/p5iHBn2xHmcuJ0wiRnlh9iRpvE2Mg
                MQao14PBXST4IjgczJ1Y4skmdCKOoB7E0hRzDmDXxdtxIS7Ngsw0bW6gJrAnmWrhydlA27GSkHNJ
                d1ASCbWlMfD4Ie8PmDZx00ql9H84CZPbfg/mb6X8II7BBv2HbaZ5ZFTMheyElhrG9iWvkfG9vjK3
                fIvFAG3O2uAerBoLtgZyfkOVy2knzslAOZc+zqUvjWRKpgVDpdDq06ciaVgqaY68L4Wk4Z2GEbjS
                qM7u4DSgfdhpiPasbwS3XySd+Iej7p2vpaXH8ZVSRXN1msrwKS+Q+Yn9h256e46cAq3R0dOUnqyW
                9EjeMXD2K4/5W9YFYIC6vBJmnAV2zYE5z6CjRgw0spGqwEtPMvgcRB0Z1K6zl9NULmvnQKtORUS3
                iEatCBFakV94aecUnIqxq2Rg8NXksR/8pvIkPems+xdjPUIzOwIO5CEh62msd+Hz1AHLT7qivOee
                MzPgMtEs0H04CQ5LNNFoiWkeeAXqhhx0E2MgMgPU4aWIdDrQ+RxR2/3I+cWM8G/ia3RWh8Wl0h52
                1A9+1uQ35RtFNB2qB+ZU27RMnQNZDxl6EpIXGUX2hIjrokTIW1h4Ucepw4s0UpCFU9CeomPh9/z2
                PyT9efKI+1ZuKXc7sFQp7Uzayyadfrv0ZvB5LPf2jdOmfn75os07JD4q0i6v1D5SH75F4s+BHqll
                Ujvhg6gXf6wdzEIYA7MzQP3VwUEng0OAno5DlvtR7mzqeubTZ/D0Q/K+IiI5T6GrDutKVXw4B9dg
                0V4RrToLMk6JGCcXwT07BW0cyQPdDo41F5iqYG/5w7PHrDyzUt4Z31zz6eskkOEUKvKdpH1T9+nl
                OxZoHvJxAml6S0IckbnKYgtvSvzv7IxVqRNytkyMgboYoO7OT8DjwdFgrroi+Qs0mqyHUccf96UC
                fJ1L3sdFzF9rIX4UMU7k4FHnOSJn0EkELaSI6hy4LNjoJOtwfqJSaKRA828aKVjVs2Ya7rsJneQg
                jE1TF9LXcJ3WAAjDZ007NHXbjryX5dKiTD0syujCoixT4nP7l6hUWjj6nhesVMYTZjxDUOOZqngP
                Gp/4ZJ4vRi9/1HZFOqBnD2z36RiQfekkysocAzFhUpMB7l85tD8FZwI5CCGL1r0NpX6n/jBUBwku
                fVvqixGltwo0U6ESbU+Gt0bMdAIFqWGq3Av2h+QUdORTQ/DbwPVDHS/4+P7+OXfP3TSj5yLllm6f
                91/+/Ql5XDcQlTfqh5wi3fz9osZNMPwTpLUe9SCTedcE9bakPDBAnV2RbC8FOuskZHkN5U4Gma0p
                6IqM1r7gQ8LM11W4Tq5twb2pqZBiCYQsCVxkuTwzgcHzgiPBf1yMzzDOZ+S1YZ65zqvu8K5tq/dk
                WNbVstosrxya3tkxQOXRa+GHga+qVaRAfmeEsXIY8DFSXrVA0Gc1R34GVE00wQuZk4XH8xaEaA98
                1CcjeaXy/HIl2Lo8Ch8BNEeU1BkFaXIwg8QHg0fTzMTS7pQBzdNu2emV7H68l3tUc7G5F+698nu/
                HNuP9zb2/Wpq6f08HHqVF9LhVtvS/wTWDFjnT9BNpy7q+OMQFya7jLTo2O6JWXCe+bSCjKJiaVpB
                0wtR5BJI0crX4EWNEkqqkT8KbAe88Ey+UeR1Ap8ProDnKVEiWtj4DFBnNPeo4XzfK7vXofyfjG9R
                NilULnqyx+QPP9mEXXLrtcyakmHNCmtXyhX+liqLoEX73R4f8X08cyWsWwGsWyk3lf/b1FS6q98J
                Q97JRuN850I97Y0FzeA4kPnDJXnWI1p/9GswkrqsYfsgBS6vQrF9Iyp3HTbtGTGOU3AvnRaknIC2
                oyJq/CKkrBIxTqbBsasvGe4H5BRoHi4PovUF5wGdFz8zDwoXTUfqTR9skmPgu35n1vDEKcMJzWP6
                cpj41k2zdruU9ZCxQJz0WuM+iUt/U7dy5aYFTxiitsbWW3QglXqKEzZrbcEKHS6F9PURlNEW3FQP
                CErCYPj8L+ksHTGto7HtwohxnIL7cg42Rtuoi950s/aDGHn/QQmFvAwK/RT8GMwXlHKdKyMn4Dpw
                HnyqUzLxyAD1Rzf7kR5VUNZ62tLbOl/1rEen2Vear+05sceAfcrlWWeBaFROB6qlJa8z1ndTU7ly
                Wb8TN9OumoYW6qemQ/Uwdzjw0mfUUQCfEWYo+B11OHjHDk41qqURrKiyNvb9K2okl/BeChpiNDSl
                +aCoQ6jbQ8ztLoamEQc75EGfBXTMsRcuI9r1KeEvBr+Gx7cixrXgKTBAHdK0Uwh1+gTqhOZng5JK
                c3PTxF6D92CaYATTBHLCM5RKS7ncdHm5qXJao047UD+1OPmvYMkMiY+a1R1EOIz6+3bUiL7Cw6v6
                DD2gRZHPCTw/dmpdWOrSlHoOnWSAcTr+0cX70YiDd6Fg+4A/oMiLYA8QumMwDh2PAYvD/c+BOQaQ
                4VuoQ3Iu/+JbD/LXvaippaBk4vCxQyb1HPw4z4HXZO8YiArcgkrlwJaZpVcnjBgz8qPmMaHv30+0
                /LB9fxIcA0J1DCah2w9oz74HcuMYtBaSS1/2OHZm4hhIRy/OQSs5mhuKKi6rO6Pm0WV4bhg5An8E
                h4JuXQb2f/EfqCDnZXkqlVbsaujNJAAGqEfzosbNwPc01HR0+FGWjU4t+t8f9cBqE0eOuYOFhaMJ
                u3at8Blc781Nf+KMnuXXcViOefXCO9Kc0sjAnK6zoG7KKTqXUJeDnl2H9nb1anLWy4dCcK5dSHDp
                y1z6TBfdZsXJm3OwDpXWd2X9Oczt7cx4+hFbyOJ6sCE3zgbg+pAa/vTNDz8H6rCcSjVuKwag7XDq
                x3MB6DFLBZyCw7q1tDzFKZnbhqLTN3pUFsRhOW/+KX0emnj2PeyGKJ5QN7W+4BZwXKDWaYRAIwX7
                Ao0c5E7geG6UdtkCmqlz4G04HIIGQtAHDiW7EZXiUYd4saOgs9ZKqEKqcEMTLdS8ElwAP2+Eppzp
                8w0D1KPhfBv2zS/ePj1Pzt+hvkzzpkFrxtqSOHHSFEa3Kj/xrUt9+ZfHszhyZ14DXpgFvdTLZbBd
                jsEq9XGQaSgtMvwd0LHHuR4BhefNsOP+iOzpoW8BbNe6sUzE28gBRk7AQpeV0VtlwkznmWzOzyE5
                Bpp/0tD0bmAROP0/YI4BZIQqNAx6r0gIjoEamx9RX7w7Bp+OuK/fpMlT7sqPY6DaVVmUsnxo4vDR
                ++hb3gVbBmPDP0GIjoG2JW5CXT0C5NoxaK0nW7f+jfLneWzPzDGQYt6cg1ZWHo7CTmtYn8ON2zno
                m0aUJ0lUZyksSoXZGfwdaCuaScAM0ABrKPGyQFQ8lzqjeuRV9CrvqaVuj9PZ6mkqb9KrVC5fPWH4
                6BHaVZE35dv0pV4ezOd7Qb+23wL5q/Uw2g22JnU10yH1lO136cNc+spYZviu0C4Gr01l7h/L6nxG
                fhe1zwarcqPoFDttR5yYT1MaT2vq7BJYrSHbPgFY/x90aPatx8SRo7/TUuqmRbPL+tYlTv7ch0Mn
                9fzun/PmIFAnu4ELsP1i0CMOBynEfYs0N4bbU0BhHnzge3HsWs2Br8ydI9/OwX0OJElnl2EZh6zm
                iPL+HL+k+8MXJP9noKmUpbhJTgQvpJulpZ40AzQIcmbvAXIQfIumEw6kHn3pU5GJwx9cpFQpa0pM
                C+AKIOW9J/UafEpeDKFOapfM7UAjkKHJXSi0FnVU0xxFk20cDNJ6C5e+0iGrb6J4dQ4ofHmHOisg
                qrgMy0TNo7PwWimbhYwhkwPAwnC0H9DLcGZmkbHlkSwDNMLq/O4AKyabsnNqcjAzfwppr+3b5z3a
                p1RuuYnfFmv/e+4/V0rNH4wcrfU/QUurYzAaJX09ZFXjR47raUC7ESZXC5Tz3136rqfgQ2v0MhWv
                zkGrpfISo8pWVHAfOy2uQ9EPoipbR3h5htqBcSIYREXYDFwBirD4pg7zixmEOqr98DeCdQKx8Ab0
                ONenLrpve3819RLWGKzrU4+08m6qNF05YfgYl21qaak0W7rw35cfZj2Zz3bB/5dJqLAtbd4ZQE5C
                4QTuu2OUFrVHFZc+Mmoec4QPwTm4cw6tav8wgCCZH45Cpf2cfE+vrV5dIdTxy9nYHwwkbW3RPBu8
                WVdsCxQ0AzQE3VDwauDSGKRh28sk+iPqlxxRbzJ51NjjyfwH3hRIPePKXGxxvOWD4fctlHpWETOg
                Ts5FFE0lrB8xatrBte5E0wiaeiuybIhxLoeeufSRsXkMwTl4CCvU6UYVl+GZqHl0Fv5SfnQtrNeJ
                +yuwBejPzbAnuBLIazYpCAM0whrV+j0IZYh5CrrsSj3zOhL1wfDRW1cqpZEFKeauzFiiqdzthsq1
                18pBDEKok71RRGs8vhuEQt8o8RvpRN18+5ufCvvJpc/S+TVynjIX784BlUIrUcc4WO5CtEM2s0dB
                X22v2QH8YvYrnX7TOoEHgZ6WVgI6xvgYcD+YxneTYjIwHLMODsi0H1HfXvKpjw45aio3XYgOPqYD
                fZi+0eRX+wcxQoJj0AMCrgd6KAlFNHWgcwuOBGpTG0Fc+qz74MfLejPvzkFrjXB5El+XSr+gjxql
                wgInkPcmQFuB2qYCtIjmBXANUMOg6YLB4BzwMvA6pIs+JikzQJ08jiyGppxNlORV99QxeJVJH372
                Y9YZrOBViYwzr5SbznyjeYye2H2Lns6/51uJdvl/xefdqZe/bfdboT/SLiyCgWs4GOnSNzpkM2eU
                ILx4iFsa1f47p3o1f9mfCnZlzVApB0B/8dgDXWw0IGWuQ06eevAz9DsnIB01IrcV9XKGT50mNI/p
                W+5Zeg0dFvKph6e8fz5g2JBzPeVdok4eRt6/95V/J/lqmHwH6uQjnVwr7E+UwyEYd1FEA/UwuRhc
                vRcxXiLBgxg5wPg3sOYVB4v2dIiTeBT0rwBzDBJnNh8JyjkEp6JtSI7BO+jzfeqlV8dAJVjuWTmW
                P43oGMj8YR+PfGgBfchaqJMa2dRUTijyFopo4XVDOQat5O/lUAjPwJUXx0C6BuEctJLmsl1DWxrn
                dyDdohgDiTAgx4CEtMju9EQSTCYRLfDdhYYl873RHdV//5y7B+Ie/Lzj7w30fYHppemZTzNRL5eA
                Y00nab1BCPIcSuhNsS+FoEyWOlAWcowHO+Tp0ic6ZNN5lJCcgzs7V7HLX1Xxd+kyhF00BlJigJte
                94/WnJyQUhYuyWoES+/beNIlctJxuk/vdRJp9k063VylVykfNems+xfLSmfqZR/yuhHgmAUhmt7a
                hDr5bhDaZK+Edi257Fxx6RMTsy4k50AV6BMHy/ZyiGNRjIFYDNAA62bXHOKRsRJKNrJWgO9DI3xf
                ssm6pVZpHtO9pVTRwtxGl16VpqY9MiRB26W/k2F+XWUlJ2Ub6qRL295Vunm65tJHTcRAr9MvwTgH
                VB498dzkUOKb01D3c4hnUYwBJwaobzrp7EpwkFMC6UU6jPtIpyAGIRN7t2zInIvdm/8rjZ2yKBTq
                pt7DosVvIcholNC6l4Zdj0V5LAoHGzsUxg3w5mULY5uuwTgHrQpd26ZYhL9qqHeNEN6CGgPODHCz
                9yTy38A+zomkE3Eojckl6STtlirLdHd2i1nEWJXvfjrivlQdJermvDB3aSDsPYUemt5qWMegtRx2
                569LP+vSFyZa9C5KJ6pAh8Tu5fuHHX6r56vLsE096VoYY+BrBmh8F+DL3SA0Z/SX6HT214oG8AGu
                yqVKUyZPywGYW4cK5aZppW7b1xEwTpDziayFiL7lNRTQexI+861IAPm79E3vo/cDvnUPyjmgMk2H
                EM1RRZVNaYxCWXwTVXcLnwMGqF/LoOajYNPA1L0cfX7OvVMJSa8Pzn5wVQ49EmcmrQy0VEqpOUvU
                T52+d2AAZGvrnc7W8L5TxjcXlIkctQ0c9Lge/rR+yKs0ec2988w1ZBtVtDhst6iRLLwxUA8D3OR6
                Uc0/wIr1hM8wzC3kdXBojoHsb2ppSa0jzJDfRLOinLae9brqRFPFBatU5iPJEKaUtOhQiw/fSNjE
                vCanRaja6hxVXPrAqHnUDB+ic6BFLJNqaj5ngL3n/Ml+MQbiMUDDqzlD7aQZEC+lxGPfQ4pBHHLU
                mWWsN9iys98b+7fKXH2mTt0oBQ5OJs3FUkg3SpI6ElknHz4bJVLBw37fwT5t9/S6S6FN5+CcAyqX
                Vmi6rLjehIZ8+TbD7K8xEIcB6pJOPdThPdeB3nHSSiGu7o8duVe+TCHtRJJklmPJRBIqWCItlXKi
                awKoo+L5SM80qc2Wo/qQZz2CyZ5yWR1l1nFQ6Dp4DGKKMDjnoJVM12GVgx0Kw6IYA7MxwI2tHTC/
                B7+Y7UIYXy5DDTXEU8NQZ04t4I/WrawtXCYdGSjP2trW8dc4388kcq84CSQQV1tob04gnSIl4doX
                ufZ9iXMXqnOglZofOFi7Pw1TD4d4FsUYmMUA9Uc7Em4DhwZIyfnodBAN8YwAdftapc9G3r8gM+Ha
                8mnSkYGW5Jwm6qqeTvftmEXG3y+jPl6acZ5BZ0e59EFBl3J5Ey61tikICdI5gCCt1LzegSHtWLCF
                UA7EWZRZC7vWgIcnwdYB8nEqOh3Xem8EqN43Kn3R1MNGDb6hY7ZPjBgnyc3ZJO6zDX+F/H1PaczG
                byBftE7J5Z0/msIMRnxWrFokXFkrQJXrrsM5VZKznxuBAbx9efqPgWUCtPdonIIzQRBzkbX4Kc+c
                mWQHWCu7nF1PZuSA+joEw7fxaLymtTS99blHHULN2rUPcu3zUuEhWOeASvdPLHZZ+bolN86gVNiy
                RAvHAHWlJ/gNhl0FNBwYkmgEbX/uhQtDUqqWLuVSeZFaYRr3eiUpboZ55vAE6uXTnnUILnvaEm13
                3sRBscfh8zmHeKlFCdY5aLXYZe+u9pX+ODXGLOHCMMCNrO1fY8FPAzRqGjrtToMR1NNEPTw1le1A
                suo8lReqfq2+K60d0Bb1hU4l1Bjq5QWppJz/RF3ft+LS16XKVujOwZ+x3mW71o+4gbqlypwlnmsG
                qB+DMUDnv28QoCE652NLGuAbA9StpkqVUtNHNQM1bICKy/HwHdk6ouMPGX6fQV62zqATwmlTtAh3
                /04u1fpJx0xfUytQ1teDdg5oHD+GEJeFiXoi3C5rMi2/8BngBm4Cx6Hp/SDEI7c1lbYOdf/B8Nms
                omGlZXyVK/ZzqRyLG+ruvJDo0gElxf2vqZsvJJVYwdLRi8b6O9j0VzgNbu1G0M5BK8muwy2HOBSS
                RSkwAzSsS2LeveBcEOLIkkYKNqKhGMff3EqlqVusDjC3hteleCUuNweQTd+6sko+0Psk2Zx8soVJ
                0bXPce3jUiUueOeAhvIhGHjZgYXt6AxWcIhnUQrGAPVApx3uh1la8LNZoOadjl5aYzAlUP3qV6tb
                y3v1B260kBVnblSP/7+9M4G3o6jS+HsJISEQlpCwKRCWsAgII6iIQEiAYVGQnZFlHBeGQRBZVMIm
                ARRENllGBxUYWQVll0UYJYAgCCoiLqBARGQLi+wQSN78v/Befi/JW+6tru6u7v7O7/e9e9/trqpz
                vnOqurq6qhq2ypwfo0mILzfNY63Yi2/W4bzNWzl3nnPuh9P75vktiX+T7xx0sxSyyYZsOzgJlq1E
                aQxQacdSuB5NXQA0JJuavI5Cu9JATAFanVB5GTtu+nSM0Ja6lnkZ6Mr0WEHzZMq64fkjZV84rzn+
                fw4DelQZIkmOGsiQqnQOfoCumr3drnyKi0PIM6B2y/H5CTKA77dDLY0W7JSgelLpcaDHCOq81EY6
                d9tNHQMNQVvmZWBIpscKO8+bXYH/n0KcdhVYXmWKop3Rvh6fDFBYNwYXB6QrJEklOgcE5XOwcXUA
                I1q3XuYwXIDKTpKVASrrKKDRpmtB5qVjWfXpJ/0v+F0TD2u6VrzzH/3Y3eyfs40cfKIk8jRPItmL
                WEmc9C72QP5ZsPcPLX7XS5ZeavHcwk+rROegm5XvBrKzPxeKEYFpnaxiDODrTVFZM/4/m7DqZ6Hb
                5jQMzyasYzbVOmfdli2DWqaeOaxzgTtDLCOuNyDd8iFpI6Q5g1gNGbmNUHTaWeCXRdBw30AtQ69p
                gcW1l6wynQOC82eYpiHidkXPnMtc+tOuvj4/gAF1AMHJJJ0KxoEU5XmU0quWD6x7Yzurq+OaFB1Q
                sk5TFz98k9A9ILRMrgzRBMRzyii4ImVq06PFA3S9lzbgroB0hSWpTOegm5HTApk5mAuHZvpaasgA
                vl0Ps+4FXwKp+vlWdFuXBuE6PmsvS6363N24or4jIwEepAnK0mEqq3NwGTGb7NB3gBuiJaHdGUpm
                XwzM8NTAdIUlq1rn4BKYeTKAndVJo8lplhoxQOVcAByBSXoPx9qJmqbJeUcC7XjYmOfw705K7GpE
                R6jVuFtg6NtBnQNifDxlrNVqOZHPuzJyfnXKbheMGRdg0DTSJD8JuVKdAxpXPffS89oQ0V2lpSYM
                dDeYt2PO18GwRM36G3ptQtyeANRJaJpc3TSDB7D3t6Mnb/n4AMcHOrTlQAdzPKYRAz3OtfTNQOg1
                5VtVaA8q1Tno9s//8Plq374a8NdNuKB8eMAzfDB5BvChRgu+gKL3gxTfi9DD4eV8WY9G4Jc9PzTt
                880Rw7mwdGq5lqWjK0tH6UMlEXg98ft2SWUnXSxtkPac2CBAyX+S5tyAdIUnqVzngGAVuecFMjUl
                MJ2TJcAAFXJj1LgPnAlGJqBSXyroYqhJSnrXvWK1sbL8IRvx0rRZQUPpNSOtq3Po0B9lsKmszoEf
                KfTvtGP7PzTgkXNoF0JubgfMNI+DlescdJNwOp8hw7Rbc4HZKA8inWd+DOCz5cBFlHAHWDe/kjLn
                rCHYdaj85wJvGCM6Z3aoEQ2pq0pdD+nsuHjMYRP+FGIMcT+KdJozVbTo7Ys3FV1oFcrDJ5ujp0YO
                2hU9FteNTSWkkp0DGt5psHtFIMPHB6ZzsoIZoBIuCPRc7yGwZ8HFt1OclnvtAzTp8NF2Etb93LFH
                T3qoo6sj2S1i8+e/cwZX2aMzlKOh6zLa6YeI5eTeFJiBx5hJQ68hevtiyIT6mLq3nFcZQdeycoOc
                eMogx/s7PIkLzmb9HfTvaTCAjzQJ63dAexcskoZWfWpxLb++j0r/feDRgj4o6ho2e/SgqReas5c9
                fOK0Pmhp9aeyHimE7CnTqk2VPY92aVuUD53rdGqVDK9s54CGWOvaNcwcIqE9v5CynKYNBqh8KwIt
                87kZrNFG0qJPfY4CPwl2IBb/UXThVSpvqa9M5D0LnZVqGCPx+9LwjndOyJjXBzOmD03+QGjCmqc7
                LtC+m2knKtXhqmznoNtBJwY6amMuQP8amNbJcmAAf2iHw6PIWs9md86hiJhZXkpmGi34IfBoQSvM
                Dl2Akb5mbYrU2dlx4qJHbPF8K/QMcM77BziW5yF3DuZhl/ZpB35af56fW/039FrVav7Rz6t054CG
                +UYY+WUgKx49CCQudjIq3Xbk+Qcgn+hlWamKRgi0/fEeYHqqSqao19jDNn4FvdT5a4h0PvrG8OFn
                RjD2vRHyCMnCnYNerNFGdfJv6KjBz2kvpvbKrhJfK9056GY4dLLPh7ovSpVwVB2VhP/x4Hpsuxas
                nLCNWp54DFidSn5dwnomrdqYwyd8HwXPTVrJOMq9OmTIrO3fXcoZniF1YzSpy+gsv02c/z1c81qm
                3BWr1gm0LPQaFVhcnGSV7xwQxD+DitsC6TiOCqgeoaVABtTogW9Q5INAE3xSFT0yOB+MJ86OA6+l
                qmgV9IK/rjEzpn+e1Qt6XXVdpatjVuceS06epJGwrFLWqIE6w5ZuBmirhvJVS3JD5Cbi/q6QhGWn
                qXznoJvA0J7ZeqTfvWwnNKV8KtkoIF89Bg4DCyZs+63o9gEq9mfAkwnrWSnVOqfsNmPWwjN3Yf7B
                45VSvEVlmWdw+NijNos1uuTOQYu853zav5N/6OTo0GtTziYNnn0tOgc03ndg6i2Dm9vnGSdxwSpj
                6K5PZer4o/gFh2Cb9gA4DiyasJ0Po9v2YHPi6v6E9aysaksftMUzsxh2x4B6jcR0dly05OTNvhnR
                Me4cRCQzJCvarVGkOyEkLWmuoQ25LzBt6clq0TnoZvGoQDZXIJ022rFEZoCKNQzsS7Z/AaeCMZGL
                iJndC2R2IFibCn0d0CMFS04MLD150u94nrcX2deF53tefatjn8hx485BTvHXRrZHcO4ybZzfc6ri
                +qs9/1TxszadAyrlr3DATwKdMJmLWFkVMVDldJPB5VCghv/PQC/Kek+62na8jW6ngVWJobOA/rcU
                wMCYIyZeTTEaQdBKhgpL57UdQ4dtudKUiW9GNmK5yPm1mt0brZ5Y5/Now1bGvoMDbfwxbUmlV3zU
                pnPQ7UD11ELuREaSThPkLBkYoDJ1gh3JQjsbXghUuVKWK1FO+xUcCl5MWdG66jb2iIk/GTKkSzvO
                PVJFG4n3E8fMmLpj91LN2CYsFjvDFvP7Z4vn1f009uboGB5g5CzSHBOQLqkkteoc0MD/FnavCmR4
                Dyr6hoFpG52su1OwFSRo9EYX3LUSJ0TPATclXnYGf01c19qrp5n9wztmfhhDb62QsW91dHXtudSR
                k47onDJFF4M8ZOE8Mm0hz8bv+EmbNhGedKMTIpfQrvwpJGFKaWrVOegmVqMHMwNI1pLGM3ShC0jb
                yCS9OgVTIeAmsEHiRDyBfnuDD1N5NYnVkggD2klwzJKjtqL6fTsRlQZS46nOWbM2HXvkpEsGOinC
                MXcOIpDYbha0a1q6+K1203Wfr8eSxwamTSpZ7ToHNPpaX/zdQJb1khNdPCwDMEDlWQDovQK/AeoU
                bDrA6Skc0qz4o4E2MboI5HWnl4KtldWhc98N3l7qyM32p3v+bxjxWIKGoFrX+R1dQ9cfc9TmGiXL
                W9w5yJvhvvP/HD+/v+9Dg/56Ju1LLUYja3mXzIVrSVz4F7DEoK6c/wStaV8NB9drmdX8drb9C7xq
                bsanwaFgpbYzKD7ByxT53+AM/PlM8cW7xFAGuqZcvuD0EWP365zJlsudCaxy6ey4fuisjsmjj5z4
                YKhN7aajvmloOnR9fbvF9T5fW4TH2quhd77Jf4dzzfPQtWNsgLLPkkYbpqndqbzUsnMgr+DkL/IR
                OjR0Ig7WEhYLDMClOln7gwNBSKUhWaHyNKWdDs7Bjy8VWnLDCiM2VsTkl+A5l0lsL3zjlsVmzVzg
                y9yya5+MMvYjuZfOyVfGHj5xatGuhdu/U2YZq6jWx58aFWycwPlpGH1woOH/CW/fC0ybXLI6dw4W
                gG0tJVkzgHU9N9LueIXdJQTomHsSKooaJlUU7VVQ1hBnO3Y+wsnfBBfguzfbSehz22eA+FibVDcD
                3WltlSfnz532s/d0vdV5aEdX506UpQ5JnvJ2V0fnrXQKvj928gQtSevKs7C+8obbRfhdd6BltNHL
                YHPjRtrgfH34vgdozkG7cj8J1KmqzSPLMgKvXdKDz8fZW5P4xsAMFCQb1cnZrfAAZ4oJzRz/PNCz
                32EgdVHF1FJUNeQzU1e2DvoRJxthx/Vg8W57ruRzt7z5V3xOP2Hqup1DOj7BouUdKHO97vKzfrxC
                BjeQ59VDh75z4+jJW5Y64tTN751ZjQpIP4M0I/Bj4R2iAF2jJYFv3UzeC0LjaTM4uy2aQglkVOvO
                gfjF6WrAtg3k+iAcfkZg2kolgyeNDOwB1CkIrSBF2zyVAtUpuLlpjVnRRPcuj1jZhv+vAAv1/p3v
                54D9ivIFenQ+c8rt44bMnLV956wuOrSdy4LlqPWgQ3fefUgXd3az74qf5J78yc6uzsdmds264eVR
                b04df+C2b/WRoJSfsG0/Ci5j5cZ9+O+DpRhdYqHwPZniTwxUQTcluwamTTZZEzoHq8G+Hg+E3AG/
                Rrq1cPzfkvVgRsWoFGuShRqiT4FFM2ZXVPKrKegk/HJ3UQW6nHcZIF60SuUCoDutvmQKfjm2rwNF
                /jb9pF+M6pj55rIdnUOXYzRgkY7Orqc6hrzz1Jg3hj3bOZ+3uCUAAB84SURBVGXiO0XqElIWPKuj
                9Z8haTOm+R/8p/agMQLX4zFWj6BHBBitx5drwtm0gLROUjYDOP80ECqhjyXKNrvf8iFiQbAbuBVU
                Rd5G0f8F7+vXMB/IlQG4PwDMAoPJQbkq0oDMIfjuwUjO6fhnGkDvHBPhULu63pqBy6/PycxfqscA
                jl8cPJshAPaqntXza4z9I8Ch4KkMXBSd9DUK/BZYYX6L/EsRDMC9GtApoB2Rz0ImdhVhUtJlwJvq
                qeK+DFknaXIiKwfB+2Qg+R+k7efxVWRFnV1+DODEz2YIgumkHZOfdvnnjP4aKXg8AwdFJ/0rBX4F
                VJr3/D2bbwnwPwScDULkOhK58WzTRXC2QwjZEdKoQ9KYDh22LgtezMDbnm261qenyAABkHX46KIU
                7WpFJ2zfDrQyHJyhnkRJOoNcLgObg9rt3tmKr1I6Bx/o8dMlIIv8lsRlrNVPicq2dIGvC7MQniHt
                L9pStOInw9MVGbiq3ePmirszm/oEwnjwRoaACF31kE3xDKmxdU3wcgabi0j6Fwr5Mlgqg6lOGpEB
                fLEwuBHEEA2/ag25ZRAG4Ekdsn/GID0gD20c1giBm50C+OlJ8ipf8t5roxF+SMpInHp4j4cDPp8k
                TaWGudE3651fAE0tJekZJZjE2R4lSKiW4I/R4K6WvNj6SZpQehwYnpCpyakCP9u2Tmn0M7dOjpAc
                FIK1ZYAeFYeKJ9zm4JfSsyQa9NKg+0OjgnRaRlcJQddhoKy7kP4o9ihBwtGD094DHuzPeRF+V97a
                ZMvSBwNwc14EjkOyeIlEC/ahUq1+wkY9Xr4phKDuNPfw6ZuZWkVFL2Nw7gbgnW5nh3xoO+HkBcMm
                hhiXQxqNEvwQeJQg4ajBP6oXfwN5y0wKOBWMTJiOwlWDj6XA66AMuaxwg0soEGIPykCu2rFGreYo
                wUXlF4mTT8kQJJrVu3r5VgysATpumcHGGEnVyz4YeC7BwK4q9Sj+0d3UfuAtUKQ8QmG7AN+JEQHw
                8LUiyZ+nLG1uVWvB3nXAm/PY3c6/x9eaIBv3LgNExEigxilUfk3CkF0XC3MB+qkyFC0PUOARYOXC
                DHVBwQzgJ008vAiUKX+k8L1Bf7suBttXlYTYPgpkWVZH8mDRHfFiVeEqRE/s094Rvw9miNdnk9bz
                ZULIr2IanL1FhmBR0pNSthv9lsxoX6vJNY/geLBWynxYt7kZwF9rAM0BSEUeRZF9QeMaYWzW5mRl
                yS1zR0b9/oPYMzOQq2XgG9ePFVs0IAM4/fwMQaNnpxMHLKDkg+inZ/15yN/J9GSwPqj9OzpKdmP0
                4vHZ7uAVkKJoCWVjHjVgq5YvPlGiI2r9LgV43SYjt9+JXgGdYfoMEDSLgyyTsHSRHJ2qpei2KtAy
                shgyjUzOAhuDxjTeqfo2RC/8pgtRlrsokucqN5B7VV4AFuKC+dJg75G5Mjpw5uog1pZvbNMkz6cH
                pmDAo9qp1bt8zhe1DfkB528KNAoQKnp9bbKCUYcFGqYVHVOBNih6H/AIQbJeHlwx/LcCuBukKmej
                WKPmHWDvikATnMuSMl4LPXiwRjgDQjXR9voMxOqmystuI/ii0lkQBCdkCCIl/XLKBKDfbuB1KTqI
                6AVVPwA6f/GUbbJurTOAL7cCz4EURR3zL7RuTX3OxO6rSnZIbd9yCq9fzcjt0fWJNFsSzABBpA2D
                fpUhmHSXPSlYgQISot/q4GugZxKaJto8A7TkULvXfRg05sUrBVBeehHyJ9AbFeXrFEXD2h8rnagS
                FMDurM/Cs/rz5yWYXUiR3dxmGQ2+gzzcFhbirQoUQjCMB6+CUNFd9/IVMFVrqrVFbqOGcKvgl5g6
                4t8x4KcgVdF8nXVj2lyVvLB7JNDz7DJl56rw1Y6eELoyeCEDsdpV1u9OaIf0JpxLUHw2Q1Apqe7C
                G7cUqwmxUSUbiUFtgKWLb6pyL4otWyVOY+qK7eeV7JjHKb92d8bYtBDQm0CzSO03hIoZy43Ki6j6
                cZbIIu05jSLMxibDALG3GPhexvjNO7kmHja2A43te+RNcAv513KOB3Zf2ILtA51yUTKV2YqkxwCR
                oyH3rOuOP5OeZdaozgwQs9tGiFuyyE1eJufd6uyDwWzD/lWAeChTHqHwpHd3HYzHvo5j0wEZSX2M
                9LVd1tkXZ/4tgAGCRC8JyjKJ6w3S+x32Adw7SXsMEGfqzGqFScpyP8qNb8+yep2N/dpj4r4EnFS7
                YXM4/SjQNtChognlH61XxNma3BggWDSzP4toc6UxuSnojBvPAPG1A3gqS5AWkPYcylioyc7Cfq25
                v6AArgcrQu+EqdV+JdizDHhyMMMHOX5Uk+PTtrfJAME0BGSd7X07eTT2+WqblPv0FhkgprQS4VKQ
                smjlz54tmlTr0+DhtEQctWWdiIZTTUDUJPAscg2Ja9VhqpOPk7WFoFkSaNvgLHIJiR18yXq5Ooop
                joA2qNKy2ZRFM8bXqA6z+WkKD5MTcVStXrAEp7p5uzIjtw+TvtZvpMwvsp2z9gT4ANAcgizydVNp
                BrIwQPAtDa7IEoQFpH2TMnQxrN2EtxDfwUPWpdGxXCa/1Go3ROw5PSM5GtlaO8SvTmMG5jBAEP1H
                xkBU8s/OydBfzECLDBA3Gi3YEzwPUpbbUG61Fs2q/WlwofkgmuiWgkyuE+EQ+oUIpO5eJ05sS4kM
                EIzfyRiQepFHrZ75leiORhRNvKwLbgUpy0soty/wmzq7oxIuJoCso41kEUX0TL42Gx5hy3Ygy9bI
                IvW0RjQgNrIYBggoLUX6pSIrg6ghXacYjV1KVRkgRsYCdUazNoJkkatoMtd7qspzHnrDx3pA9TwF
                qdXjBAhdH+hxQBaZSmJvHZ9H8Dc5T4LqPeCZLJFJ2sfBck3m0bb3zQBxoReAfRG8CFIW1QFNjPRE
                216uhA9tcvQ0SEVq8zgBQlcAWZftanO7pXu5zF/NQDwGCK4JQI8IsshvSLxIPK2cU9UZIB62Bn/K
                ElQFpT2fcpasOt+x9YeT1UHWlU1kEU1q8zgBRhYDD2Zk5i3Sbxjb787PDMzFAEG2f8ZAVfJbgPdA
                mIvZ5v1DDKwGfgJSl8dQ0HNm+ghReNkQPAdSES11XaEPVSv3E3YsBDTZNat4QnjlvF9RhYnUGBub
                6Jmtn39VNAayqI3fdTd0Csg6CkUWuYrmPSjWF85ib13TwosmyL0OUhHF04Q68I0dmud1UwRivZS8
                DgFRFRsI2BibcCjuL1VeVbHbemZjAF8PBZ8DqW9khIpdvwcfymZxfVPDzT4gleWKqDJbDqgD41iy
                ALjqXZMy/fUmdHUIiKrZQMhqyEvP9rLKuWTgyV1VC4A29MW/6kzuDP4AUhc9nz0aLNiGiY06FW6m
                JOjEc+vgBHhVXbk4Ar+3k4cf3dYhKKpoA8G3FHg0QiCfUUX7rfPADBAX2sTo40CTUFMXPUI4H6w4
                sFXNPQo3Gvn5LkhNtMy68hdCbFB9+V4Ech8ij9HNjVRbngQDBOEa4IUIAX1CEgZZicwMEAtq5LYA
                d0eIiyKyuJpC1spseI0zgJ+R4NoinNFmGX/m/Fos0cOOb7Vpe1+n65HdKjUORZtWJQYIxs2AhmOz
                ypFVstu6zs8AAbAJ0GYrVRDNBP/I/Fb4l94MwNF48ECCDn0EnWqxERV2fC0Cv9qZ0vHcO3j9vXwG
                CMq9IwS3svhi+dZYg3YZwG8fBDFmVysG8pb7KWAb4LkugzgajnYEqex6iCpz5HG+jRtE/Uocxo7J
                c6wK/zKLpLtUwmAr2TwGCM6vhsf2XCkPbR571bQYr30IaFlqFUR3mp8EXiEzSLjBkeYXnAxSlCdR
                avwgJlTiMHYcHYngL1XCYCvZXAYI9BjPzVRfpjSXxbQtxzeaU6BdDW8FVZCnUfLzwCsQWggteFoa
                pPpoSM/Ua/EKZuz4Boghnq/VQlz7lJIZINJjzbhVpTm5ZHNcfC8G8IfWX+8BNCxfBdFw+BHAmxj1
                8uNAX+FqY6A78xTlYZRafSD9q3AMG9RGnh2J4DOrYLN1NAOzGSDotVZXG3DEkG+TiZ8Nlxhb8K+Z
                6geAx0AV5E2U1JC434PQYtzAlS5Yh4BUd628Bd2WaNGcZE/DBj2uOR/EkHPJxG1jst62Yn0yQNDq
                LvPqGDWAPH4AavNe9j4JS/BHOF8OaMOb6aAKolfangGWT5DOZFWCr9XAHSBVOQvFKr/VOjbozaOX
                RSLZu8smW6Os2KAMUAmGg59Gqgw/Ip9hgxbqEzIxAMe6g9TSVPGd2va4qNSn/INfDwOVv7PM5Lw2
                E8OX7mLFm5bApSgzUGrfNs1K8nTsUFt4XSSSNQG48p2lJB1lpYpjgCDWkLS28owh15PJiOK0b05J
                8Loo2B9UYYtj1JwtmvuwN/BEwzZDFc7WBfeBVOV5FNusTbOSPB07Fgb/F4loPV6p/G6QSTrKShXP
                AME8CvwqUuW4jXx8hxjJjXA5DmhexyugKqJO4iTg561txgGcLQiOB7orT1XUQa3FLn/YMQbcFYlo
                PfoZ2abLfboZSJsBgnoJ8LtIleRP5LNS2hanrR38jQVadhpjZ0uyyV00yVD7ztdiGVsZ0QF3G4LU
                R4bU8Vu0DH5il4kd2lnyryCGaJSnFrzE5tn51YABglu96Fgv4XmGvPxK3YC4gLdlwN9BFWQ6Sh4L
                arF/foC7MieBOz3aOx3MBCnLKShXiw2qsGNj8FwksvX2W4+WZq4JziBpBgjyxYHeohZDXieTnZI2
                ODHl4EsTo2INc8bwYX95PMSBfcFCiVFYKXXgT49fHgEpy8so96lKETuAstiiXTg10hVDtBnVqAGK
                8yEzUB8GCPZFwM9j1Bzy0N3QIfVhJ19L4OrISLznkY0a1IuBLmi1uIPM15v95w5/iwE9hkldbkDB
                Ffq3pFpHsOUIoPccxJCbyMSd42qFgLXNygBBPwLo+WIs0Y5j3gthEMfA0W9jER4xn1+T1+eBh04H
                8V8rh+FxO/AESFk05L53K/ZU4Rxs0b4uMTtjV5KfV+FUwfnWMT4DCn7wYxBLtI7YW+X24yq4WTEW
                0RHyeYE8zgTr9aOuf26TAbh8P7gRpC4/RMGl2jQv2dOxZVEQaz8X+e4i4H0MkvW4FSuEASqBNmK5
                AMSS35DRioUoX7FC4EWbG5UpGm69GewOvF9FpPiByxWA6lDqEw41mrF9JLOTyAZ7VgEPgFhyDhn5
                kVoS3rUSpTNAZdCufN+JVbvIR0OWW5ZuWGIKwMkaETluJ6tpnHwMcKctYkzA52hwCog1+Y2schF1
                Cr8LFotofulZYc/HwIsglpxWulFWwAykyAA17ORYtYx8dBelyUHeKKfb2XChlSJFyZMUpMcGmwDf
                CUWscPCp+TpfATEvTGSXi2id/8SI5peeFfboZkbLa2NNPCSrruNKN8wKmIGUGaCSHARiDo9eRX7e
                PASnw4MatTyXMT5F/npJjjsEOVQyeB0CPg0eB6mLRjO+CWo12x57tJlbzInU75Dff+UQLs7SDNSP
                ASrLjkB7GMSSP5ORd9YjVOBh01ikduejDoFWiihfrxbJqTrCrVYg/B6kLrrYnQtqszyxx6XYtC54
                BMQSbVm+TU/+/jQDZqAFBqg0HwLaBTGWqCLu2kLRtT8FHq7MSOrDpNcjgwnAHYKcIkbcAm2oE2vb
                cbLKTTTErtcRr54THaVmi117gpg3LHqTqFfqlOpVF15ZBqg8KwG9RyGmaF5Doy9o2K9dEttZk61G
                UUOpB4BVKhtQFVEcjrVmfh+g5/VVEMVGLS902DUMqCMcU9TZe29FwtFqmoE0GaAS6RnfrSCm3Elm
                jX5xE/Zr/oEuQP3dlT7EMb2YaStQq+fGaUb6nDkhu8G3RmaqIFNRcqNU+cyqF7aNB7HeJtvjz5/y
                xdshZ3WO05sBMUBl0mZJMfdCUEV9Cfy7GZ7N78pwoYluu4CNwfLmpXgG4F3P6qsg96LkvxbPUHEl
                Yt/nwKuRnaHlnN7cqDg3uqSmMEDFOjZyZVV2l4Jarb9uSjzUyU5i8IsKxsRFI2471on3eW3BPu0d
                cUVkP2g+xuHzluX/zYAZiMgAlSz2xCC1A9PAJhHVdFZmoGUGiD1tTqVZ/inKWyilUbsNWjaooidi
                4ySgXRxjikYfPBG6ojFhtSvGAJVtPfBozBpMXjPB14GH/SoWD1VXl5g7EqQmWqJ6DFi66vwOpj82
                6rGlJirrDj+maN6Ol1AP5gAfNwMxGaDSaaLiDTFrcnde9/C5akxdnZcZGIgB4i32pLcs1ULzCfYC
                jXgjIHZq1EbvY4kt3nxtoKD3MTOQJwPU5iFA8xBi9/i1J8IXlH+e+jtvMyAGiDNNji1TZlD4D8FH
                muIRbNUeEoeC10BM0QjkEcDbtjclmGxnugxQET8OXgSxRVsNe1gwXdfXQjNirKylixol094VY2pB
                ZItGYK92OtQISWx5jgxrvYqjRYp9mhlIhwEq5arggdi1nfw0IUujE40YZk3Ho83RhNi6HRQlmqtz
                HFitOQy/ayk264VVJ4C3QWz5NRmOaxqnttcMVIIBKudIcEnsWt+d3x/4rO2GL5VwcE2VJK6+mlPM
                9mSrUbVzgPawaORwN3ZPAJogmIecR6YjahqeNssM1IcBKur+4I0cWgHNbfhv4B3O6hMupVtCPC0C
                Yr5HhOy6poPzwQ5geOlGlqQAti8GtPmQ6m5s0XyFz5Vkmos1A2YghAEq7Vqgv62BszYSj5PBx0L0
                choz0BcDxNN/ZQ1K0mvuwilgE9Do94eIYzjYETwJ8pD7yLSWL5nqKz79mxmoFQNUXr1g6HSQx10D
                2XZdA7zssVZRU54xxNJ+YAZoVfRCrP8Dh4E1y9M8rZLhYnVwPchDtBrhJDAsLautjRkwA20zQEXe
                CmhTlzxEExa/CRZtWzEnMAPzMEAcTQB3g746tIo1TV6cAiaAxj4umIe22f/Cx+JANwPtdLA4vWX5
                O2dO7Kts/2YGzEBFGaBSjwG6089LniZjvazFeyNUNEZSUps4WhZ8Fnwe7AQ+AkampGMqusCL9izQ
                qIvmWeQlPyLjJVKx2XqYATMQmQEquJ7taiJRXqLd1vyehsh+c3ZmoC8GqGuTQB5LmHvaB22I9pm+
                yvZvZsAM1IwBKvsaII8tU3saFH1eDlasGXU2xwwkwQB1axVwFchT7iFzzylKwuNWwgwUxACVfhjQ
                C2/eBHmJllOeCDwcWZBfXUy9GaAu6fHgySDPequJnl8GjV/xUe9osnVmYAAGaAA0s/k2kKf8k8yP
                AZ60OIAvfMgM9McAdWcJ8DWgYf48Ras/VulPD/9uBsxAgxigMegE+4KXQJ7yPJkfDhZuEL021QwE
                M0BdGQW+CtTBzlNeIPNPByvqhGbADNSXARqH5cDVebZA3Xk/y6feCLdQfdm0ZWYgnAHqxsJA+zfo
                ZUZ5y2UUsHS4tk5pBsxAIxigodgF5LUvQu+GTru3HQD8UqdGRJaNHIwB6sIIcDB4BuQtT1DA9oPp
                5ONmwAyYgTkM0GhoQ5Xv5906deev7ZgPBH7cMMcD/tIkBoh9PT44BPwD5C3aYOrbwHOAmhRkttUM
                xGSABmRjoNexFiF67qlXyi4T0wbnZQZSZYBYfy/Q6oO85xRQxGy5m78fTpUP62UGzECFGKAxGQI+
                A54GRchbFHI+WKtCNFlVM9AyA8T2uuBCkNdWx2Q9l+gRwl6gka+sbtkxPtEMmIH2GaBh0dDnSUAX
                76LkRgravH1tncIMpMcAsbwVuKWoykM52mvkeOBHdumFgzUyA/VigIamiN3ZKGYu+S3/7Qk8ebFe
                4VR7a4jZ4eBTIM9tjsl+PtEqBO9SWvsIs4FmIDEGaHjy3td9vtaOH7QM8hTgd8knFg9WZ24GiNH3
                Ab0lsYjliBQzR7Q1ut9vMrc7/J8ZMANFMkAjNBTsB3TRLlpup8C9wYgibXZZZqA/BojFkeA/wJ2g
                aNGcIL8ZtT/n+HczYAaKZ4BGaRGg3Q+14qBoeZECzwLvL95yl2gGOjqIvX8BWh5Y1KoDipoj0/mm
                dyH4ldYORjNgBtJkgAZqMTAF5L0VM0X0Kffwq+6eRqXJkLWqCwPEmGJd247fB8oQdYr18jTHel2C
                ynaYgbozQIM1GmjPgldBGaJZ2leCfwOeqV33gCvIPmJJK3Y0MfZakOebEcm+X3mZI8eBxQsy28WY
                ATNgBuIyQAM2FpwK9BrYsuQ1Cr4c7Az8Poe4Lq59bsSM5hHsDq4A6nSWJYrjb4Ala0+6DTQDZqAZ
                DNCgLQs0L6DIPRIobj55hV8uAZ8Aw5vBvq1slwFiYwTYCWg5oC7KZYo6JKeBpdq1w+ebgXYZ8C5Z
                7TLm86MwQAO3HBkdCPYFZQ+LvoQO14EbwM2dnZ3P82lpKAPE5lhM3wpsCz4Oyn6W/wI6fAecTWw+
                zafFDOTOgDsHuVPsAgZigIZ4EY5/DhwEUtioZRZ63AtuBDfpOw2yfrPUlAFicAim6T0D23TjA3zq
                t7LlURQ4HZxHDL5etjIuv1kMuHPQLH8nay0N9FCU2xV8CayfkKLPocvNQJ2Fn9JIT09IN6sSyADx
                tjRJtwbqEGwJRoNU5B4UOQVc6Y5pKi5pnh7uHDTP58lbTMO9GUoeCj4GUorRLvT5NfgZuBPcRePt
                RxAQkboQU2PQ8aPd0Ds6/gWkFFsanboWnEpM/YJPixkolYGUKkepRLjw9BigQV8DrdRJ2BOkuLpA
                nYU/A3UUZoOG/S98t5TMALGjbbV7OgP61P8pymsodSE4zbGTonuaq5M7B831fWUsp6FfDGXVQdgH
                rJe44s+i35zOAt/vp9F/M3GdK60e8aGOo0YCejoDG/FdkwpTlvtQ7nvgUuLjlZQVtW7NZMCdg2b6
                vbJWcyHYAOXVSfgkKHsWeSs8zuSkv4AHwO+7Px/ggjCN75Y2GMD3aq9WAtoee53uT31fFaQwgRA1
                BpSXOXox+C7+v3/AM33QDJTMgDsHJTvAxYcxwIVCqxx2B+ooaKZ51UQXigeBOg09eJiLhic8Qgj+
                1Vr+1cC6oKczsDbfq9AhRM255C7+0yjB5fjXqw7mosb/pMqAOwepesZ6tcwAFxLdRaqTsBdYouWE
                aZ6oZ9DTuvHYvJ9cXF7kt8oLPhuNERoFGNfHp36r+suDnscGzSX4Hj77I58WM1ApBtw5qJS7rOxA
                DHDBGc5xLU/TiMJ2QKMLdRNt2DQNPAF0ARKe6/XZ+/vzXJje5ljuAvcLUsiSQKsCBvp8L8fHgUVB
                3URzB64BlwMte51RNwNtT3MYcOegOb5ulKVcrDRJTTvcqaOgJZFVvxPFhCDR44sXwFvd0AVL33t/
                9v6uY2oXdLEX1OHq67PnNx1XZ2AUaKJopOc6cBm4iQ6BJ582MQpqaLM7BzV0qk2amwE6Cgvzy8eB
                OgrbgBHAYgZCGXiDhNcDdQiup0Og/y1moFYMuHNQK3famMEYoKOgO9ztwW5gC9DUEQVMt7TBwKuc
                ewvQI4Pr6BBoxMBiBmrLgDsHtXWtDRuMAToKGhLfFGg0QdCmSxYz0MPAH/hyI9A7Nu7wHIIeWvzZ
                BAbcOWiCl21jSwzQWRjHiZrQqI6CttjV4whLcxjQhEJtjT27Q0Bn4PHmmG5LzcDcDLhzMDcf/s8M
                zGaAjoIm3G0C1FFQh2EtYKkfA7/HJHUGhDvpEBSyuqN+NNqiujHgzkHdPGp7cmGAzsJYMt4IfBRs
                DNYH6kBYqsOAVmLcC+7shl+cVR3fWdOCGXDnoGDCXVw9GKCzoBUP2spZnQVBHYclgSUdBrTnQ09H
                QJ+/ZmRAHQSLGTADgzDgzsEgBPmwGWiFAToLqkurA3UUNgTa9lePIrwaAhIKEK0e0HbUvwN3Az0i
                eJhPixkwAwEMuHMQQJqTmIFWGKDDoJcBrQL0bgBhne7Plfl03YOEAJlFmkdBz/soej4fpTOgV2hb
                zIAZiMCAG6gIJDoLM9AOA3QaFuH8tUFPZ2E1vq8EVgBaXml5dxfHv0GE3i+hEYCeTsCDdAL88iJH
                iBnImQF3DnIm2NmbgVYZ6H40sRznq6Mwbp5P/ab3EiwA6iDvYISWCk4D871git+e8kgALFjMQEkM
                uHNQEvEu1gy0ywCdB3UM1EFYGvS84EiTIHu+z/upY0WtqJhBWc8DTQIc7PMZznmCi/9MPi1mwAwk
                yIA7Bwk6xSqZgVgM0KEYRV7azEmdBD2ymPez57fev3PafC9nGuhlTa9yoX9ViSxmwAyYATNgBsyA
                GTADZsAMmAEzYAbMgBkwA2bADJgBM2AGzIAZMANmwAyYATNgBsyAGTADZsAMmAEzYAbMgBkwA2bA
                DJgBM2AGzIAZMANmwAyYATNgBsyAGTADZsAMmAEzYAbMgBkwA2bADJgBM2AGzIAZMANmwAyYATNg
                BsyAGTADZsAMmAEzYAbMgBkwA2bADJgBM2AGzIAZMANmwAyYATNgBsyAGTADZsAMmAEzYAbMgBkw
                A2bADJgBM2AGzIAZMANmwAyYATNgBsyAGTADZsAMmAEzYAbMgBkwA2bADJgBM2AGzIAZMANmwAyY
                ATNgBsyAGTADZsAMmAEzYAbMgBkwA2bADJgBM2AGzIAZMANmwAyYATNgBsyAGTADZsAMmAEzYAbM
                gBkwA2bADJgBM2AGzIAZMANmwAyYATNgBsyAGTADZsAMmAEzYAbMgBkwA2bADJgBM9AXA/8PWdS2
                u3nWIdEAAAAASUVORK5CYII=" transform="matrix(0.3333 0 0 0.3333 0 0)">
                </image>
                </svg>
            """,
            "class": "only-dark",
        },
        {
            "name": "TIA",
            "url": "https://warwick.ac.uk/fac/cross_fac/tia/",
            "html": """
                <svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                     viewBox="0 0 178 171.89" style="enable-background:new 0 0 178 171.89;" xml:space="preserve">
                <image style="overflow:visible;" width="518" height="525" xlink:href="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAgYAAAINCAYAAABF+LdjAAABfWlDQ1BJQ0MgUHJvZmlsZQAAKJF9
                kM9LAkEUx7+uhVGGQR06dBjKOqnYBlKXQCVM8CBmkNVlXVcNdF12Nyq6dAi6CgVRl34d6i+oS4eg
                cxAERRDd+geKuoRsb1xDK+gNM+8zb958mfkCgk/StFJbECirpp6KRdhcZp65XiDAhR4aTJINLZxM
                JkDxnX/Gxz0cPN/5udbf83+jK6cYMuDoIJ6UNd0kniYeWjE1zlyvT6dHEW9wLti8wzlr81m9J52K
                El8SM7ko5YifiH1yUS8DAtf3Zlt6Ci1cLi3Ljffwn7gVdXaG8iDNARhIIYYIGOKYQhQhjGKC1hD8
                EBGgHUxl1eSXoxVtTV8qFE0WJicUFlflgI+JQZF6uK+//WrWKofA+DvgrDZr2V3gYgvof2zWvAeA
                ZxM4v9YkXaqXnDSFfB54PQW6M0DvLdC5YOTHRPtH7gjQ/mxZb8OAaxuoVS3r88iyasd0mTy6Um2P
                Glo4eQDS60DiBtjbB0ZI27P4Bel2ZxC/xa5BAAAAeGVYSWZNTQAqAAAACAAFARIAAwAAAAEAAQAA
                ARoABQAAAAEAAABKARsABQAAAAEAAABSASgAAwAAAAEAAgAAh2kABAAAAAEAAABaAAAAAAAAANgA
                AAABAAAA2AAAAAEAAqACAAQAAAABAAACBqADAAQAAAABAAACDQAAAABPkPccAAAACXBIWXMAACE4
                AAAhOAFFljFgAAABWWlUWHRYTUw6Y29tLmFkb2JlLnhtcAAAAAAAPHg6eG1wbWV0YSB4bWxuczp4
                PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iWE1QIENvcmUgNi4wLjAiPgogICA8cmRmOlJERiB4
                bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiPgog
                ICAgICA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIgogICAgICAgICAgICB4bWxuczp0aWZm
                PSJodHRwOi8vbnMuYWRvYmUuY29tL3RpZmYvMS4wLyI+CiAgICAgICAgIDx0aWZmOk9yaWVudGF0
                aW9uPjE8L3RpZmY6T3JpZW50YXRpb24+CiAgICAgIDwvcmRmOkRlc2NyaXB0aW9uPgogICA8L3Jk
                ZjpSREY+CjwveDp4bXBtZXRhPgoZXuEHAABAAElEQVR4AexdCXwURdav6plMwimQSSYgSggBD1y8
                j/VYkoAXXusBnoTggbpen3cSRKOSBBV1PdebAJ7geq83JHiuq+6uKKtAAogYkswEUK4kM931/SuA
                hpBjuqeP6pmqH0Nmuqvee/Wv7q7Xr957RYgsEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQC
                EgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhI
                BCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiAR
                kAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERA
                IiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJ
                gERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQC
                EgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBCQCEgGJgERAIiARkAhIBOITARqf3ZK9kghIBLpD
                4GAyJSkc2OpTk3zJm5tVH/V6kmlE9fF2zOtpYRG1uVeyp8UTbmlOqu/R8jV5ItwdTXleIiARcD8C
                UjFw/xjKHiQeAnTPPc/rl7RVSaWK108pS9U0kkoJ8xOKY/jLKEkljPoxxacCnl748Ak/ud1fvfe/
                hvZcOWjGp6XN30343kgoaWSMhkC0EXxDjOG3QkMepuK4Eoq00MZVGyo2oK4sEgGJgMAI6H0wCNwV
                KZpEID4QyCE53tpA1p4Rog5VCMnETTqUETYUvcskhOJDAvh48HFjiUDoenxW8Q8jZCUldCUjdJWX
                RFYOrP/ppypSxevIIhGQCDiEgFQMHAJesk1sBPjkvyZjyF54w/4DZdpelCjbJn/KJ3+yOz5unfhj
                HVgV1oY1UIBWwuKwCg+olYyypZR6vq2u27SUkPk4L4tEQCJgJQJSMbASXUlbIgAE9vFfMDCs0FGM
                KH+gChtFGBmFiW8fnGpdz5cgRY1AE6Hke9T+lmlksULo4gjxLl7Z8BS3QMgiEZAImISAVAxMAlKS
                kQgAATp84MS9CVOO0BjdnxLtDziED0mT6FiKQAMeZN9iWWIxrAvfeBXvP5fWPgPrgiwSAYmAEQSk
                YmAENdlGIgAEMjMLUpTN2iGKohwN8/dROHQkPgMkOEIgEIIUn1FKPtU05RPat/fX1dUPcadJWSQC
                EoFuEJCKQTcAydMSgR0IZGdMTmMaO0pR2FFY/+aKwMH4yOWAHQCJ/ZcrBV9h3D7lyoLXyz794ec5
                iJ6QRSIgEWiPgFQM2iMif0sEtiOwl//CPhElMlah9ASE/+XAN2CEBCduEMDKA1mKca2ijLyTrG1Z
                uCQ4n4ddyiIRSHgEpGKQ8JeABKAtAkPT80d5FHIicgCcgOPcKpDU9rz8HrcIIC8D+wRRIu9QhbxT
                XTd7Sdz2VHZMItANAlIx6AYgeTq+EcjqP2U3Jbnp2O2KAFcGeKigLBKBn6AovIulh3e8mvfDpaFn
                NkpIJAKJgoBUDBJlpGU/f0Ngr8DEoRpVxiNb4MlYb/4jTnh/Oym/SAR2RSCM6JLPGGNvaR7v/JVr
                n/5x1yryiEQgfhCQikH8jKXsSRcIZA3K35NG6AQoAmej2iFdVJWnJALdIEC/gDXhJeKNzK/++Tkk
                Y5JFIhBfCEjFIL7GU/amDQIjUvN317zKeDzEuTJwOD7yet+GD3e843sdtN3voBlvxC1wtGwN6dMY
                S6aUdrS/Aj8mcfwdx8+Qzvklnxp5+fvQs2u3HZb/SwTcjYC8wd09flL6dghkphVkeDzaWciKd/b2
                kMJ4vcb5ZkSI1aeN2EchBEsIQu9oiDBsXoRNjBRsZsQUFceUkCfiWe9NoU1m7ZLYdlfGSBNLiXjC
                A5Cy2E81vmHT9g2cCDZwwkZOlOE3UVqPQ15s6kR2azdk8fITG0zRj4H/S4xqf6+pn9sQLx2T/Ug8
                BOL1oZl4I5nAPc7OviqZbdx4ukLYxZgUcwEF9h5yfVmP8MiVTGGrtm0yxFZB2VmJ/q3qybRVi+vn
                bnZjD0emje/dpKRkoi+ZGvaHgEKTCeVhKMIGM9HfoehTPzf2q53MfD+HBYTSp3ar870mt6tuh478
                KTwCUjEQfoikgJ0hgPTD+zBNuQTn8/HBW6nrSgtuwB8w2S/GBPktTPlLFeZdpUWaV1ave+5X1/XG
                BIEz+xX0S0oimRpXGBRtr+37SmBvCbIXPm4MHW3AuM7G3g5PrQjNWWYCRJKERMByBKRiYDnEkoGZ
                CAwePL5HcqTHBMooVwh4ngG3lJ8xyS2GEvAtbrrFGqWL+9f7fpBvk9EN38iR431bgj32xpaT2IyK
                jKKKMgoT7ihgOTA6CgLUYuQjLLU8GempvLxqVUWTABJJESQCHSIgFYMOYZEHRUNgeFrBATA3X0Io
                Ox+yib5OzTf1+VTj6XcV+nWy17N4yZqn14mGaTzIM2LQuX5VS/qDQpRDtvmUtO5ZwX0ZRC7rodzM
                JUR7Er4I34ksqJQtMRGQikFijrsres3fElsae52HN8MrILCoIYZ4xvOtgNmnUFw+Jar2aU3w2WpX
                ABynQmb580d4vLR1PwtcO0cjuoIvQwhaEPrItId3a0h5SVqPBB2iBBRLKgYJOOiid3nPPc/r72tO
                ugwz7lW4QEUzFbfgzfQLStmn3CrgS0r6TFoDxL6iuFVBU31HcosCfDn48tNh+Ijlr8DIGliXHmQt
                4ccT1b9E7KsosaSTikFijbfQvW3NSEjotYgLvxCC9hJFWCgoqzChvAMfgXflZjuijIpxObZtjqWN
                USg7EWN7IijtYZya6S156uWnNA/764raOatNpy4JSgSiQEAqBlGAJKtYi8CIjPzDNEZvAJcz8IF/
                meOFJ/lZhLj0dxQPeXdZbcUPjkskBbAMAWynvS/TtBMVSriicAwYibCVdgSyzKceZWZ17ax/W9Z5
                SVgi0AECUjHoABR5yBYEaHZg0ikw796At3H+MHa6rIRF4G2+s95mJbmytvaJLU4LJPnbj8CowMRe
                W4gnD06u2GGTjYNyOMR+KXbhWIkolpkr6irewRnoC7JIBKxFQCoG1uIrqe+CQIkyPLDybDzdbsWp
                vXc5beMByLAKj9l51Ku8JN/KbATeRayyMgoOReKss3GdTIDYTi85LEHSpNur6ypehixSQXDRdeQ2
                UaVi4LYRc6+8dHj6pDPguX87ujDSsW7AyYsodB5l6rzl9XOxGY4sEoGoEKDD0if/kVDtbDw0z0KL
                QVG1sqQS+waWjFur62e/YQl5STThEZCKQcJfAtYDMDyQfzKj9A684xxoPbddOeDVai3e+l6GH8NL
                NQ2zP0MN+ba1K0zySNQIwOo1cOXRTKVnY8mBKwnpUTc1sSIe3l9qGr21JljxrolkJSmJgNwlTV4D
                1iGQnT7pOJg+78A8zHc2tLtwH4GX8IY3u7pu2MeElGCTG1kkAmYjMN4zLNB7NKXaJKib2MmT9DCb
                QxT0kEODTaupm1MZRV1ZRSLQLQLSYtAtRLKCXgSyMyaOxh4GdzriVMjIv7Hp0JMsEn5exoPrHTlZ
                PxYE+D4P3hRk5mQM6brp/rHQMti2Es6802AV+9Rge9lMItCKgFQM5IVgGgI8bTFR2EzY6ceYRjQ6
                Qr/C9vUcUZSnpBNhdIDJWtYi0Oq0yDSuIJwLTr2t5daOOiXvYtnsphX1Fd+2OyN/SgSiQkAqBlHB
                JCt1hcCwwMR0SpRS1OGJiZSu6pp7jn1GqfLkZsU3T4YXmouspGYOAnyb6WalxzlQEKAktGZcNIdw
                91RUKMtPKErLrctqXwh1X13WkAj8joBUDH7HQn7TicD2vQyuQT76W9C0r87mRqtvxQOvAo0fqa6b
                vcQoEdlOImA3AkPT80d5KLkSSsJE8E6xif8G8Lt9cP2qh6tIVcQmnpKNyxGQioHLB9Ap8bMD+afh
                gTMT/LNtkqEBWy0/7EnSHv3h5zmNNvGUbCQCpiPALWxwyr0S1/NfQDzVdAYdE/wBDorXwUGRJ0mS
                RSLQJQJSMegSHnmyPQJ4qO2H1YL7ceGMbX/Oot8/YO+E+9QeZK7cw94ihCVZRxAYPHh8j5SWngWw
                gF0LAYbbIgQj7yheep1M820L2q5lIhUD1w6dvYLvvXt+aiSs3IG47UvB2fr9DBj5CG9VM6vrK94C
                P5l3wN7hltxsRaBEGZa+4jRE8WC/EHqkDazD4PFIpJnevmpDBZYaZJEI7IyAVAx2xkP+6gCB7EAB
                nArZPTg1oIPTZh5S8WB8WVPUmSvWzv3KTMKSlkTADQjgXjsCyvcNUIVPh7xWO/IGEVp5XXXDnGfd
                gI2U0T4EpGJgH9au44QERcPwFvO4DeGHGni85PV4bl9a+8xS1wElBZYImIxAdsakkUQjJVhmOBOk
                rX1OI7xRpd7LVq59+keTuyHJuRQBay84l4IixR7vGZ7R6zpEG9wOLKzM5MbgEPUqEhLdKiMM5FUn
                EdgVAZ4bhCnsDpw5Zdezph7ZTAmburw+6yGZJdRUXF1JTCoGrhw264RufRBR9jTeUQ6yjksr5beI
                xm6tDs75j8V8JHmJgOsRGJGRf5hG4OPD2PHWdoZ+wYh6cU393O+s5SOpi4yAVAxEHh0bZcvMLEjx
                boXpkrDrwdZrIev3KdFulTsbWoiwJB23CAxLn3QUlvfuRAdzLexkGEt7d9E+fadXVz/UbCEfSVpQ
                BKRiIOjA2ClWdkZBDt5EngTPbMv4IspA8dBblq2twIZGskgEJAKxIDAsIz+XMjLd4iiG77H3wiVy
                74VYRsqdbaVi4M5xM0XqQYOm9OyhNd+LBwwPQbTqWlgBX4UbahrmvGqK0JKIREAi8BsCcFKcAKX+
                bty+Q347aO4X6AbkIbUHvVnmETEXWJGpWTUZiNxnKRsQyB40+SAWUZ+nlO5lESAbEXZVSnrv9ldp
                jrQIYUlWIgAE+DJg0hZyIxx5b8bPXhaBskRl7LyVDXMWW0RfkhUIAakYCDQY9ohSomRnrLiRMMrX
                KZMs4IkXDFIR0WjxqmBFnQX0hSXJSkqUYM/R6SRMMpCcqU9ziu+rPa47cquwAkvB4gqBEan5u2te
                OgOdOh8fK57t3N+gqLp+9l/xl9/nssQpAlZcPHEKlfu7lb37+YNJxDsHPcm1qDefMoVcU7N29tcW
                0ReKLCuZ5wumpB2GnPe5eEzm4Fn5RwjYJryTboGZ9wNF0R5NLRrzvlDCS2HiFoHWJEmEPYAOHmZJ
                Jyl9L6KSgkRT/C3BUlCiUjEQdGDMFis7I/8sWAmeAN3+ZtMGvZ+wn8FNNfUVL1pAWyiSDeWV2Qoh
                Z2Lh9Vi8lEERYD2jEJCv096aXpwLZzFZJAK2IECz0wsuwHIetyAMsoBjCDQvgvXgDQtoS5IOIyAV
                A4cHwGr2fD/4JtrzIYQ4FVjAC9u4splNSVvvWLNmftyazBvuXDSceNTxSMQ0HhgeYBhHRh5Lm5p7
                ueH2sqFEQCcCowITe22hHp7/4Bo09ehs3m11vBA8vtXju6629okt3VaWFVyDgFQMXDNU+gVtTYrC
                6PNoOUx/625bfK0wz0XLGp75ptuaLqzQRhmYAPH3N6kLyPSoHJxeNFomdTIJUEkmOgSyBk48RNHo
                U7BymXUtt2X8A5KVnSeTlbWFxN3fpWLg7vHrVHrEOfP93u9DBbMdDLfALn5rTcMWOCDNx6ZH8VOC
                ZR+OYNQzHuGb3DJgxQMUrgj0/fTiHIuz18XPmNjRk4aSyt7MowWIh2YozLsibeqf1trB124eOSTH
                uyYw5EbwvRWfFJP5N+PavgrLiTwfiiwuR0AqBi4fwPbit+7xHu7JfQkuaH/OhN8feIh26dL6uStN
                oCUEid+VAQrLABtlh1C+lubU3UpOWGcHL8ljVwRqS97s6fX1ysHb8zg8AMehxtB2tb6ABjff7+/z
                IL30EL5FcVyVrLSC4YpCMIGz0RZ07CnSp++VMkTZAmRtJCkVAxvBtprViMCFWRqJvGKBuXAdYqSv
                q6mbM9vqPthB/9eyD1NbiHIRIwrCuuxRBtr2S1HYfqmFeUvaHpPfrUWgvvzDLA/xjIMT6DhM+rng
                Fs0bc2UyUcf3LR7baK10jlCnwwIFF2PjJCRHIv3MlACTypeqh521onbOajPpSlr2ISAVA/uwtpQT
                lg5OxNLBc2BiatQBLpAXNaJdg01VGiztgA3EG8oXHagw9SqYPM8Fu2gmBkukooyN9U/NW2AJcUm0
                FQEeStqY5D8G4bMnccsAlAGjibxWJlHvwf2Kjlkfj9Du479gYItXeRjPjjNM7l9II+ScFfWz5XVu
                MrB2kJOKgR0oW8sDYUmTpiGdyW1gg0g608o6rLVPWd4w+++mUXSAECup9AaTyZnoy1Vgf5QDIuzC
                UmPq/oGpY2UGuV2Qie0AH+t1yVoeI56zkYabT3SmvAnDp+au9Km5hbFJJ3br4YFJ58Ka8jdIuZuJ
                kqoIl5xaXTfnLhNpSlI2ICAVAxtAtopFZr+Cft5kNhf0TzaXB1uoREj+ssY5P5tL1z5q9aUfBhSq
                XApdCR9mRRy3oc7ghlvlL84daqixbLQLAmzePE+o2n80cnScA+X4TFRI26VS7AeaqKZl+28Z49r7
                IRoIhg68aIiiRuYitPmYaOpHWwfLkK94I96CpaFnNkbbRtZzFgErt9d1tmdxzj0rUPAHhTD4E5i6
                I2ILHgrTltdlzSSkBJZA95VQWeXejJKpmCi4M6EPH6E6AWleE0ogFwoDawBdV1p1OPOQc0LVPLcE
                FD9rX3FSiEc5HVA97EK4ohZ55dqnfyRkfO7wQM8iXKe3oaEp8wNfplA96r7DB048Y/naud9HLZCs
                6BgC1t5OjnUrvhlnZRSMUxh7Cb3sbWJPf8DD7/zq2ln/NpGmbaS4c5nClBKsJ58HpqYncjGpIzVY
                rz40XterTcKoUzKwAo1SqJc7jJ6NSkM6rWjBCSxFlfqn5t5iAWkhSW7PgcJ9lrJNFPAXvG2cKf0O
                TETUIlJSMbAIWKvIwp/gcrwdPQT6pk1+bs5e1jh90R6aok6DQjAZmJjyhmPR2G1UiHpEavHY/1lE
                Py7J8hwDNJmcAwvQJVAIDnOwk0+nFede7CB/21nzrKnNSs8HwZjfW2aVMKySly6vmz3LLIKSjvkI
                iPwgNb+37qZIh2dMuhuOUDeY2I3WfOdISvKGiTRtIdVwd2WGEmHFiJiYAqUg2RamRplQ8o5KlZvT
                CnOlUhAFhnypIFRadTB2qLwEzmvnYTUIljEYt50tcRmV0BWkS4LzN+H8hdkZBe8gpfLj+G5GxFMS
                nmHPDAtMyqqpnw2FXhYREZAWAxFHpZ1MfL917xY4GVJyVrtTxn8y8lGSpp7zfejZtcaJ2N+S5yBo
                xiRLmHIFJotoNjCyX8gdHBn5BHEi09KKcqt2HJJ/O0dg3YwPdtO0pPMYYbAOkAM7r2n/GYQ9HpNe
                mPuJ/ZzF4Lh9Z9b5kOYIEyV6Ltm/5cIlS+a3mEhTkjIBAakYmACilSSyMyanEaa9Dh58S1+zyl8H
                1/94YxWpwiZI7igrSypTeicTKATkekjcR2SpedpjyDcdqY8/FllOEWRrdSQsX3QEI9olSDgF3wEh
                lb2gPzs4kE6YoIqAmVMyjBw53tfU2PMB+FtcZp4MdFFLcsvpq1c/n3AWGfMwNJ+SVAzMx9Q0iln+
                /BGKh74NgsNMIroFA37x8vrZL5hEzxYywdKqXJiUnwCzbFsYGmZCF2L9tNBflPOlYRIJ0vCXkncH
                NPt8F2DHSiwFkZEid5sq7M/+wjyunMsCBIZnFBRAoeM5D8xKEvYDUq2Pi6dU626/UKRiIOgIjhhY
                cIymMR7aNsAkEas1Qs9YUV/xrUn0LCezofzj/hGizsRD6ELLmcXGYAnM3zelF+dxJU6WLhAI3bVo
                H6KqN8KqwqNHxPYNgYAIfb0lvSi3tIsuJeSp7EGTD2Kq9ndMIJkmAdBAiXbq8vq5X5hET5KJAQGp
                GMQAnlVNh6dPOhMPJB4qZNaD8y2tJfmCFeuf+MUqmc2m21C6cAKllHtEB8ymbSK9tfD7uNU/LDgr
                0c3M3WHaOL3yCA3WFOB1Wnd1BTm/BgrpbYhEmIXr0HHPR0Ew2UmMkYMvGtAcjnDr43E7nTD+Yyv2
                bpiwvH7OW8ZJyJZmICAVAzNQNJHGsPRJ+TBHPwOSZoQjakguUrK8oWI66Lni4bYt/FB7FPKebCKs
                ZpOCtza7R00K35tx4/GbzSYeL/S4/0CwvBJ7eMBZlLI/uaRfP+FOeaCpR/Kje1x35FaXyOygmCXK
                8MDKO/BwKYYQZswnYVC5oLpu9jwHO5XwrM0YyIQH0SwAtucoeAT0zBiX9Uyj59UEK941Sz4r6bCS
                EqUxefRfEMpUBj6iOhdy57OnmJeUpN+UW2clHm6mzR7/KqkxtPFsXMU3YcL4gxv6Ajk/wEYjj2Lb
                zbdoSa5rnHJFwTY7MOlUyDIHHzP2WtDwcnSxzHXg3OiaMQE5J30ccYal4AbcDPeY1KUaTWXjVoTm
                LDOJnqVkGss+3FclnqdwMZoZeWG2zJXUo1zhv3n092YTjhd6tSVv9vQm9bkIlnceOTLEBf3iS2uz
                iMoeS5uWt9QF8gotIiKo9iVMhZ8NNWPsYW9iV2Or94eF7nScCicVAwEGNjtj0u0wX95qkiifK56W
                U5fVvsCTFwlfguVV5yJ5ytMQtIegwm7kb77+wpzH5VpzxyO0LbeE50pYe67CAyW141pCHf0Gk9cj
                alLz83IpyNxxyUwryPAq7E1QPcQUypQVyt0ZTUFSFxGpGOiCy/zKUApmbo/NN4P4/EgPmr9qVUWT
                GcSspMGXDoJJo8tgJbnZSj6x0Obm5SRNu6T/LWN+jIVOvLZFQqI9Nea9Dq92PF2x2Mmm+CBQ8g9G
                tbvTbs77WCp51l2VgwZN6dlTbeZOiXx5IeaCSaoUIdYJs09FzICZQEAqBiaAaJAEHZYx6VGzkoXA
                0euemoY5fJLFfCZ2aSx5u6+W3ON5SHqSmJLSX+Esdz0yFj4lpnzOStVQXol8EnQaZUhXLPb+FBCP
                Yd8e5UWNRe4KTB272FnkEol7iTIssPJ+TDBXm9Trv1bXz77WJFqSTDcISMWgG4CsOT3ek53R8xlM
                jPkm0FcReXAlIg8eM4GW5SQa7lw0nHo0vjfD3pYzM8bgXUVTpqTeMvonY83jtxVPStTiS+b57a/A
                J0nwnjZDKXhGo9rMQNHYFYLLGrfiDQ/kX4OcFfehg/DtjLWwJ6vrs5B10Z1bwsfaezvbS8XATrRb
                ebWG9zyH1/pzTGC9CQ46E+Cg844JtCwnUV+68HiF0hfBqJ/lzPQz2IA18mvTp+ZW6G8a3y2WP/h2
                cr9NKVAGKFcKRBy7NgNAf2VMewQplh+AhaC+zQn51SEEhqUX/BkOqTwvS8zLTXgJmo2XoMmgJbxl
                1CG4TWErFQNTYIyaCEVYD3e04xd2rOVnqtGTlwcr/hsrITvaB0srr8ca713gZUZ+BrNFfot4wpem
                3XxcrdmE3UxvWx6CqjORthjjxrJE7gtmiUa8ks5UlMjfBhQe65pEXiJjaqZsWRkFhyqs1SkxEDNd
                Rh+tbqjgVitZLEJAKgYWAdsRWSgFD+H4lR2d03msRlW8Y1auffpHne1sr87fNnfb3PMJrEebsWxi
                tvzrMeld4y/OmWs2YbfT45kKmYfeC+XgSMH7wqNG7lWat96fWjLuV8FlTWjxkKdlGHx3FsDyNCRW
                ILb7VN0UKx3ZvmMEpGLQMS6mH80OFMzAW5cZHvj/S1LVsW7YLrk1jI14/gEwDzcd0FgJUvIm85Ap
                MlHRzkDW3bloqMejlePo2TufEe5XMxSCh8NJZMagG3JdEZorHIIOCDRs0OQ9qKpBOSDDY2bPyG3V
                DbPviJmOJLALAlIx2AUS8w8MD0y6BabOO2OmTMl/FKXlODfkKOAbIIVZZCH6fEDM/TaXgIp87MX+
                4ry7zSXrbmrrSyr7RXxkKt7m4EXOfAL3RoV8z2DX0TtSb85dI7CcUrROENie6+ADnN6vkypRH4Zf
                0A01DbPvjbqBrBgVAlIxiAom45VgKfg/PMjuN07ht5afYyOkE92wERLi23dTNe+HkNycJCe/QRDj
                F0ZCVNHO9heN4QqLLECApy8OhjZdBhPvbXgYiJ6cCI6rKjY2GuuKjJ7yAuscgb13z0+NROh7qHFw
                57WiOwOHxMvdEpUVXY+cryUVAwvHYFig4BK8nT4ROwu2sCdhpy6unyv8hj3Buz7pw7Tw+8jPcETs
                /TaVwpcIQzxThiFuw5Q7FjbeVXkq0xRYTtgIU5E2nRh9G/JORcSIKxxtTe9+nBLMHnB+X5Lk5VuV
                HxVjF7HrOZ0Eh0TpKxQjkDuaS8VgBxIm/4WjzflYA50DsnCWNl6wBPEPtQc9yw3ZDOvuea+XJ+zj
                bwGx3ujGAeuoJSNPbeiz9crhV49DbLsswfKFBxNNuU/4HQ8Z+QR+IEXphbmfyFGLTwR4lsQeavPr
                mIjGxthDns9lAiwHr8RIRzYHAlIxsOAywPLBKXgL4xeoN0by83erTz7/a/JEOEY6ljfnKY5DyaPf
                ECybIXdQu1JmMNw2/K2KWyTpTrxdYXlL6Hv/Z0bptWmFo1+WqYstv3UdZ5CdfVUy2fjrfAiC52ZM
                pQXPn1PgkPh+TFRkY6EfDq4cnqyBEw+ByXoRhI8xmQd7vrp+K0L85sPZSvzSUFZZDi2zUCBJNyDj
                2qnpxTkfCySTY6KEyivHwlGLL2sNdUyI7hmHIeN9JEymp5fkbuq+uqwRLwjkkBzvTxl7voS3/jNi
                7NOvGqFHr6iv+DZGOgndXFoMTBz+oQMvGuLRIv8EyYxYyGJQXt29/scJVaTKFfvCb98h8flY+mxu
                W1qrKvSEjMLRCf9w4NEhEaLOxBr9heZibC41LJl9QFV2ldz+2Fxc3URt5MjxvuZgz9fwunpijHL/
                5FE9RywNPSMTlhkEUioGBoFr3yyr/5TdFF/zZzi+b/tzun5T+l5y6uZTlyyZ36KrnUOVW9erGeVv
                5T0cEqEdW7osQtnxA4tyV7U7kXA/Q2ULz4DV5BF0PCZF1WLgftIouxZ+BK/IZQOLkXYB+cGDx/dI
                CffkDok5MYmL0O5kdcuflgTnS8uTASClYmAAtPZNDiZTkn4JNL2LZdu89ud0/WbkoybflhPWrJm/
                VVc7hypjzTodzoZfgf0eDonQnu2XYR8Zl+gJbxrursxQwuRhRsmZ7QES6DeWDdhMzRcuzbjxeOGj
                bQTCLe5FGZk2vnez0pPnOTgils4iIuzt5fVbT3XLcmwsfTW7bUwe82YL41Z6G9KbsXYbo1JAyL88
                mudktygFfKygFDyNP0IoBdwUzVpIXsIrBeVV42mE/E9kpQBvI4hcUfdLn5pXLJUCtz71rJObv+VH
                milfTogpPBXWsnHYxfYh6ySNX8rSYhDj2CIs8Vasid0eCxkMwuLm5HDO6tXPr4+Fjp1tG0orCygl
                s+zk2Tkv9oI/te8keukhwkdvdN6H2M7wiANvJPlBsX0J6GpcM/+XWjj6NblsENt4J0Lr7IzJaYRp
                i9DXfWLpLxxab0R2xJmx0Ei0tlIxiGHEs9PzLyCUxpRUAw/ypTyevKZ+bkMMotjaFIlxBmsq+Q5M
                d7OVcQfMcAG/nNqy6Gxakrh7tAdLFxxEqOcFcRMV0RZsonVPS3hT2aCSU7Z0MIzykESgQwT28l84
                SPWo3Icpq8MK0R2E8YBNqK6b83J01WUtqRgYvAayMyaOJkzh8bI+gyR4s5VKhB2zrHHOzzHQsL1p
                qKzyXZjuj7ed8a4MF23ovfX4RE1c1Jo7wvcn5CSg2KCLJO0KjxBH/qso7ILUwrwlQkgjhXAdAntn
                FGRGNPYxLLODYxC+iTCWV90w5/MYaCRMU6kYGBjq1guVMe50l2qg+Y4mQSTj+COScdTsOOCGv8Gy
                qkvwZsrj4R0tuHC/VZTIMQMKj/3FUUEcYt7qYBghFYIoaB2gwDSYcO9KC4dKaMkEV0TYdNAJeUgQ
                BEYMKthbUxmP+uofg0gNeBE7yG0vYjH013BTqRjohC4zsyDF24QLlJEDdTZtW70Jb3m51fUVPOeB
                a8r2bZSrIXA/Z4XGWrWmHum/ZYyrLC1mYdZQWnUi1uoroKClm0XTXDp0hUa0/EBx3qfm0pXUEhkB
                k6y0/0z2bxntlnBwp8ZbRiXoRD5pC3ksRqWAr3dNdJtSwGFqpspU/HFaKVhHPfSERFQK2Lx5nobS
                hWWUMsR5C6oUYF8K4vEeIJUCnQ8WWb1bBKrr5i7CcsBF3VbsusIRTY09H+i6ijwrLQY6rgFEIFyO
                da5HdTTZpSq8sW9aXldxzy4nBD+wtrwy08voUkxIsfhUxNrLrZqmjQ3cMoabFBOqtG5lzbzPQSk9
                SdCOB3FtXJxWnPeGoPJJseIEAVMiwSidjOdwRZxAYno3pMUgSkixMdIRUAr+GmX1jqtR8jc3KgW8
                M1AKSh1WClTwPycRlYJg2YcjVM37T3GVAvqGmtSyn1QKOr7t5VFzEYBf1h3wX6mIhSqiwf6WPWjy
                QbHQiOe2UjGIYnSHpl8cwKTEQ10Mvy3zLFzVdVuuioKdcFVaw+EIO9dZwdgdiTjxNJRXnoBUUv8C
                9ns7i3+H3DfB+fFif9HoPyNRkWvCbTvsiTzoKgT6NSRPwTN5YQxCpzBV+/vIwRcNiIFG3DaVSwnd
                DC3f9WtNIPNDXISju6na+WmX5+12OjyRRyCkpvY5OJESGOGNhobKFt1AqIZQRCqiAv+pRtX8QNHY
                FZ1f+PKM2xBY/uDbyf039zgGb+THwxlqFO49vs8GPmw1lMDXPUR9JbV47P9E6Nf2/Wm4g+vIGOR5
                v7p+KLIsJm4elI6wk4pBR6i0OZYdmHQffl7b5pC+r4ysQarjw92601fjjIUjNY3yZEZOFZVo5Ii0
                W3J5eGhClJ/u+6xHSlPzk+js+QJ2OAI/mVtThzXcTSdMwPKOLG5HoP7OBcOo4hmHSBdYp0gOlICe
                XfUJCsK0tKKcUhGyV5qzoy0tgzM4d6yWZTsCUjHo4lIYFsg/mxL6YhdVuju1RWGeI5c1PPNNdxVF
                PR8srfwbfCsuc1C+mWnFuTc6yN9W1sHSjwYSqr4Jpgfbyjg6Zj8wqpyXXjT6P9FVl7VERSB016J9
                NFU7ExPAWZBxf71yot381JbgBSLkqBiRkX+YxuhH6EOy3n5sr88NdGfUNFS8ZrB93DWTikEnQwrP
                12GYEP+L0707qdLtYSgV5y+vr3i+24qCVlhfUtkv4iNrIF4vh0SsbkpJHrXHdUe6YrfJWDHib26K
                R/kAdIbGSsuC9m8pLVvPTy0Z96sFtCVJixHgM1/9XR/t59EYVwTwYfvGyhJhs1f4i/JiitKKVYYd
                7bMD+RdjyY1b2YyWDZqH7b+ids5qowTiqZ1UDDoYze1+BZ/g5jm8g9NRHYK57cGa+tnXRFVZ0ErB
                0qprkXOBL6U4UbDESfLSinKrnGBuN8+6GYv+4NE0nmKbr+kKVujd/uyGYrl0INiwdCNOq5/KjMqD
                mEbOpAo9C1Etw7tpovd0PXY0zU4vyd2kt6EV9bHsyxUDKAgGC7a9r24Ymiv9DRCFZhDCuG72U2DI
                bYgiMKwUYK3uk93qkm9wM0itefjxRuBYHxh9Mq04p8ox/jYybiyr+iPyMyBpkdPJo9p3mm9+pF3i
                n5o7p/0Z+VtMBPh9u847+jBNIWc2llfBMkAz8TzCO44l8gYUH50Iyn+zhLpeon36Xkk3/ro/unqo
                3qat9Sn5U3ZgRWF1PSkz1D6OGilx1BdTupKVln807qMio8RwUa4Nq3T81+SJsFEaIrRbl3zMWMgx
                zCFZflbCWxLCr6CxfMFxGiGIehFOKWjAwyHHPzVPKgUO3QR62HKfAexjcm/IN/pHKAV8o6Ab8CzK
                1EPDSF1GtaFG2lnRprr6oWbNo5wJ2ki2ZbTQkqyMAmOKhVGWAraTFoM2g9Ia/qI0PYtDnjaH9XwN
                QzMfvypYUaenkYh14cyDtw1nCnwzihJhLbuhvGo8dhp6Dq9zSc4g3SnXbzxK+FRsULW60xryhOMI
                1Ja82dPn6z0eCsAliMk/yhGBmFhLXzW1s34aFph8DiWty3JGnuNJCu7JUYGJBy6un7vZEUwFYCot
                Bm0GQfE1wZGGDmlzSNdXRtl1NQ2zeVytqws3RxKinOZQJ9aktrAXHOJtG1u83V1CGXsJDIVSChC/
                /irWjY+WSoFtl4JuRvUzFu7fUFb5cJKvdy2UggoQcEYpaJVcMRoJoLvf0TaoqZ+1EMsnxdHW76De
                8C1ESej9FKRisP2qQBTC+VAKzuvgIon20LM1dXMejrayyPWCKaOPxFtsuiMyMvogLcmNOMLbJqbB
                skr4n7RuXc1Xf8UpjN2ZFl50lijOZOIA47wkDSWVvYPllRdDofxC0eh/ceFw/5/dnJaMMe09p2Xo
                iP/yutl3w3rLs9UaLRcNTy84w2hjt7eTSwkYwb0zCjIjjBkOu8FNunhr0hak6IyPQjV6ulXeSt0g
                tNHjCT/RTR1Xnw6VVV3OCLtHsE404SE6OW1qXiw5OwTrkvvFaY0qKK06mCiMP1vOxRghdBo2AnEK
                03zht8QRZ2dJktmWyc2050gc3WfnM9H9ggX4yRGp+V8sa5zzc3Qt4qeWVAzIeA+UAu5X0NfgsG4l
                inbOmjXz4ynW/s8GsYipGXwLZsGE/UtMRARujGRR50ApeEQwEdcig91p/uKcLwWTK2HF4Ttpasxz
                fqi86hKikANgyRQUC/aUyHtkLAnO3zQi/cJzkbqb7zXiMwDiAM1L5qDdWHyE0sgM9EVXk4RfSsgO
                9OLe78bX6Bi5fvnaud/rQl3gyutKK/fDPZDlhIjIfTzPCb528GwoWzgOz/e54CXSU/4rqmmH+ouk
                UmDHNdAVj9YERNMXHBkqr5yFnTTXIh8RVyChFIhZoEx+tqF3k/CbwrVmnWXMcJQZbtc87Kx7jZij
                YJ1UIj2krOtlJ5Sz/PkjFA/l6YpTOqnS3eE3q+tnn9pdJTedxzrmZdCNnYhLrve3LBpES+JvM5OG
                GZVHU428j+ugh0DXwovIKnlhomSVFAj3nUT5peTdAc1JyRPhLHcJTnCzt/AFr84fIANOfvpNuW6J
                vqJIfsR9IY41CO5mL6X7/VBXscpge9c1S+SlBKoorSk0jSoFddj07iLXjXg3AkNTPNwRmxkjb8al
                UlBaeQCUAr4OK4xSgCWbstSi0beIsAlON5dj3J5uKF90IELqrmtBeDPuOeE8+zsB/isoMEXIRsrz
                bripsCRVnRT2eL6F0KkGBO8Fb+jH0O4EA21d2SRhlxKGBSZdAqPunwyOGpaKtYLqullBg+2FbQYT
                5mHOCMdec4avdVwb7lw0HJMvf1Nx3Ht8Ry8ZJbfAn2CqVAp2IGLf31ZnwvLKsQg1fB8ZJf8Ny9wF
                4C66UrAZcj6FJafDseR0mN99SkHrAH8fepYvz1xseLQZOz47vYBneUyIkpBLCfv4LxgI7ZH7BRh6
                YOON2vX7IHR0dQfv+qQPUVs2YF3NboUxsqmF9BlaktvUkVxuPBaavmB3piifQvYhwsjPyA1pU3Pv
                FUaeBBGElVR6g8nYr4DRm+C/c5A7uk3/DTkfIx7vi2k3H73RHTJ3LyU2W0LUE+XLNkZKIx6N+8Tj
                C2F7MBJyKSHi8XDHHkNKAdp9S/v0vYnUt4fS/b+p1nwoI4rdSgH3910eT0rBT/d91oM1Nb+JK0IY
                pYAyciX2PBAtIsL9N00XPeDXQY/mpskhRq9HMis49DqySNeFhLuc4gK+zhTt/rSb8z6OR6vSFk/K
                //WINP0Jfdtrl953fyCVMPWvqIacN/Fd7J8EHMZzePqkM3H1I07fUGnSsJUyz8ltqLXojZjiyDIC
                1i2/Ex2aaOXj5uLk5ha+HnlgtG0srsd3qeQbIUmlwGKgd5DnDoXB8qppKU3NP26LLnAmymeHPFH8
                3QS/kwc1VRueVpx7enrhmI/iUSngONTWPrGFeCif2MNR4NJBFXoe9lIY18GJuDqUUBaDzH4F/TTK
                Hoph/aR4RX0Fd2CJywKFCaGK9hc4bMSNYtA4o/JymIzz7UexI45Mo0QpwNowD5OUxWIEGqcv2oN5
                tOvhUHgxYayXxexMIE9XQ84HvWHydP+SHCwhJkapWTv7a0Qp3IbeGtpFEXsp/G1k2viRPE9CvCKW
                UIqBN7k149xAg4P5z+r6oQ8YbOuOZozuQWBztrtQqsSFslWPOHS8IYpyjajY9+C8tKk5cZsbwu7r
                tDN+DXdXZigRVqwRdilWC4wk0umMtCXH4YD6T6Kx+9PC5JV4Tz/eGYCD63+8Z03GkPEYLyOWvT1b
                lB5cqbi6M/puP54wikF2RkEOtGOj4YVhmGMvJiT+Yux3uoAp22On3zb9UKm2wiZWlrEJln40kFCV
                52YX4p6CUnBx+tQ8qRRYNuKEtOYg8CXfSCP0aqjTPQX3IVDhdPd3BQpB6i25/7QQFleQriJVkWxl
                8sVE1f4FgT16hcb63BVIfPR8dX1FXGKZED4GOSTHC6XgYQy+oVUE5MyeUV03e4nei8dN9fnaOODZ
                3QmZFU1zdTppVjLPB6VgPrAzao0yF3Z4v6dPza0wl6iktgMBHr0TLFt4a4svZSVumkIoBFAKhC0q
                JWyWqirwH8g5WyoFv49Tde2sf8O/6f7fj+j6pmBOgd8O34k2/ooQbzdWw/pTxp6XwUJuNKvY9ymp
                W6eTOquldJZ+8J6qAB5yjphBPQpzdZhio88/E6N3lLMj+Bv3mVg+uOe3X/KLaQjwKIOUrc1/YWq4
                CM56qYJbCPia4PNMVW5PmzZ6uWkgxBmhrd4tt6aEe56Obg3T3TVKDsoOrJxcXU+e1t1W8AZxqe20
                xXzk4IsGwBns9rbHdHzHizS5ZMmS+S062riyqqLCv8Ch0uLRXKsYhEorL4BZUYic8ZgJZiOt9M0O
                DWPcsuUWoRB2xUxpaqmGzXEmFGgoBeIWyDdfIep+iDC4IF0qBV0OFN/8TiPk0i4rdX2yNHvA+UY3
                4OuasoNn495i0ByOcKVggCGMKXmspn42T1IT/4VpUAzwSHGgeLRerlxKWD99wZAIdWRfiY5G6a20
                1D6X0Evj3A+mo55bdIwnJmr0kfMbYS9G5EymRWxMJEvfwJvMbUhi9V8TicY9qRX1sxcMS59UgWWF
                AgOdDTCvdyraxZVCHtcWg+yMyftiwC4zMNjcSrjGE/HE1WB3hQMSGzn1FsT8W8OuUwy4T0ZYUZ4E
                pr27wtWmc5+GWzadTS89JGwTv4RgA6UgG2+T98ISkyl4h99F3oHD4ENwGnxLpFJgYLDCKeHr0MxQ
                2jooFP83LO2CbANshW0S14oB9jPgjiXGrCKU/mVp6JmNwo6cyYIxojm1yU+DG0OmkMDmQthXjO7W
                ZuLo0f8lUe8pg0pO2WIiUUkKCPiLc39gChsDxQBGAyFLJUIkj8aSwYly6+zYxmf16ufXw2BqNPzQ
                RxUv9zOKmxK3igFCSU7BKB1ncKTmIwzlTYNtXdlMIdQpz+o1bgOs8a7KwXA+u08AuTcgYua0fkXH
                rBdAllhFoHvueV7/7IxJI0dk5B82bNDkPQ4mU5JiJRpr+0Bh3jeMqXmwIIZipWVi+08Jo3lQCPIC
                xXmJsdRpInidkULk2Tyce6uz810fZ6dlBSaN6bqOe84ae5sWvH8jR473NYfYvQbF3Mo8yvUG27q2
                GRzoYDHgjsw2FyzZ2MwxJnZ8CSFUvuhxYOWwwxHTNEbOwcRQHVOHbG6c1X/Kbh5f8zhcaTz99iCY
                YQfBwXcQ/06aSQoXB2nHEf2pkV8CzSSbTGoA1msxEdbicC2+r1CY9x/LGp5ZjKq2XLCBqWMX181Y
                lOdRtYWQwc9ldKh8haDiaWmFOe/Fa8pih3D9jS3T1Gup4uEvlLojtPCWjX0Uxh8A30/kjHB3iUvF
                oCnY82o8cIYbGhpK766pnfWTobaubuRMLDYedK5SDBrLKicSSsc5PtRMKQxMzXnPcTmiECB79/MH
                E9VzKib30whpzsVs/pslAEpBdyUdTrHpmJD331aREo2qpdgl70f4xbyG+/y1wXWrPuEJa7ojFMv5
                jMLR34bKFp4Mnh9BH9E9acTCG22/Ac9bseXxm60KQVGM1GTzThGoCT5bPSw9/wHgfGOnlTo/sV92
                Ro9Lq+vIo51XcceZuFtKgMNhGh4W0wzBj7fXLYrvbkNtXd6IUTx8HSi4AF2jGPDshsBJhJTHL/qL
                Rwu9psktA9kZ+TcPD0z6F4l4f4JSwDdx4m9ivykFsV1udAgS91yDJDOVawJD6rEEMTsrLf/o2Gh2
                3dpfnPcFeE7pupaZZ2kt8q9MRAjqQWnFeW9IK4GZ2HZOy6t578RZQ46IuM7v4EtinVN3x5m4Uwzg
                cFgM6A2ZeXHj3dy6+5Y7xs5UKbEt7ChTCUZLzCVLCXwJAfZt/ibQL9quWVTvv4hAuEjUSSI7+6rk
                4YH8axRfcw0ekjNgEDjUIhzakh2ARYV8RaEfY3OcN7ZHI7U9b9p3OCTOxn4i3KnZwkJbcLGVsRa2
                F3bFfJaWyBBUC8HehfR2p3MegmikpPqafTcYaShSG2cC1y1CYERq/u6al/I119a1Sn1s2GfV9XOO
                0tcmPmrzeO2Qj2xCb5Lt7hGcHo9MLc753G6+evmFyir/jEnuVb3tTK6/AXkTDhxYlLvKZLomkCtR
                hgdWng2MSkFsqAkEYyGBKEMyCxsb3bascc7PsRDqqC2/X4I+8rZFUSmvYank+kDR2BUd8ZbH7EKg
                RMnOWPkVFM4DDXDcpHhahi6rfUEkh1Vd3Ygri4HmUbi1wIBSADuDArNkgpZ1KWwvdN12pQA8I1tS
                fMLHXfOJAPaCGU5fHpDhMhGVgmEZ+blIDfsvKAXPAyOnlQI+TPy5dhFeEpbDglBmdmY6Hl6bQtRz
                wcOYuZlLuEuh/8MS6LGINDhdKgW7gOPAgRJNodTonNCbaT5X58CJG8Uga1D+njDxXWzkCkLK5Dkr
                1s79ykjbeGijMcWZZQRCvtvjuiOFT24USkZGNEa48uRcoeTZ9KLcl5wToCPO/K1q0u24fxbi7MEd
                1XD4GCJtSBFJ8n6RlVYw3ExZ+haPbYS/wV9MoLkBWRWv8af2PgDOhR+aQE+SMAmBZWsrPgapeUbI
                wan2isy0ggwjbUVoEzeKAXL9c4dDnwFQN3m1SEL7+TKNWOq01fmYsC87PyfGmdqSN3tCKShxVhq6
                2kMjVzorw87cRwUm9oKpdR6wuXXnM0L+2ltR2BcjAvljzZQOzoivwDnw7wZpwsBCHo8Qz4j04rwH
                ZdZKgyha3ExVvDeBhZG9XHokKa3+bhZLaA35uFAMstMnDQM8BQYhKvs+9Oxag21d34w71VHKTnem
                I4rwioEvufdVwGZ3Z/Bp5cqYok4cUHjsLw7KsBProQMvGrKFUCTZIWfudELsH/2RH+FdLHtwBcs0
                3yotiXB66/V1nS7GTXc4lg0uG1j8p6C+trK2nQisXPv0j0giZmi3UuSGmcITddkpr1m84kIxIAq7
                DYB4DYBSG+lB7zfQLm6aNJQu/CM6M9CJDmmK9i8n+EbLc0P5x/1hEiyMtr4V9fBaeVd64ZiPrKBt
                hCY2mznKo0Wg0NH9jbR3uI0Hyx4PIYTyMZ4EzQxZ0m/KrYOWcW2UtJqxbDAVywaHyBTGUSImQLUU
                dSsPYQ8ZECWZqMxodIMBduY1cb1iMGJQwd4IizrfECSUlK1aVWHETGSInYiNFEVxyFpAt6Q30SUi
                YrJDpjBTuVLgZHjiN2ktQa70ClG4KR4OcpUQJk0IgQwKAWVrSkuox6vIUucxSGKnZqkti+biwDc7
                HWz/g9GPMEnsj2WDMrls0B4csX8vCc7fBAsPVw50F/ihXLhXYKIIDrm6ZHe9YqCpreu/RvqxOjl1
                y5O60Iqzyq2x+YSe4Uy32EKRN0/i+yEg29zVzmCzjStCOS+nJRNanJRhB2/uvAdT/Hz8NilB0Q7K
                zvyFmXdcdkYvQw/79hLzPAN0m9Wy/Sn8pr/CKfpSf7gqN21a3tIOKshDLkBgq3fzwxCzzoCoSRGm
                uMEPZ6euGZlQdyLg5I+sQMEf8PCeYEQGPBimL1kyX4iHrhH5zWgTLK88EfhlmUFLLw28tb2mt42d
                9bUI4W/qRkJfTRETbxqzRMnvkNmvoB+lGt9UzEnriSm47kSEseuw2dqFOx0z+CP15tw3oAT8e6fm
                jLxONXXftKK8J2SSop2Qcd2PNWvmb8WSUbkRwWFlm5jlzx9hpK1TbVytGODhyaMJjDgS1exRv2qW
                U6CLwhfZ1bjHrQMFW5UQDx6kYpa15ZWZeMszZcIw2MNfIklhR30bfpd7vMebwl6AKdXZcM3fBTL5
                G3uM+03ESpR78CIbyo43wzqNsrP8xTmn+28ZY3qCpVhlle2NIcD69H0cDrdrDLT2KB4qyP0cnfSu
                VQy4ZzQ0gvHRdXPnWnAou8PqTVd25ijer1B5FU9VO9oRyRj9TGRvbI9GLoO+6di9gUCRaRk3Ht/g
                yNi0Y9pqbmfkhHaH4+lnEt7oXuHPk1g7hXTJPBtiURL17hsoyvt7q7IQK1HZXhgEqqsfasbLVKlB
                gc53U14Dxx5+BsH9rRk8o6/BD92RCFhXX1rTsOW53wgl6hfGHLIWtAIu7DLCypLKFNigLnbusqCL
                08Lsb87x/53zsEDBOdik6Lrfj8Ttt3Q8T147mEyJyX+CKwJQDmb0KzpmfdwileAd69vge5oRssoA
                DD6vQnjosyuKKxUDvnMb0DX28KZKSTzslx3L1RWavuAw2D0dcjqEV4NCXo9Ffivb9vGRs/HWl2ol
                j65oM4VdIYJT5qBBU3piqW5mV7LG2bkDfk1vuSjO+iS7YzICX5Mnwgoldxgjyy7jicGMtbW3lSsV
                A09y86WAqY8BqL6rqa8QLK2sgV7E0ISVzPMxxQP/CmdM5dC2P0dqX77RlZAF8l3hlGBwiH0lvTD3
                E6f4t+XbU23hERm7tz0W79+RyKZkZNr43vHeT9m/2BBYXrdlDigsN0BlwGbiudBAO9ubuE4x4OY+
                +AgYCiODe1AJEMazP3FLY1IaHKTYvk4hgO2dediPkIVbUiAY971wpjB2pzOMd+a69+75sJgwVzlL
                7dwDw78CzbRnIiydGAZINuQIzFexxHaHESxghfs/s/JnGOEfbRvXKQYb0pvPReeMvMksX94wFElN
                Erc0lC86EDv0ObnrV53f35fHwgtZNI/HMWsB/BreTJ+a+18RgIlE6FTIwZfrEq9QcuOwwMT0xOu4
                7LEeBAY3rH4R9VfrabO9bhYceh1bxo1WXtcpBljfuT7azu1Uj5H7CSnRdjqWQD/Y418lUaZhCUG/
                w6ZpMDH2pKhZ39aWfZQGa8bZpvVVJyF4O4thLcgoyITozilIOnGzoHpvShS+IZssEoFOEWiNamPs
                gU4rdHWCGZzDuqJp8jlXKQbD0wuOxTrAKAMYhJp8WyoMtIubJqF1m7hpeH8HOxQh3shjDvLvknUS
                UbnjWXKXlSw6CWfH90TJnR9hjMfim7KPgEVw2UH2MjPCF+0QVPJwDgGP5n0S3H/RLwE7PCst36Ed
                baOT1lWKAZyDboiuW+1qUfIoz1zV7mjC/GycsXAkPCtucbLDmPxeTbv5uFonZeiMNyspUaBwIneB
                MwULlkJYC7Kzr+KKkaHcIM4gZxlXr6JGzrKMuiQcFwgsDT2zEeHvTxjpDPaoMTaXGWFmoI1rFIPs
                tWahHQAAQABJREFUjEkj0b/jDPSxiRBFWIc3A/3R1YTNm+fRNIolBObgWyAyHTJ1ui7Bbay8zjua
                Ox0OsZFlW1aVgeK8T9secOo7+2VjLnhLr3yAoCjkz06Ng+TrHgQ8KuHLCWH9ErNThqVdkK2/nT0t
                XKMYIBJhijFI2NzqullBY23d3ypUnTYDvXDO0x7MGVWeDUwdu1hUNFWFnOaUbEiK85BTvHfhKyfD
                3yDB8+ZI6YT4GxzySycILGuc8zNOGQmBV6jivbgTso4fdoVikJlZkAJT9EQDaDGPx3uvgXZx0SRY
                WnUtOuK0yarZS8NCO3MhjNUZxYCRUGpzwz/EuNhK8Cxgp4ohixBSwM/Zc7IQkkghhEZAYR6DicBY
                QazZNq0CxhWKgXcLOxMA9DcAwltLa59JyK1Og6ULz8NGQAIoRfSRAYXHrjYwdrY0abhz0XCECu5j
                C7P2TCh5VpRtlYcHag6F8j2wvYiJ/Zs5ozAmNuiu6/2yhme+gY/ShwYEDyDb5ikG2lnexBWKAaH0
                EiNIILefQU3OCDdx2jSWVh0LzCogEZ71jpYNvpamUkcl6IY5VTTH3pI1psL3Q4yCrItyTX3XoTjO
                LSlsdxVdHrETAYSCG5prkALd0Nxmdd+EVwy27WPNRhsA4uvla2d/ZKCdq5sEyxcejC1fX0Enkhzv
                CCPTdys5YZ3jcnQlAHVoGYHQf4vld0HzuoIpQc+lNBH6xwTtu+y2DgSqG+a+h+pLdDTZVpWR40QM
                jRVeMcBbvyEHDbwBPa57kFzeoKG8Mhs7FL2NbvR2uivIsPhPf3jR/U7L0RX/2pmVfqyrH9VVHavO
                YSM+YawF2/s42Kq+upmuSg1lWXVzl6XsBhGAedZI6KLiYZELDbK0rJnQigF3zIDX9iQDvd+Uom1+
                wUA71zapL/0wQBmF1spESOfaRCOsgJaInWnS10JOcmYzKdqS1Nz8vDgX23gPZMkQRx5xJME9NUgc
                aaQkIiPQnByeC/kQHq+zaASKQes9qLOhddWFVgx+yWjizj8GJjr2wpLg/E3WwSYW5Ya7KzMU6n0f
                SkGWIJJNS5uWt1QQWToVQ3MqGoGyBSItsezjT+b3mNDPgk4H0foTUjGwHuO44LB69fPr0ZGXdXeG
                ksHDM3qeoLudhQ3EfhgwY06HGlV4qsqEKPV3LhhGI/RTKAWjROgwLDyf+VsW3SeCLF3JsPzBt5Mh
                6/Fd1bHsnEY/sIy2AcItSR45+XWCG7KtSmw6wUYe3hUBLH0bmnuYwbluVwnMOSKsYrD3ts1cjtXf
                TfbNirqKL/W3c18Lvlui4lG4UiCKpWAzY5HJoi8h8JHuv7knFCnW04lR9xAmlGJANWku7+w6kEsJ
                nSEjj3eEAHd4R5pkA9ZSdtI+/gsGdkTTiWPCKgYRTeO+BfrD7Sg1pLE5AX4sPJG8KBe7AVaBRiAW
                Oia2hb8hy08rHrvMRJqWkWKEHWwZ8a4J1/UvztHvvdw1zZjOItRKvhV3jqDEpnNs5JkOEaBPdXi4
                64PeiNdjJIlf11QNnhVWMUAcvpEtcLdGmuhzBrFwTbP68oVnInnRO3jj7SuO0PROf3HeK+LI040k
                jBzSTQ1rTlPyIZYwmDXEjVGFRpdqrGVCtELkiiwSgegRoIoyG7Vbom+xrSbTiJE5Ty+bqOoLqRhk
                BQr+AOn1Z6OjZP6qDRUbouq5SysFyyovxVaA8yC+I1sEdwLba/6i0SWdnBP1sCMWA6gERjKkWYoh
                ZGq0lIG7iYfcLb6U3m4Etu/N87puvpQcJMrGSkIqBliDNaQ5YQu/uF1G4FsDN5RVluNie8yZELuO
                L3O8+n7HWshE0d6CO5Z229GVJZUp+LZfV3UsO6dpwikG2OSq1rL+up+wxMb9Y2h7D+CbYmwuUjyG
                5j6zOyikYoDJZoKBjv6wIjjnEwPthG/ya9mHqUHf6HfhcFEomLD1TNX+nF6S66rQ0D7JlFukvLZj
                SclS/y1jfradbzcMkZZVTn6dYISoBIlNJ9jIw50jsLyhgr8ArOy8Rsdn8IyXikFH0GSn5R+I48M7
                OtfVMWhoz3d13q3neORBC/F8hQvmWMH6EFQUNiYwbUyNYHJ1K45Tjocw2Qu59bQvrMrJr5OrBs8V
                iU0n2MjDXSLA/Yhe7LJGxyf/MGJQwd4dn7LvqHgWA0UxpDEpXoWvu8dVCZVVTYTH+Ke4wjLF6hhd
                hw2AxqYW5gnlXR81Rg45HiKM6YeoZbSx4veh5gaw02xk6SZWUjFw02gJJCvCgA3NSVpEMzQHmtl1
                +82p3UrPDCwjsG/iaXtl9vhXScHGjffhzfbKbuGyv8IGwtRjxdoASDcIjjgeQkohFQNC5quMTKqH
                VUqYOGrdI2pRA/jOrLWItCRrEgKNd1UO1lR6IiK1/kS2pbDOwLNTI4z8w8PIawMii/7lRG6V5cGK
                /2ZnTFoGOUbo6uq2iLzbdbUxubJQisGIjPzDkKZ2qIE+GtLMDPCxvMm6GR/sGQptfI5ScrTlzPQz
                2IhcBSf4p475t/6mYrRw1PGQiGkx4CMD0+EaWKakYtDuMoXFbk27Q/Knwwiwkkpv0Md3vWTjKKHj
                4HTOk5W1/tv+37YEOJTsp1Fycyhp9OvBuz6ZmHbz0RvtFp0hggwK9y06+e7DI/NW1Fd8q7OdadWF
                Ugw0Qg1YC4AFoy+ZhoiDhLBl8hRVozNxVfdxUIzOWK9UFeW0jMLRjl2snQmm5/huSSRbdcLxEEKy
                sCJs8ie8YS1AtMuherBMgLpNKYR9ngD9FL6Ldfe8l+5tSToBETQnhQg7Di8o/bYJzZfyuyl8a3U1
                /Pn66QtO6n/LmB+7qW3yaQ1zk6JXMcAU0Go5d+xZK5JiACwMRSN8Xd0w23UOcG2vvsbpi/ZQFfYU
                Yey4tscF+l6VTNSz+hbmuj7eXVOwi2AUzxILsP9J5OgN3HyvYaty0aJeLBgGXSQ/WFw/d7OuFrKy
                aQisLa/MTIKXPt66zyRhcigScaEYvnlHRhTlYRA4xTQBoyBUUz/3u+zApP+h6r5RVP+tCrrK/Qym
                /XbA5i/COB9mZRTwTHR76O0/TO6uXkYIllderCnsOzyYhVQKcBs+4m8hx/YtHut6paD12mLUEXM5
                cBTUv2DbHbe8ftiXkFGup+/0AKKv7fRT/rAcgdD0Bbsjidv/4fNPLyMroRTMAFOzLFknN5RVHWN5
                J9ozYMzIHDV8e6K/9tRs+S2MxUDRtHFIg6y70x5izPNTNyOTG3CHGaaSp3DhHx+DFmyyVDuRC8O0
                fEV6cY6xRB07kRLnB/DO2LYAaa9MUPyq7eWol1sJohIK3sC1eKnelnFaH5eK+lac9k2obrUuE4ST
                zwTg5yBvBJ+49U8EUfYI2ciLUPXjKKubUg0Rcy/BD6JELzEPZSeijSPLCcIoBoQqAEGvmYh+8UNd
                xSq9gDtdv6F04YWaSu6DHLs5LUsn/IMwK58JpcDWG6gTWcw9rGgD4ZNiLs0oqGFb1V+jqOZsFY28
                Bi9EqRhgFPCO8ml13dwGZwckfrlvKP+4fwuLnIEenk3DbAx8XBTr1IGdcMze6ZcNP5bVVvwwPDBp
                MWY3OElGX6AoccXg7uhbmFdTCMVg793zUyMRpt9cxDQjJhrz0NNJiZvJmEd5EvoPH3BRy389SuS0
                AYXHrhZVwJjk4hYDJwolwmeHpLv1qSQbf90IeER0frV11DSN6M91b6uE7mPG07qvSz5mLGPKJWEW
                OQ3qOVwIeLFRUXfo/oc5jkcn6FIMAMxRe/kv7LM09Ay/J20tQvgYqBHK19d1ywJTy6u2ohUDM6xt
                TWaKskRspYDOC7dsOipulYLW8XPGxwAPBeEVg+rqh5rxlvL3GC7zeGkaSVLoy/HSGaf7Ebzr/UHY
                5+WWRt/oGo0p7+HN+SzItF0psF26FDZvnsduroqivWKAZ1JE0cYYaBdzEyEsBlhXOlGveRdZ5JYu
                bZi7MmYELCbQaiVQPE9gmWScxaxiIR9GIpfb/EU55bEQcUlbZywGhLrCux0T4u0Rxs7DWPpcMp7m
                i8nI4z/Uu2+J0nwgjFPkk29ouf8ELBFPISo7CYoxcg05XyDHQjphgmq3JMvXzv0e0QncCrunHt7K
                Nj8D251gRVAM4JdFj9cDFq+LiewdvW3srF9b8mbPJF+vG7BWfxOUgl528tbDCzfr5x6FXZJamLtE
                TzsX13UkKgHWUuEtBnxMuc8OHmCP4Ou1Lh7jWETfxKh2RywEErktT9Cmqt4LQ9XkIlzzg/X7jVmL
                HtyLbJ9kd/QIc8E7mOx0+fDg+XzCjvZ2/nVcMRg2cNJByNKerrvTjAipGMCSQRvLq/IxoKXo0+66
                +2VbA/orZazYH170NyfShdrWzTaMfrrvsx6kqdkZh0+mucJiwOHyellpJEIvxFdnsGozZrZ/ZeSe
                mgbpdKgHd57CvbFx40mYdJGgDRMZ0hHqaW9j3Z+SmTrfRn47saJEw5xFdSkGILBndsbkfavrZvFc
                CLYVxxUDRSMnGjAxbSF9+y4igvkMB0urckPlVfdi9PgOkeIWRl6nTL1CxC2ArQTN29wcsJJ+V7QR
                JuUKiwHvww8/z2nMDhQgfpyVd9WnODxXn8y23BeH/bKkS3yZlCiev4QaN3Il0qnEYdH2bSuyJp7W
                t8i5JG3J2tYFzUrPFgisa5mOaRp3Vk8sxQBhKui0PgUTikRlDRylor0irK4XvHPhXsRL70HmwlOs
                5hUj/bUaZVcFivMS0sEsSdXS4QAaI4QGm6vuWErY0bumpM0PpIR78k28BLZ67ZDWnL/YYrlkSXC+
                axQ4c3qtn0qorHJvrOXeCOvoRCiPTjkR6hG8nmj0kvRbRv9HTyOz6/JrKzuQ/wnmuzw9tBXaGsXG
                XzhtKw49Jbf1b889z+sPkA7X3VvK3tXdxoIGv5Z9mApv24eIh36HaAORlQLoX/QJbwvZN1CUmEoB
                H37Nowyw4DKIimSEeYNRVRSk0po187diTfQGQcSxQQz2Td8G39M2MHIti8bplUcgI+GreDH7H5QC
                biUQXSnYCFmnsRaSnXZLzpsiAE+ponvuQh+OGRWYaKufmqNLCb4WLw/F0B06gn2uHfUv+KXk3QFh
                X/K1MFlcBVuH2OuwlCyFM9WU9MIxH4lwYzgpA9XYACPZNc2QWVN/rTeDjp00auorXoQj4mHgGe+O
                iEFVSTrta/JE2E583cCL+0wFyxadgKWwmxGLP9oNMuMl7Xs8lx+h4a1zU0vGCZVYTGMqHBAVvUmL
                fFupkgPs/2EX/o4qBrjmjtG3iNAKy3KnNk2qnVnpx1v39VgkugKS9LFrkAzy+QnWmDv9zWwWLRkT
                MUgjrpoxoqTCK9iJPm0aVHLKFicYx8pzcP2PN63JGLIPYHPEOzpW+aNoH0buhtNXrn36xyjqJkwV
                vrVxKIlNgM/UTcgCub8LOq5iLnkVDpCPIOx6EaLWHLnRu8OpdVOl9ElrtkVsdFf79/N8rsSvxFAM
                MJBH/d716L5htG23FiCXdy9PJPk60kJgWmV9o5PUsVprcSOXre+19cnhV48Txg/DMTTaMKYKLAbO
                PC5cZy3YAVsVqYpkNhWc6/Fp/8TDdq8dx+PnL72spqHi0/jpT2w94WHWvuTeFzYycj1eLDJjo2ZL
                67W4p5+gTHvyN2fqIlv4GmdCGeYweokeAtBzdM+Veui3r+uYxYCvmeAVSr8marN/QX3ph6OUsOc9
                KAQOJcZpP2Sd/g7iBrmrqUfyo3tcd+TWTmsl8Ak4lw2As4XtCGBCda1iwMFataFiQ1ZawSl4OP0L
                P/vZDqB1DO+vrq94xjry7qHMl0dbklOuIBq7GhYUvwsk/wLLHPel+fu+Si89xFVLQJQp7yKpny7F
                AGNyyMiR431LlsznUQ2WF8cUg83EezjiOvXyV70R7yeWo7KdAV868LSQ1zGViKwUrMfEc4/WzB5K
                L8mVHtVdXBy4GR2xGGiM1HUhlitOrQhWLB+eXjABGHJzpuhOZ91iiiWlt3evX32T4FtedtuPWCs0
                Tl+0h+ZRr21hdAqiqnrpDBCLlb3u9rAyI6UyK/cX5X4k6nJBd52i3uaPmKorYpGTTGkO9jgYfz/v
                jr4Z5/VOzGbwbKWhMHaUgU3uvrVzQ4mkFjIXSkGmaZ02lRB262Psfo8ncj/2NvjFVNLxSgwWA1h+
                bO8dFGBXWwx2ALa8oeKDrLT8PEWhPO972o7j7vvLnvT5t15ZVV+VsL4360sq+0V8ZKpG2NWIWNI9
                S9k75gx+j3Q+8hDclVa0PeSw2F4JzOS2rPaF0LD0/KV6l+YQJcSXE+JbMcAmm0fpfkYzYttaYONd
                lYOxNfLxZl4QJtGqxo38qDfMZvUvyd1gEs2EIMMtBo64JLl8KaHtxbEiOOeToQMvOtSjhV/Hw1r/
                UmBbYvZ/V/FwvbamfvbDpF7308d+aS3gyLMUBkObLgtTdhvevlOdUJSj7xZtwShVYK64J70oN66M
                O3xbb+Cgy2cHbbhiMDN6/IzXdMhiUKIQtvKPesXeDqbeZobqM42digcf7h0RCteYsS7FyMNpxaPf
                dasJzWkkuY+BQw/CuLAY7Bg/7sE/Mm380U2eHrOB6Rk7jgv+dwNknVANq4fgcloiHg87RKr200Lr
                Nt6Np9pwS5iYR3QToexvSDxyf9rUP601j6xIlBQoBq25IPQIxRUDW4ojCY5GpK/+A3qn27tf9TDb
                LAaYhI+wZQS6ZrIeysl9mspGpBXnnJQ+NecdqRR0DViXZxl8DBwoSB0fV4oBh5BncaupyxqPNek7
                HIBUF0tMiktxDx3Ol0J0NYyTysHplYcg7LASi2iv4g1cZKVgK567d/lamoekFeXdFL9KAZL3eLhi
                oLukZfnzR+huZaCBIxYDTYlgGUHnyzgja1bUzlltoI+GmiAJxXonPNi3CUsX4+/D4ZaNz7k1/t0Q
                6BY2ao3LpgSZNu0vqhapsZ+rHRxLtOo6cltWYNJHSNuKlODC7RHShLeyv9KIWl6z7rlf7UBEJB7b
                HAu1MozLBSLJ1YEs8PVgTxLmvTM9bi0EO/d6ae0zS5E8LISjuiJAPN5WP4NlO1Mz/5cjigEuVP0m
                EUqNaFjGEaPwJLfVT40ug6r0skbpy+k7HGyMSy9btkMglKSNwnKM7iyb7cgY+dmc7u/3vZGGbmmz
                on72AkJKDhkeWHk2bplSyD3UYdmx9EZmKRF227LGOT87LIvt7BtL3u6rJqUUalS7Fs+wFNsFiJ4h
                XD7IcxpRbwsUjV0RfbO4qfkZeoIl6+gLLCp87pwVfQtjNZ1RDIwlNrJVMYC37n902jT0jwBSd0JT
                fln1eOZnFI7+Vj8B2SJaBBjxHOVQ1sPv3BZnHS2mO9cr0ZbXkxeys696hW785TI88afhPJzbbC9v
                YrIpqq6bvcR2zg4zbLWKJZOLNUZvx7We7rA4XbPHDq+qR5mWyM89+Hp8iolel2IAUPW/VHc9Eh2e
                tV0xGDHoXL+m0iEdStPFQappn3Rx2vRT8IJ9FxuGcGXE1IHAG9V3uCBeVrAveOrUsf8zXXBJsEME
                kJznyA5PWH/wv9azEIdD9bZdTx/I6j+lQvG1XI4J6gxc84daLOF6KANvKpQ+tWxtxccW8xKOPHcs
                xI6H42CX5ss5++BlQzgZ2whUqWikOPWW3H+2OZaQXzVN+YRSbtzSVfaC429vq3cBtV0xUNWUUYjr
                1oUEKm+qDm7l6+62FoTJFGLczHjQfINb9WWqsvnp0/KW2toJyWwHAqYqeDuIdvcXSqCQigFffx4Q
                qfyZlpTovhm76zM/v2L9Ezy3xgz+yd79/MFE9ZwKv6LT8DsPHxOeO+xH7H3xGvB9bXDdqk946mbQ
                TbjSUFp5ABwLZyKAaozgnf8KY1WUWpizQDpQbxsp2rf312Tjr834laxj7Ggz7cGd9z/X0UZ3VRNu
                UH088QaBtV69hadina/qbRVr/fTC3E8ayqouxJLCY9DCdSYBof/mlgEtAp+BaaOXxyqLbG8cgVYn
                LKLtYZyC8ZYqY/8x3tq6lkzR7m1MztnI5s2bQidMsPTeqv75uTXoyaP8k9mvoF9SMjtRw3breBYM
                xD0yCObUQTjHPx2thzfg3kM+fFoLq0Atvq9QmPcfyxqe4S8Kra/GcRXgjk5FU9bN+GA3VfXOACaX
                or7lq57RyNRJnZ8YpdenFY5+uVUhKOqkVgIe5ta17ED+1xg+XdZMDDafQ+NLMSBEg7aj8zqmimNv
                XenFObMay6p+wIPsRTyH9uzk+uUxFt/h1WsRzi/Sklo+yrjxeDzQZBEBAdWjHelIYiN0XvH4bLd0
                dYc5T/WNPer/jMyZSaFqfxKUg8lWKwc7ZOL7LuD7C9s/Ow7zv3TPPc/r52tJHqgQtbeqeNam9N9U
                b1du+LaCiP49OL3qFFVDnD8lu4srK23BM3FmJKm5DM/CzUQqBB0PFaXfQL3VpRjAf4dbDCwttlsM
                cP/rthgwojn6cE0tzvkc63iZjeWVhyHv/WmUKsNw0dfhxkTkAvveR9SP+xaPbbR0pCRxwwgojB7p
                UOhpddrNR280LLhFDZOa6UQkkEnaRp5ODFWnJcFxbSItyXXSHM9Wr34eeTsI/2wrsA/I8jsC2OU1
                3RP2PYAXlHN+PyreNzwbsZ9B5Gp/8dhl4kknlkRUo4uRkVWXUKitew7VxQCVbVYMkPGQrBypV0iq
                eBz32N++LvYFZOcfWVyEAJQCZ/wLiHj+Ba2OauWLLm43fOc0JpEkpMs9NzEiKNr1XvCffMxgtTxf
                C5O/QlQnIj2iRIiuxtLQ/6UWjobvh87ZLkoO8VYN0W/fQpHSVYCx5RYDTNT2lb0GrR4Obj10clRJ
                z94JF3qkEyNZvRME8JbVC6cO6OS0pYc1AR0P15VWHY43zn3bdxxrYWeGQhvn/3TfZ3rvz/ak5G8T
                EYAvwZ6hGVX/wPjMxQQiqFLQumwwHQnZ9vEX5bwqlYLoLwAaifCXXn0mA2x9njUov7Nl7eiZd1HT
                VsVA1XiSGd1l2fYQKN0NZQOJgKcl+TCg4ERiI6wysSrRRkBTSHtrwe8iUnJaclPzvxpnLNRt1fud
                iPxmBgKtlp2yqstVzbsE08aJZtC0hAYl7zCV7ucvzp0ms7TqR7gaGTmhFfyot6VHtXY5wVbFAL4C
                BkwgremB9eIm60sEWhHA9t5b8eUbB+BYn95Cv3CAb6csg3d90gcnu1yfxlvpfppGvwyWVV3CJ6dO
                ickTliGwtuyjNIQgvoElMB7J0dsyRrER/pEq7M/+QuzhIqOuYkISN5luHzqrHRBtVQwoU3RbDHBz
                OO5fENOoy8aOIsATqcC8eSBC447A2lwFhEH+fFvKew478+3SSaaGJ+AgX1rprmA5gT0RKl/0Ig+L
                666yPG8eAqHyyrFeonJF9mTzqJpKqRmmsDvDLZv29RfmvS6XDWLHFoqB7jkObXTPpXoktdn5UH8O
                A+xMp1ub0gOArBv/CLR1HN1Q/vF1LVokH0rCZej53lb1Htft21bRNkyXYhlB12omm6Bp3sNCZQvP
                8RfnCWX9MIyBoA1ZyTxfyJd+J6w0N0JEMS01jH7EFHZRenFeIqaOsOzKgV1usb77stUpwVLFwLYL
                cFRgYq8tRNmo96JXFW8m3//dslGRhBMSAW4mbyyrzEPylXsAwIEmg8DUpJYMkXJZNNy5aDj1aEbD
                xyLQJx5HDNP09Jty60zGKuHJbR+b5wHEIWKCQVswFU31ZwfvtyvfhZg4WCPViEEFe2NbcL0brUWS
                /Vt6WZXnw7alhE3EkwVY9Soiv0ilwJqLMdGpciuCf2reAjzsDsVVeTkuzXXmYUK/FEkpaO2Xoo2L
                oX9e3LhX0AitCZVWTpfLCzEg2abpNgfDyklQ2P6Dw0IqBRj3bzUWOTStOHemVAraDJ6JX5fVbuaZ
                cfUucXqbGpIti0ywTTFQCBuqH0smwxT1gyZb6ECAP+zSinIfSyaRETDnPYamuoztHbKiTLhlBIWa
                4dnOesLsOVXVklZgg7EbZGhjh6Mf1UEeRgsfjmdxsVWgQTR+H1HRNbES/NvYPet7bz00MHWsXM41
                EdhdSSHdP+U77eorCvUamFOj42GbYgDNMzM6kdrUoqSmzS/5VSJgGQI8c2Xa1NzLCdMOgTXhs1gY
                ieZfUFvyZk9MQDmx9GnntmwAft+T0tS8PFS+8C/w2+i/83n5qysE1pZXZnrCybjG2Hld1XPw3I+Q
                LTetKO+m4VeP45v8yGI1Apr+uQ55UjKtEss2xQAPpqF6O4E2q/S2kfUlArEgkDZ1zL+Rue1oPBiv
                xwfbX+guwdTmqq91t7KwQVJSr1yQT7aAxe5w1XgkzNQ67PL3Sn35wjNXllSmWMAnbkgGyxaO9mrk
                S1xbljqPGQUMz9zZSsvWUWnFeYuM0pDt9CNAFf1zHSKtdM+p0UpmY1QCRSdw2ekoCqErdVSXVSUC
                piCwPYrhvsbSqm81yl4C0ajfiNH2Tau2MjbaOThYnkiNNo6qHfMhyuN0yujpvX3kF8Tg/x0q1bP+
                cNUi0bCIqjsWVGp1dp1ReTkUqQdgNrbxuRtdZ/BkbsRy7xQoBK9E10LWMhMBhOVjrtN3l2LMMs2U
                oS0t2ywG2FVRdyewyAWwZJEIOINA6tScDzRVOxTco/Z1UVX1aWek7Zgrn5DwuInF8bBjwp0f3Q08
                L8T69MJG359u6Lxa4pxpDUUsW/QYt66g18IpBZiQ3oZUyF4olQKnrkpM8rrnOtzXQ62S10bFgGbq
                7QTuoFV628j6EgEzEQhMG1NDPEl/ZIy82j1d+r/0qXmfd1/Pvhqh6ZUjwM2yB0hXPYGj4oKuzifC
                ufrSDwMhX9pCKEpTxOsv3QKZLvMXjT5ZhqE6OzoKZasMSJBpoE1UTWxRDLDPOjfF6s2gFvmhbvNP
                UfVCVpIIWIgA3zo5LbzoLCyF3dY1G/bk9mWIrqvZeVZR7LQWtOkZbfA3f8TD8BK2BEsXHKRQD/wJ
                iCO7e3YD/BfY4+AAhCE+Ltw1243g8Xh6q6dplYF+ZQwePB5ZSs0vtigGvkiy7jcWmFbWEIIwDlkk
                AgIgwNfKsf56B9xkOjGP05Zkos4VQNSdRMBe7yfudMCmH1gzfSeR/QsayxccR6jnY8C9h02QR8+G
                svv9LeRoucdB9JBZXXPNmvl8T5d6vXx6ar2G6G0TTX1b1rtoRBuqdzsWrJ+sjKYDsk5cIkBHDDo3
                NRxJGuQhbCD1KFu1iFq7NalnbW3tE9z86VhBSOO9DWWVflyfhTsLof2dhzzufMzZXzxCAKGTo/U6
                /ZoiNXbdM4WOC4k0lFeN1xh7DrgnCSZ+GP4flyGl8TOCySXF2YYAn/MCesDAjsX8pfsHPW2iqWuL
                YoCYr0w8SHUW7qUpSzwjkENyvGsy9jiKafQkopBh8GofhP7yz0BNJUme1osGQTm4gKjiIT3VZpId
                mPQLztfiVC3ehmvR5quI4n3dzgyZaUU5xaGyKj+ciC/+bXyY8uRv3wX50juZjYSFw2e/OEzzkaT3
                7efrPMcgdqXEJkOPQxL9jzwrxWckxDzk9PTCvE+sZCNpG0eA4WUYF80ReihQjWbqqR9tXVsUA9wi
                e0Yr0I562Ilx1Y7v8m/8IDBo0JSePSItx2EN689rKDsZE1cqd5vH32gL91XZDdX3ITBD4e9EjxZ5
                AArDf/FAfg3XzevLgxXf6KIYLeft9fiaLJs377JgdfoASHAGDlf7i0dXkak6CVlcHV7wBzgxOyEO
                4l/9io5Zb3H3hCOPnRFvxhv5DNEEwzXwbVghpw4szF0lmmxSnt8RwDjpHx9Kh/xOwbxv9igGhKTp
                FRkPfP0g6WUi69uFAM3KKDhRYexSojZj7ZWkYHzNLgcQSg+AFaEkO5D/I17YXiHeyH3VPz+3xmxG
                nB5PpQxT/fm9ffQf0BPeF9SB6wAr+t4dTSh9X3RXJ57O85BQpDeegb83idcv+gbzeC8YCAda8WST
                ErVFgIfnt77qtD3Y7Xfm77aKgQq2OB9CEzIgPNPtiPH/7F0JfFTF/Z95u9mEcJNsEuKFJMGDevTv
                0WrVJICitFovqKhARMWrar1JQF0VEvC+WiteIXgVbGu9q8IGr7aKVm2pAgkgIiS7G5A72d335v+d
                EBRCkt339h2zuzOfD2T3zczv95vvvH3vN7/5/X5jYPyyi8UIDCuYeGxxfoUfSsHrYHUG/tmQGa9d
                i76ORN0rhuVPrBkyoGKAFcM80FfeSlzuMz1MfdIK+onSxO/uiERpGOqvkSWG+iVhJ1iOXNhWmgOT
                l3BKARSVmtxw/Vk8qiYJoU07kSnRAvoHTQ28W2NzscdiAHOx7h03txKKLb5sISoCRd4Li+EXUK0x
                MlbPPoHJ48nSCJ3qzmRTsNUwg/Tt94eGhkdMzf0u6kOX+Xz8B+SIxQC/9bRQDFY8/EZmS0OvZzHe
                c02+bxMl1waZLoaTIRwgZUkWBLjhqX1bVYfAsFbm6Gged1NbLAa4SXVrNSpThPLwjhvRNG948D4T
                c4rzJj0KpYCfFgalQIjCD/25n23Z/HVJ/qTx+IzFdGqXQOYJQzDCvg6McmtOePFyB/jaypIrXgO3
                9uKnI4qmFDTBHF2KE0OlUmDrHZE4M5eb6n7nIfGa7ndrPJLaoxgQWAx0lr5aWFoMdGLmdPOi/Ak/
                iUbpJ3jtXgVZ7LFG6Rg0tIEheJA/D+vBnOHDxzrgra9D2ASbupjijLWAkE9TPX8B9yloySy9X0Cl
                4N+KphyL1MZp5eOR4E9FoO5tRt55yakYDBlSwfeU9Z433vpl87xtAs2YFCUGAnjZnkGJwtMBHxij
                qQjVl4SD2e8enn95ngjCWCEDVhLOKAZpsI0An4Lrge+1VsybUZpQel9SM8In5kwvldlijYLocL/l
                66I8kgfB2boKzypsugXUcouBZ4um21qAgeo2qeiCUjY2EwEK50Ke7Odl/OtjJmEraSHS8cTtZPvH
                w/aZ7IyDnpWD47Sp4si48MLkW0gpW4I19ePxGL5XqAFS4sP2zW8KbhotF1NCTYxeYdoz/X6vs5dr
                +L4Xc+XA1GK9udflhqlDX2ZjqD9SMTB1mq0hxq1B7h0MHvnsAms4WE2VHoCMih8W5VVc2Bio5YpN
                KhVHLAYKJd+kEoi7jyVUs3AEthHm7n7N4c9tkGcinAznOyyHZG8eAvzdx32i4i472lS++N4Qd4c4
                GlpuMVANeE0iz7qRvZY4hiubmIXAUWRKhmsHexX0klQp+AGJ3jjZ7K8dTok/XEzmD9/e/1EvKGu6
                k4qZMWbG1DVm0BGNBk5JPJwx118hlyhpjncojJ6O0zylUiDazZKYPLrffQrVTPczsFwxoIaE1u+d
                mdhcyN56EdiU33Y/LDuj9PYTsT1PtoR/TyMJ0zEiyqdXJndbm65863rp99S+NSs75fa4N8x6Z3+F
                ut/EXdKvp7HbWLcVspyWM63sHRt5Slb2IKDbWo4QRyPb9T2OxnLFAK4U+oWmRLfW1OMoZaWpCJTk
                TbwMBH9rKlHniWUhCdPLB+VO5mc1JHXJYMwhxYAG9rv++B1JDV4n4Tf53hqkqu638CIW5L6gmxVC
                T8FJn4s7iSq/pgAC8NHR/+6jSvJZDAhluh0jAI5urSkF7omkGEJxQUUZcuE/mhTC6heyUHOpL1t1
                xrl+cYz1gPXDIcWApdQ2Aj+dMuzJfBnOhocYmwnTe20kGhuZU1XGo39kSUEEqKL/3Qc/E93v2FjQ
                WW4xgPe37hS4CqWbYwku6+1HYFj+5KE4qOglcLbeadX+4bVzxEv1mKxIL57iGDslyVoURxQD5HpP
                GcWApzru6yHzcAecKMRdgJWkprBy7/TyJULII4WwBAGclrjJAGHd79hYPCxXDHDanf5EMoyZmrY2
                FgiyPjYC3NlQIyr33Ne/NRSbvGAt6PlwRrxaMKHiFgfOu44oBohI0BtqFfeY7GzYnsCoIfcBKInn
                2sm3B15NClVL86eO+KKHNrIqBRBgihbWPQxKM3X3idHBcsUAe3P6hZaKQYxps796U17bJeB6mP2c
                neGIl8IdiA/WFTbkjKRdcnVEMdAY29GlNEl2EccnXwfrhxCKIe7DFupSRuRUjfpfksEoxTWCAKP6
                FQPG9C++Y8hmvWLAqH6hFQPgxBiorDaOwHDv2D4wrN9unEJS9hwQjkYrk1Fy/KgdUQyw95L0ikFL
                df1x2EW6W5B536Zo2pjcW0q/EkQeKYbVCFAD1nJK9L9jY4zDesWAGrEYULmVEGPi7Kxuo71uAD9H
                XjZ2jrMzLzjBXn3I4IsP6Hxd9O9I5e/MXCW5xWCjzz9AI+wFzK9LgDmOID797NzpIz8WQBYpgl0I
                MGLAYkD0W+VjjMcOxUC3NsOogX2WGAOV1cYQODDvknxC6Y3Geid9r8wIi96ZdKOgzJEzIKiiJK3F
                gPsVqB7yBOZaBEUQOxl0Uk7lyLeT7t6TAieGAFN0L4phqdP9jo0lpPWKgSHnQ/3gxBqorDeGgItE
                bkXPPsZ6p0AvRiYMy0u68xQcsRgwjbQm64yHZvkvxX6+EM6GSFhzjbeyjFsuZEkzBAwtilnaOB+q
                +s0paXYD2THcoYUT94dvwWV28BKYByKItDsElm8P0ZjPz0NJTY9r3oNJd1+U5HQ+3DDT/xPC6EPd
                Dcve6/TO3MryVM0TYi+UycjNgMVAo0npfGhg/0Nx6TanJOM9ILrMiqqcDRlTNmdB/PizMcWDLhAl
                HW6PYiNe0DHrDuzfSZeYbJ3v1WyV0j8BVNNjwXucqK4qGfljbmWpr6sqeS09EGCKAR8DI358MeC0
                fCsBZjHd+x9Mk1EJMebNruoz7WIkOJ8MluE6TXAZ28XT3Epfx+SkarNjvA0yzvD0RbQNO9RgdzO7
                LcyNkKsppdjRkCVtETAQqk+NRP7FANhyxQCmaP0eky5NWgxiTJzV1QfvMxGJjJgYWd+sHmwc9JGf
                PjmUJCXimGJANdYUB5TCNAnM9B+Je5xH3Dhd1kaJazz1lUedFkTydxYBt7FQff3v2BjDtFwxgLOv
                7mNKNZVFYsgtqy1GIKKSX4GF5feHxcMwjTyWcWOGDx+r2/plmgBxEmLEOYuBS2FJYzHgKY9hzeRR
                CE6HJkYoYecOrjopGOcUy2YpjADTDPnX6X7HxoLQhge/psYSonO9y+2S+9qdQbH5O856/7XNLEVn
                168tmF0mupA4P9opH4O2gbeMSpozToIrvL/FXB7t+HwiAiG3asS/HJdDCiAEAhpTdL/7EK6o+x0b
                a7A2KAYGkhVFVdNNI7GAkPU/IsBPF8QKefSPV+SndgQUIv52AqVObSU0Jcv++IZZ7+wPa8FMp+9q
                /Mbm5k4te9xpOSR/gRCgioF3n4FsiTGGbL1iQA04Eirmh1/EwEFW74ZAttqbr6Syd7skP3IEGCkT
                HwinFAOaFNsI7YmMmPsPmMfeDs/lF9Hw1iuTRZlyGKv0Ya/pf/chGsj08H7rFQMDXpZEM6I1pc+9
                Y/VIVY3sYzWPJKVfKLzcVHPMYiA8NhCwpcZ/FhS8Xzos6/eaqp1T6Dt9u8NySPaCIUAVzYDFwIBV
                Psa4bVAM9MdlImJHeCevGLgmdTVlmvgvQGcQ7n94/gSnV5o9jlxjZECPDSyr1IS3GLDHl2QwSmdZ
                BkG8hBm7MP/WkY3xNpft0ggBquh/91lwhID1igEl+kMPLUjxmEa3VuJDVahUDLpBcZvGBndTJcRl
                hdISRwRhRPhQxdCGLRfDWuAMPh2TAkexGd5pI153ZI4kU/ER0AxYDFgyWgyIfosBch/o15rEn/Kk
                kRCnCkrFoJvZUtwuobHB3B3SjeiWXqZEbB+DgM/fB0qBz1IQYhKnX+bk9L0zZjPZIH0RMGIxYEno
                Y8CMWAyo+YdCpO+dpn/keMgL/fLTPyLzemiauNhwxzqM1JEsfholQm8l0Ex6HbBx5HCpjruPKRq7
                jF52tMzRYt7PMfUoMabfx4AmY1SCgfOlNSZ9DJy945lUDLqZAJH9L1pmLuLz5ojzoYuo/+sGMscv
                r69+z0sYu9lJQaCzPZYzvfyfTsogeYuPgDH/uiS0GOAHqd/HgEiLgcO3sDOn8zk86HjYI7xsUDzt
                nGhDqcsRawHGumNQ8YZlTow5Hp4ZRJuOdk4lfuIiNrldkap4ZJVt0hwBI9byZLQYwBkqrHuqpcVA
                N2Qmd5DpWbsHNNB9lbM1KtUc8S9Aop7P6bhxpmdfMwPNlhmL92OEXWEGLaM0sMVz7aCpJ28y2l/2
                SyMEmH7/OvgV6X/HxoDU+qgEQlpjyLBXNXKHO6nd7yVPul3ARvW6dBtzvONllAmLDU5Zc0QxAHaf
                xouf3e00RbsGPE3PJR/3OCh501tVviDu9rJhWiMAJVZ/ODQzEPkXA2XLFQONUN2aMtKV4mQ/WZxC
                QOSXn1OY7OLLNJewigEh1KGtBPrZLnxE+tvie6MfMJnioEw71Khylcxu6OAMJB1rmqtXZPglfK+3
                T6z2lisGYNASS4jO9TBNSsWgMyh2fmeKwC8/O4HYm1eGIqbFgJ8WSCg7bG+Jrb8Cd3shFQMtI/ti
                5LGGcuBMgeXTV3Br6SpnuEuuyYgArLW6333YStD9jo2FjeWKAWOqAaH1a02xBirr40eAEm19/K3T
                q2VrlpiJfELLvT/FTDjhNNqWN7CfcBEJzOd3Q1G61qm7Ew/4/+Tk9HvAKf6Sb3IigMylui0GLpcS
                Mnu01isGxoTWrTWZDUw602NUWgy6mf8Nq1fX6vaZ6YaWqZeZwk4xlWD8xL4UMTY/mEnOwRAOiH8Y
                5rZERolrRMTF3FFKamYjYGQbXWPUwOK7Z8ktVwyQnNyA0Ey31tTzMGWtHgQoU9foaZ8+bdm3oo4V
                SamcUgyE20bgiZ4oIzc4NVfYCv0HjlNe7BR/yTepEdD97mMsmnwWA5e6zYDQVFoMHLy3+zX34g97
                0x1aHBySKayxl/e2KYRMJhKc/UFfkDzeZLLxkaNMOMUgMHPRcRD+mPgGYH4rRWGzpcOh+bimCUW9
                eVLYfs3fbjAbG8stBkuDC7ZCaL1JjvoUF1+tPzWk2eikKb1PyRyetvW1NB1+D8Omf+uh0rkqNVIK
                5s6E5KniRSQo1DXJuckgX+e0vveqg/wl6yRFYMiACn4yqlun+JvqSX1UZ5+YzS1XDDok0L2d4Pp+
                m7QaxJw+CxtQJuZL0MIhxyAdaAxsFzKlLbzfndpG2PZ9vx3/iYGbrdUrHn4jE06H42xluhszbGPc
                Q30+bbdL8qNEIC4E3B5m5J2n+90ajzDCKgZhJap7ryWeAcs28SHgirr/jpZ6LT3xEU/OVq8QskDI
                7H7YUXdEMeBbKyXXjBHqHhm4NeuXuL34ysuBQtdt6tv6nAOMJcsUQIBSzcA7jxrYqo8Nll2KgW7h
                FUV/PGfs4coW8SKwLPT0FqxEF8bbPtXbAQshLSgbZyw8AMcJH+QQ/lCWxCrw0L7QOYnYA6IpSs5h
                ITnrRUClLt0WA2RK1P1ujUcuexQDAwkY4GXtjWcAso11CGhEedk66klFeduOjB1CKkkRhV7gEJIM
                D7LXHeLdJdtNvrcGwemPWwycKJuU8I45TjCWPFMDAeSP0f3OQ3hjEm8lKCSod+qgGDgWg6xX1lRt
                j4csVwy2per44h0XziB4ae3aBTvibW9Xu/awPEIn28WvE5+PBledpPt33YmGqV/DnsyxyHToMZVo
                nMQQovhYjm/M5jiby2YSgb0QoJqRd14SbyVgL/K7vVCIcQEmkgNjNJHVFiPQ0PRMkFByn8VsRCcf
                dinEJ6KQoRr/SZCryAnZsLUi3DYCtlSc2kZogy/5Q07Mg+SZOghAudT/zmNsrRUI2LKVoBC6yoDw
                +kEywER26RkBV9R1L1oIe9Rwz9KbUEvpo1831a42gZLpJJCh0ilrAcZChVIMmme+mw8l9gTTQY6D
                ICxrz+XdXN4UR1PZRCLQLQK4j3S/85DLy8i7tVsZdlXojZnc1U/XX8a0VQSbIboKI0N0tZeNLUGA
                OyEWF0y6E6uxRy1hIDbRTW6XVi2iiBtmvdNf1RhM5w4USlbkTC1bRqoc4N0NSxdxnYwVlyNFI2yB
                I4wl04QQCNztL1BUehy2n/YhGinAPGINq7zpDdd/6EzIqTYECreuMSmMrNbVIc7GtigGGZq2OuJy
                xSnSD82G4BNHyanf+w+CpPuH/k2Zczblt/0OOBSnFRaU1Xz9XZ0lzj2J4qhq7vNAo1eidAz1Z/RV
                rG6E+l3ikT7aoSfFtm1tpN4QjrKTrQhs9PkHqB5ShiQTI+HDNoJE2aHYst4pA940uIbPrDLkKQ0G
                ZtbflTet7BG7BCwjZe61hO6rl58a9azS2yee9rZsJXwVepab2fQePpM1xFuRH88gZBtrEWjPhEip
                QOtDa8fbTp2Rta3uHQ/bwMkgC8ecDiGvJtQ2AvP5FMKcyeUAMN450Feu99lmcM5lNz0IcOfcUE39
                MaGZ/hnBav8nUQ8JQQ34K17/v4UCcGgPtLzQex9G36eYb74tzqzr8/fbD/LoXT1/v3LjnE09jMNw
                lS0WA0iHOWLfYJWhK97aTbUD0Vfu3RmeXvM6NjTVvlSSP2khflgjzaMqMCWFXi9iJAJHrGnW4sOI
                ph3rEHobc8P0Q4d4d8k2mFl+BGVaXpeVFl/Ec+1Vi1lI8joQYI8vydiwYVM58lmciRf7Gei6j07r
                /A/cMLeTQx4vTw9/+Q8XLfoQJe4DEa6ojzolllgLuBB2KQbYuqGrYLXRpRhQqnDF4B/60JKtd0fg
                +5r3B4ZJ9EpvUXAWHTcukcx9zOVmv4lG6cegP3R3Hqn3mc1qaJor7L6xS1Nv0rsXadocMfJn6iuP
                mkbPBEIK00ZDYXWkMKK97ghjyfQHBFb5/Fm9PeRXiJQ5O9SyZQwhSv8fKhP/cHGw+t37vVWjlidO
                qnsKUAr4u05XwWbeal0ddDS2TTHAD3c1TDi6Cn50Q3R1kI1/QID5/O4WD700zKJ3Afec0Ipcrl0+
                /0MDAx/4fjscEc+AgseVtb4GSCRDl1cbmodOE1XQwF2LSwhRnUpqhKknvxcNG8g02hmZ6Mf500Y1
                O8M7vbliNU+DsxedSDVlIpA4F/+gDOh9w8SFId6RrjvRkvv0WFZwDw/RKz1SofNnuiXFNsUAzgyr
                MHidhR6os4NsDgSCM+vLQ5Q8iB2cw3+42ahyO5SF+Ymu9rCSXlpSMGk8clNwE+oP5FME+KUu1YWX
                rsCH4Lg0KC3UFt+gznOK3+8/8qaVf975upPfuek42LIlAu/sP0M+JFxiQUaUIFaP7f9UFwkhQdU2
                WGn7IDKqL7Yc+hFF6Yd2/ZmGhzGlh+Az9psZrGD6cIXjmtxGsHnyuWKsuLSJLTX1F1KiDLGJ/fFW
                88GDVPe7Ds/g1VbJZZtiwAjXbvSpBkbAsgqoZKDbdNfiA92Kdg+j7Jy95WXDWjLY+bhet3edvisr
                mua+XlJQcQu09rv19RS6dYtCXGfw8ExRpWy+a2ERfhNOJfHhEcfCWQvoZUdHMF+nJDpn3BzdK0sp
                UVTtKCgLJ+NZhX/E2xNdpkjFoCd8zKrjqa4jnqzfaJRNhGL3c31vETOkoHY4wQ/RK6lCkAbAooLn
                jD1laEHFMQpjfH9aT2lqaJ47WE+HdGzbdM/fe7vDnkpGyY0Yf2YPGDTm5vQ9pONh2kOzuKpocf7E
                J7HKmhxXa7EbteKtdxocLOtFFrPdSxoOUQ7JGPy+z4790uWQIB7pEMwoPVyh7BRYrU+HbeyETrh/
                m1tZdgCUCPvfU50ESdWvgZrFPyVMuxYvKW7G7+m5ZjkELiU6YNDUky2JAODCF+dP2og/A/QMBFvt
                hzU2z/uvnj7xtrXNYuBxaSvhuBavXLvaFRQXXORtT82764r8+wMCfJ8tNKv+fBIhs6EU7PNDRfcf
                iuCccy2qeTbDRAvDXvylxXkr1+Cl6kuUmIP9v0MM/K8b19d+6qAMMVlzaxAShfH9VEcK7rUn00Up
                4AB3JLjh2yb8393tvh0ubTKeYJPwHYsV9ppUCoCEyYXNn+8KNOaeqTB6LZSCE00mb5TcKiuVgqGF
                E/cnqj6lgA+kN7bnjQ4oVj8lVgOz6jsSxQT00sM+ymF6+6RD++AM/9HBmvoPsTvzLMYbj1KwC5Y7
                uUl615fE/vq0hkDdHYS2Z+AT7pCh2GOj/8pQ1WMa188VWing43ApGs8jYZsivyd2TMtg7PE9r6XX
                t7xbS1fkVZVX5obJ/kSjcMBlsJbJYhYCPPkQfKNuCjV4G6EUvAS6oigFfIiWHrnu0qiBdxz75svm
                edvMwr8zHVsfNLC5fQmNe1RnIXr6Dieiw1G/qKc26VTXnsYzyqqB5UW67S87geqluJQnsAIcadaK
                p6Gp7qVDCi9aGVG1l8GCJ+oQv1A2L5pFpzSsflb45DSBGn8xFMAK50BVXhs4vewb5/iLw7nDeVc6
                HZo0JaFq/8Fw4rwmSgisYQyLYNEK0xA2n1A0V6wRYfHL33E6C/1SZwddzW2zGHCp8CIyMJh2xUDX
                oFKx8YqH38gMVS+6mUbJcjhyXpTgGMuxBXFxgjT26P7Vumc+i2r0WCgr/9ijQrwviPIht0CZmbR6
                da3wSgHfLgKmPAOjrUr87tOmMe0Pu3+XnyUCiSIQrF5UCqXgLSxw/oc3wxWgJ6BSAKmYMhW+JJ8k
                Ot6e+uP3rVsxQB8D79KepNizzlbFAM4SRgajG7Q9h5jc37gTVGDmonEDtvb6LxSC2RhNX1NGxMi9
                62v8Q0yh1UFkdbC2qbhvv3L80K/DpRYzaZtCi5H3kEjkOERV8GgKPJPELwjL+jUkPc1BSRvyIu+9
                4yB/yTqFEOBboIFq/9t4RtTjBzgaQ8M7TswCjbzWO63sHqulAw6633HwKTPyLo17KLZOSrF34k+J
                Qj+LW7qdDXc0NB/YR+jYcp0Diqf5Tq/ok86FGet2vMMOjaePgTafR8Jbf1HoO327gb49dhk6cEp/
                xRO+GbJzJaFXj42tr1yKLampK5rrXgerpFAIOCQ82sQVycSKiu1vPUTdcrjOW1X+YLe1skIiEAcC
                odmLD9FUNgO/w7PjaO50ky/w4p2aV1n+ltWCDB8+1tMWyua+ArosgoqLHrJ8Xe3XVsmnS5iEhejf
                /39ky2aeltelg1avgwrXlCxbR5bp6JO0TXcpBCFKb4PWNtzi99iRGZ4+c2CunmCWv8Eu4DsO95g2
                LGfiHzR3e9QCD7Oz1UIFft9hQXJbQ/O2uYQs4PddUhV3JLMK+69OKgVrW7My09rpMKluGAGF3Thj
                4QERRbmDqRoSEul67jsxmn9DIZjtnVo23+znYXeDCQd6H0oUpvc93Lp83bYV3dE047qtFgMuMOI1
                sQIih+gSntJxiDFfoKtPkjVuVwgyy86hjMFCwBUCGwuj18Nk9oCVHBF2CquHNhnr9TPBx6SoiC4l
                jsIkUI/w8r9uV7Jq162bY7o1pEuuJl8M3rXoIOKi/wHZDJNJx00OOF4CT/yn4u4gG0oEOhBonvlu
                PqWu6TjKeAoWNx7BgVmISIjZOdPKbN8yK8qbNBFbFli46CiMfNYQmHuUjh66m+rVVHQz2LsDd0Bk
                uhQDrGj5HkxKKga7FIIQFAIoBfYqBLsmh7J7WmoWLs2pHIm9P2sKclFwhZAnYLoJ5y0cCk/cM2E+
                +DVePseYwHEraLyJh9DLkTbyxurva783gaZjJLjDIZIZPQoBHFMKsPO7zNum84HlGGKSsSgI8LDD
                SAa7GVugyJfCsi22eCY4bLoIPkdVuVUj/pUgIcPdkYT7cL2bm3hmWupfwAfjgGLAHRDpb/QgCbOG
                bucMPfSdaNuuEHhKzw4SwhWCnzghw248XRpTXg7W+Md4K8vrd7tuxUfGz1sAYf5vJrYa9lHdyhjM
                cRGhWiHy2hfixi9EHf/XH/92FQ0f+BHc6/g/mPzWUY2sR1raT5s7JxQAAEAASURBVGif/osaGh5p
                29Uw2f/i7PixMGWOcnIcGmHTqG8EoshkkQjERoArsy2z6q+CuQ6HttEBgisEnylUrbRyIRQbsY4W
                BkIVYWGwXDGwfSuhJH/ir+BdrzcOOIDUyHbkq457Po023KUQoP/tAN9phaDTMOh2vJRPzasqe79T
                hSNfD8+f0HubxgZ7GNn2VagtkIx+AnqBC85+u5CpGTzfR47evia2/wQhWj+za5/VRLklKQcQ2JmL
                gPCET79wgL0elg1YUEy304egZ+F8SnH+qg1os/sCqOcuqMUKadTK5rkLYzZMoIHtigFP/6io9Bu9
                MjNNLWkMPtugt58o7Vt8b/RTM7InUYVdDdNRiShydSHHVk3TRudPH/lRF3XykoUIdCiNb+FHebKF
                bGKSplQbmVs5clHMhrJBWiPAj3YPerBtAAdfAOHoWQYxJqIJW2N35LaRJxM9XTYGH13VQ/MrDlMI
                07/6p0qe1ccE2L6VsHJd3Ro4IPIYd30rIpfCtdGkUwx2HhPKfgvT7EUI1emrdz9J151mTuOoy+Uq
                BSmpGJiDZ9xUQhllODCm/VS/uPuY3RAWo3e8qaMU0GGF43MULbNPaxZpSoaEVmbPp1X0+AFHIaY9
                DaXgSKt4mEB3E6J67o6Gtz1oRUh2ovK5GPkFLBh6y3dWKwVcINsVgw4UeHa8X3V8jusPzjDjisHc
                uBo73Ijvt22YtehkjSjX4CCQMXjY6p9++8fQCIwf0CJkrtdXxp35ZLERAXhxH467ZJaNLLtkBb+N
                qi4rBL14FJmS8X1+5EQ4kf0MIhbiyPF2PxX+Gf8GayrJgFJO3DjJo+MEu3YfFfiywE+F4TNbSdzq
                Ww3fPbdW0CEKJRY/nrp3BvHh+OMbIJhT749YmHB/o0c84baa/r5TualeyIL7z8jWiy0LNmcmlrIP
                CKO6FAO8W42AaOsNEfD5+ygeOgEe5dcgZP9gW5kbZ/Y+tJb7c4qDr9Jx45Iu1t/4sMXp+e39H/VS
                Wtuex0vK46RUuA8W5E4vX+KkDPHwHu4d2ydMs0fD8fTXm1jbryD3wF398MLf9bGrv7wd/zccD+WO
                erSPurnSsARXXoZj18twjuURNLsadLSTfwLV9VDAuC8BGyYwGh9Cxktyq8otS/5j4th1v9Mwtg9M
                5N8tKUcUA2jxHyr6U90csv/+5w9cs+b5jd2OxqGK5pp3hyJHxVX4wVwM05UuRxKHROYKwAI4l91v
                dR5wh8aXVGx7tbbOhkOuM6GqPyLVpqnKtB+/ivWJZ4gLt/Q+H9a4c7Ac5D4YmVhcmCnk0aB2NNSB
                GVASGmG9eRnEn+mIoDGTT9LRCs7+oC+LRmdhm+sKCG8q6CaCsQW6XmVOVdkfksFp9pDcCwdHCDlQ
                7/g1hXyot4+R9s4oBr2VJcoOFobAelZINDOccTz6vG5koFb0CVa/O4wS1wzE5J8LpUDUH8xuQ6eb
                IecclxJ9BOeLr9mtQn50CIFA9SJsNdGrHWL/A1s89G/z4mjhHy4I88GnFOWvHNsWotW4d4faJFYR
                FARuKr+uOH9iLbYabk/XrYbmGQuPJ2r0BSQM298m7A2woW8oGr08Z3rpt0RY1XbPYUXc8JnTb5Pa
                tt/6b75o3JOUJd8cUQy4ExC08k8xouP0jAqrhRPQ3nHFgJt+s1rbHoAsl2Bu9aR31jNc09pCY1kN
                OR8iLvdT3ltO2GIaYUkoIQS4YokF2PMJETGn86c5YXq/OaTMo1JUMLGcslV3A6OjzaOqixLsmnQy
                thrOh4LwYLRNmZ3sybP0jB5hiJOgtM6BQqZnAaeHRWJtGQlBtmu908pF+A3pGgtjyglQxnX1wVj/
                VU/qozo7GWruiGLAJcVe3odYaetUDJz3M+COhaEa/1MYwXhDiNvYCTaMf+Leuy83jL1TX7ktN5SN
                w0tqVjx8VSOuv2EQTm89RVRFuYj6SoW5P9rDuBibjXv3NEEmOQu/96nuTDYFC5oZpG+/P6RSQq3O
                GPOw2VBm6d14PsNqovfl1ZmaZd+fi2SS3xXeOALKQfIVKAW/0Cs1nue2bCNwuRwzfxflVZzJ89nr
                BKc1M3d7/6VLF/BtCEdKqHrRzdCiZzvCPC6mTEMI0V/w737st/HoD1kEQ4DNn+8KNXj5HrZOB1wL
                BkKJD9ku77CAsiGSJXkVl8Mx8BF0dmzREktwPDQ/UVTXmctCT6+L1TbZ6rk/AdEiL0Af+KWgsn8L
                P67L86pGvCGofDHF4onbthPlezTUd48z7dSGwLy/x2RgQgN9gpnA8AcSVP3IwGF7Wa3BPtysiL72
                Fx6qA/2ZJ/MQsWyEFaYuGnU9VHBr6SoRBZQy7USgpSHvTqzEHFcKcC//19sWrBFhXnjY4aa88INQ
                Cq4UQZ6eZABux6gu9ZOhBRVnrmyq/aSntslUx52oiRp5BTI77QjbFWwwYJA/UFdGZV6Sb4duI+6f
                IbxW77tXI1HNtoWeXuG6mjBD1xqb5wVgluPOTiV6CCBz4Clo74hi0CeDjYSRpbceeS1uG4Vm/zos
                L3Ub+7S+XnLNmDaL+UnyCSIQqPH/BttRVQmSMaE7LEsaxRbCOMesb7sGcfA+E3M2RVvn47c1Yte1
                JPhbqDD2fkl+xeQVzbXPJ4G8PYoYrF5Uil3SP6NRTo8Nnan8GrkoLsmvGmGbKd3SYTJttF5bPaxU
                /12x4Tk4j9tTHFMMOob3Af7qUgwIY3zf0dfR39Y/jPDDfqC3Ol+W4Edcp1LlxcHTTgo6L46UIB4E
                AjP9RyKk6pl42lrfRrnXO71sifV8eubAj+OORjW+SrXyKO6ehTBemwmz9nNY4PykofnA6XgsacZJ
                OdczWF1/KSxYv8fLJ8M5KbrkHIFMszf22TEjlRY9sOzq9p3B856/K20rDisGfLDsIp2jPRppTnOX
                r3shKZ1OdI519+bfwZb2rMvF5uVMHcFPJpQliRBombF4PyzR+Quwl/Ni0+WtWR6f03IUDZ50FNE0
                P+To67QsCfKvLMpfNaSx2XdhMikH3NcF21r3Q7lBQjbRCl1DNXVs7vSRH4smWSLyFO9zwb4kSg7T
                S4M76+vtk0h7RxUDzaW9iwOV9MqvaFHPaHR6Tm/HRNvj7Owmew0GdDuh7C+I0a0bVBJYJDMTJjqD
                zvRfd68/Vwtrb4P7fs5IsDtXpsEsO3m/649HkmDnSnuCF43wqIxkVwraQcRTbHxx3splDQFyh3Oo
                xs95w6x3+rc0uP8EpYA/S0Urb2WS6IX9po9qEU2whOWJuk41QINpRH3XQD/DXRCn61zhByqBO08/
                qq8YMMXoY9B1a6axb7uuMf2qHw+aCuQdKIDH+IScaWXvSKXAdIxtIci9vDPChHtQi5EimylTnd6r
                3Xffsb0iLhePytjHlkmwiwmlvpK8SefYxc4oH64UqFrGImyKCqYU4P1H2O254cW/7FeVgkoBJgwh
                h7q3EdDtM+6TZ3S+jfRz1GLQLjClb8Fv4FCdwnMHRG5qsHXDX/OEF7ginlngm69T3ljNGdJ4wuOU
                veJStRcHTh/5TawOsl58BFY8/EYm2RrhIbnHiCAt/Bv+nFNVeq/D2eFoViT7CeBxrAiYmC0DHvx1
                Jd6KxhXB2s/Npm0GPX6eS5QRHO3N/s8MeqbRQLIiRWEX5FSO5Ja1lCxlpMy9llE4sOsreNG9pa9H
                4q0dtRhw8RWmvWlgGF6ECtmeDa3gptHbkB/gDgPydtVlCyZ8AWVsUsRD8nBmwS9yK8tnS6WgK6iS
                7xrfvx24pRff7tL9ILBotF8zd8ZFTueRLy6YeDPGd4FFYxSBbDYOd3rlwLxLzF48JDy2db5Xs2kG
                fR0K4s8TJmYiAShT/1SY8n+prBRwuL4bfMDx+KM7oZnGiJF3ZEIz5LjFQOvb/32yZfM2jEJXGKCi
                tUcnfJLQ6A10zsnp82Row5bTYaswYhLiaa5fhTLwWk4k9L4IoWIGIJBdYiDQkR3zMdi0RDErb6Uu
                5exch+O/i/MmjIYttSYGfKlQvZ+LRv5MyNhS6P6qCAPiOVgyPNyng50kgjy7ZIDJ91HvoL7X08uO
                juy6lqp/sRWNdwaWg/rKxsbA9n/q65J4a8cVA55aFOE+fgxFX8KXnXs1dyYOgT4K/AbGavD0UENe
                NX5kfPXTU1HxIOTepK8h18CrOZVly5xesfUkrKwzB4FgtX8m5vlSc6glTgUP34u8t5R+lTgl4xTa
                ExgpbQ9Dodb9ZDTO1dGevyjKy76gMUDqHJUCzNnjSzKwmHkJ2I9yWpYf+SOPBqPX4JyD3/94LeU/
                GVlMwunQfuVSiB8pzItX4gWq9wbRMjPc3qVrn9rg1O0UmOU/QcHJiggjPBMyHIAHcAsAbcLn/8Bv
                4lVPJPxWf9+pjsnnFC7pzDc4038DXn33CoMBZfd4K0fEUmAtF7cj1fFjljMSi8GaaC96ED80zkmx
                gjPrH0d00xQnZejEuxWK8/nYPtWbEr8TmeT52h6F43Kt0ysxwhQnr2ia+4zefom2d9xiwAfgYuxN
                Vf9CQmkNR7mVwTGNPG9q+Qfg/wFMx9eROxZkyK0BPpvpW2ApuBGjv0cgBPy5bbTKaXmGe8f2aaPM
                57QcDvDf37Wd/RZ8HVMUgzX+y7FIEUkp2Ihw2dPzK8u5JTVtStjlOt3AKpy5o6rtjod8Uhx3PuRC
                LGuetwov12X8s65CyThd7S1qzLcHpFJgEbhJQJb7FCClLD9DQySlYK2aET5PhFM122j29cBGOGc8
                O24trPiq9t///IF28OrMI1BdfyK2Dx7ufN2570ha5FJ+4XS4rBPjRxTIbwzw/eKr0LPrDfRLuIsQ
                ikH7KKiiWzOCBnbKkAEVAxJGQRKQCBhEYKdSUA+HOtOiVQxKske3bUQjZyGKxtbY5z0k6PhSlD8h
                D8bAm7qqS5NrAzNa3ZV2j5Vn2sTz8SXwzbCbd1f8IMt/kMnw+FyHfV26ks3qazsjVGipfj5M9ztR
                P4+uewijGFCmvtm1iD1ezcjIYmf12EJWSgQsQoCfW99S438Iq8JbLGJhgCwNQ54zvdPLlxjobEEX
                ZRqI9rGAcNKQhEXxmmE5E/exS+Bv7/+ol6Zo2L9neXbxjMHHryjRE5He+LsY7VKy2qWEeXSSS+/g
                qEKNvBP1sumyvTCKQaa31Q8JN3UpZQ8X4eRsxETTA0VZJRGIjQDPUxDKKH0c99/VsVvb1QLpjqkG
                p65yW9Ondjc6ntAFK8ULuqtPo+uZmlsZa9d4s3aEHwSvo+zi1xMfOGb/NTccPHXQ1JN1P9t7optU
                dZqhd1RwxfrtjvlhCKMYLF26IIyd+pd1TzhjI/mxrbr7yQ4SAYMIMJ/fjXDVOpjILzFIwqJuyuX5
                lSMQPy9G6UjoIn+b7dPBfm3HrLTULDxFnAgEusgbCcLPxfmjve3AviseB+VOLsRz4oSu6nq6hqRP
                +B3bH6a4SyZhFAMukKqQ+bsE0/HXHYkqZ+toL5tKBAwjwHzzPUEP/RPMtOcbJmJBR6zMK71VZU9Y
                QNowSWS+52G8suxE4CSrFzAtvjf6aUx5UgzA6Wc46+XMdFYK+DxoLvVc/DHwnmVG3oWmTb0BgU3j
                vRehgU2ed3BRd9y/Yszjcy/+8oJEoCcEvq95f2DI4/07PIzFUkQpuQ/Js2b3JLsDddBViC2rZAfG
                ZoSlElF1JnHTyYVlZj+ALgKc4Eka1Iy207wOZ9rUCZ8lzXF6pZGt7qbGpqGLLREoTqJCKQafkjkR
                yA2nGX0FiYXK2r2f9XWTrSUCcSPQXPPu0AiLfoQOZXF3sqEhHA1rc6eW3cRDZm1gFzeLofkVP0Hj
                oXF3SIOGCqOWKUqBmfWnIUJmsgAwrldV5RQRImKcxqKo8CIoafQ4A3IgmsSHkyadK0IpBhwG+BnA
                TKu7uChTuOenLBIB0xFomeH/ucJcPF/5waYTT4ggfSWnjVwqmlLAh+Qi9uypJwSfzZ2huY3mR06b
                zZYfowy9UIRtpE0aU08tuLV0ldljTEZ6NKpyh1NuOdNVNI0ZeQfq4hGrsXCKwYrAtkUQOhRL8M71
                +NGN73xNfpcIJIpAoNp/rqYQP+h4E6VlZn9EQ7zdmuURIoFRV+OCN/rJXV1P82vZ2ZFevzAbA1Vz
                TwfNfcymq5NeK+7J0/OnjfpSZ7+UbQ6F/TwDg/tuZbDOsWiEXfIKpxhwT0zcYLo9q2FSPXGot6Jk
                18DkX4lAIgi0Jy6aWX8T1P0FoJOVCC2z+2LT4M+b+mw/Y7/rj99hNm2z6MGren+zaKUSHUapqT4A
                sBZwnJ0OmVWpws7Lqyp7P5XmKpGxHJg38XAsVo8xQIM/b9DV2SKgYgBAqGbIlEKpdqmzcEruqYBA
                ezhiTT2OTWZ3izYeOD4+kxMh55VcM6ZNNNl2kwd6Oinc7bv82IGAxszFJcoy7gLpTEcBpuTy3Kkj
                /uaoDIIxdxk+XdXQVrrpoxdSMejwyGzWO1qYbibx41319pPtJQK7EOCRBy0e8hq+X7brmjB/KXsg
                J/zeJSKcf9ATJgjLG4R6T09t0rUOPlSmKUzNM989nDLtQiex5Iqqt7JckBBJJ5H4kXeHH4mBeWHf
                NDTXcl8mx4uQikG7RyZrz/OtF6C8TQWtlnn+6hVGtk8uBJpnLToiwtQlsOONFk5ySm/LnVp+A/U5
                660cDy7hqGLayy8efknVhjLTsFGoazbMq849wylZFs2IOL2NIdz0Z4V789wFus/wwcKWbyMIUZy7
                qWIMX1FYXYwmXVczKrcTukZGXu0BgdBM/4WKRv+B7b2hPTRzpAqx0Nd6K8vuEjH6oCtAFKaa9vLr
                in6SXzMFm+DM+nLgcKqDWLQhgdV5CEvc5qAMQrLG79XQO0hl1Ng7zwIUhFUMljfVfYx9SiMericf
                XFAxxAKsJMkURIBnMkTkwaNwlpuH4fUSa4hMo4xNyqsa8bBYcvUsDVVcg3tukda15mBDWZWTKCLq
                5Ja8aeWfOymDiLyHFVYczB3h9ctG/7WyufY/+vtZ00NYxYAPF09FI7G5NMLYxdbAJammEgKhGQv3
                CXq89VBArxJvXPyUROXc3GkjhFlFxI+RMKf6xS+yfS3zE2UVqvbzfBqjEqWTQH8/lIKHEuifsl2R
                g8Dg+SmG3nWW4Si0YqC2Ks9i5LpDsvCgv4iQsS7LUJOEkx6BYPWiUqa4PsO9cpxwg2EkxBT15NzK
                Mt1ZQEUYi8boRhHkEFQG3SnfO48DKfF+2/majd+j2OaVfgVdAD58+FgPAg0ndVEV69KWbKK9GKuR
                nfVCKwarv6/9HiFjSA+pu+xTnN97jO5eskPKI8B8PiU4038DnLYWCnRe/W640y+jCjkmb+rI93a7
                mFQfFcrWJZXAdgrLSELY8IOSoMwaefmYM0rKHsmZOmKpOcRSi0pbSzY/NCxX76gwny982TxPKF8N
                oRUDDrBCFSPbCejJpuidINk+tRHgyWBCnrJ3kKT0XoxUOIsSP7uehdkvBleWr07mmWCqVAy6nT+a
                mGKgerIqQLtPt/StrWhS2lp91rJIXupIPGbonaMqmsF3nHVYCa8YLF9f+z6G/7UBCMYMzZ04zEA/
                2SXFEOBZDEPV9RNULQPOPWyEkMNj5A5vZPG5eb7yrULKp0OoKFHW62ieZk2ZYWz4fUyJ4pg/DBxh
                b8nxjdmcZhMW13BxaNhhCHMeGVfjPRt9vnL9vCV7XnL+m/CKAYcIKykjCTQU6qbXOQ+xlMBJBNZX
                v+cN1ix+CSFEdbiT+jkpS9e86XY8UMZ6p5X7kiFHQddj2PPq6uC2IK6oe16V39oRoMo6o0iEZtWX
                4h52aLFD/5dTVT7PqOyp3s/FCLYnDRRjDvYGGOnrkhSKgcsdnothhfUNDbvIcAQZVjhe956PXj6y
                vZgIBGfUn+4m6n+Qne1sMSWka7AK/EVeVbkRPxoxh9Qu1QKuFDQJLKBjomG+DSsGWCCd45TgUF7v
                TZY8GnZjdFDu5EJG2XgDfLdrbVnPGehneZekUAyWr3shBCReNoBGLy2a4ZjpzYC8sosJCARnf9A3
                WO1/kijsFZBLODzMBJH2JsHIB2pG2zEpHAv+3d6DllcUYlwxgJOaQ1ld6TpvOCDkC0yEO0p1addA
                Do9eWZAee8HKjXM26e1nR/ukUAw4EAjRmWMIEEqvGjKkIstQX9kp6RAIzFp4ElUjX0Lwi0UVHhaM
                R3IjwZHIGhcQVcZE5cLKeHGiNFKwv9qWGf3QyLiCM/xHo99+Rvom2ocS7SHqG6fbYpso32ToP9w7
                Fo6g7DIjsmqEGnunGWGms0/SKAYrm+civIzAeUx38WZs1ybp7iU7JBUCq3z+LFgJ7qGaUg+z5xAR
                hYdcLcjadUZu1YhrUv9BS+Vpe51uQqz469esed5Qjgd4HfJQOAcK3awo6uMOME4Klm1Kb57QaIBe
                YXEvfNIYeOYjvf3sap80igEHBHtc9xsBBtYG7oSIuZAlFREIzPQf2dtDPsHYbsQ/UefZr2jaEd7p
                Za+m4hx0HlNjYPs/cS1lLSKdxxvPd6wQDStLSNntkGKg/WnQ1JOFNHfHg7m1bcbC55Bda4SHRth9
                RvrZ1SepFANPzrbnAYxu5x0oFAcV50863S5QJR97EGA+vztQvagKqyl+rsZP7OGqm4uKh8e03OLg
                ybnTR6bRvnu7A2JaKEHx3hHMpRlSDAJ3LS4Bj+Hx8jGzHQIk/2ImvVSiVZTf61w8d4boHRMsh6sb
                m3cI7XCcVIrB0qULsM9FH9E7Ebw9PHr5alKWFEGAPyyDHvIeJXQmhpQh6LC+UQg9EYcgVdNx49Iu
                fA++FEYchgWdygTFouTfK9fVrTFCRXGrJxvpZ0KfTd5BffkWrixdIIBnj6F3ChxQHySkXXHugqoY
                l5JKMeCQRdvIH/Fnq174+IlXJfkTfqa3n2wvFgLtVoKZ9VdTF/sc2rp45xz8ABed7w6TI3OqynCU
                c3qWHRk7+Etle3qOvtOoNUNRVe1EcPbEsZ2o2fSVvk4vOzpiE7OkYlNcMKEUAh9tQOjvPdqOpwz0
                s7VL0ikG/PwEmGKeNoISo4rPSD/ZRwwEArP8J4Q8ZAml7GHYgLLFkKqzFO0Jiy7JrSw9b6Cv/PvO
                ten0fe3aBTvwWzVkPk8xnBh1aQuMjgn5WBxRDDSqyW2E7iaNue7orqrn6/TxpcEFuhe2PdM0vzbp
                FAMOQQalD+CPftMsI6cW5V10vPkwSopWIhCc/XYhIg6epRrh6bGPsJJXgrQXajR6GBIWPSWTwexE
                0u1qf4Dq/60mOBGCdX9uxfp5XxmRiefkQKa2g4z0TbBPlLkjbyVIIyW7D82fhNTHjFsM9JawS1Ww
                qBG/JKVi8HVT7WpA+2cj8FKq3mWkn+xjPwLMN98DheBGomYsA/cL7JcgXo50M2IhLsUxySfnV45a
                GW+vdGi3bN3Ty+BRL9whMTZiH3ZTeqthftEozNXUief0MuTZEOrEP8MYmtwRk2HoHYKERi8sCz2t
                23neZPHjIufEDReXYLEaaZTeG6tN1/V0RHFBRVnXdfKqKAi0zKw/OeTxfgF57sE/JBERtdBXqKYe
                6q0sf1JaCbqeI1Wl3Oyani8ZSh/tWMh0DU6Mq1RhjmwjQCwjOWNijCb5q4cWVIzBKAz5NqmUCB2i
                uPvsJK1isLKp9hNEGnDTsu4Cb2lDGp9uRrKDbgQ2zlh4QGim/yWNsrfR+WDdBOzqwEiIMDIevgRn
                plcYon6AVwdrm2BRSZqHov4Rdttjk9ulVXdbG0+FRo6Jp5nZbaDk8uyhsnRCQGHszk6X4v369srm
                2qRRtpJWMWifDYXVxDsru7eDQnFCcd6kU3a/Jj87iwDPXBio9k+PKspXMD2f46w0sbizF6LUdShO
                RHxRWgliYbWz3hV1cQtfeiU8oqzm6+/qWuJDqOtWTCGHd11j7VWmaVIx6ARxUV4FTzJ1VKfL8X2l
                1NC7Kj7i5rdKasWgsanuTUDyD0OwUGP7RIZ4yU49IsBPQezjoUsRfsgtOb16bOxs5Xc8pbG3asT5
                g6tOCjorSnJxx97qFjhsTUsuqROSdmWre0fijmaM7JuQFAY7K8wlFYM9seNrAIPWAraooam2fk9y
                Yn9LasWAQ4t0x0Yde44tzq84XezpSW3p2pMUVde/vvMURDZU3NFSxOKz29WM8EHpktLYirloaK57
                CnT5v1QvW7F1cgYP10xkoJt8bw1CfycU5UjO9NJvE5E91foWF0waizEdZmRcjLmMvqOMsDOlj9sU
                Kg4S4Ycr4QW/2Fj4SLsG+BrER7i1LHYhwB94bRmZN0MDvw7Qe+zia4APdjVYLXNFpntvOWWdgf6y
                y54IsMzc7VeGW7IP4tt5e1alzDc8S+j5WCEuTXRErRnufR1auUERluVHBMa68IYwlreAkrcam8U9
                LOnHMe75yaH7bk8hEv2mKIatBkcW5Vf8JlH+sn98CPCY7GBN/a1hT9YqZKK8RXClwI+X1//hJMTJ
                UimIb37jacXTmmtM4z4ka+Jpn3RtKKtsaK591Qy5KVUc2UaA7FIx2G0CSwqyJ+KrIUdoJIlKOmsB
                H3pKKAbL19fy6IR3+ID0FqwIZ++771gnzHV6RU3a9t/e/1GvYPWi60k0shKHVtwJhaCfuIOhy9uP
                Rq4sG5k3rfxzceVMXskam+cFsId9BkaQaiGMzzY01d1t1sxAeZaKgVlgGqRzUO7kvlggVBvrTv+2
                cv28Jcb6OtsrJRQDDqFC2XSDUO7fK9z7RoN9ZbceEGCPL8lAgqLLslrbVsC8eh/2XXN7aO5wFd3A
                GL0mN6fPT7gfgYw2sHY6lgee/gJ4XwguKbKNR/8V7UUvNXU8mjOKAZyApcWg4/ZXXdEqfCzo+Krn
                D1OZdpueDiK1TRnFYHlT3ccAlvsL6C6MsqnF+1zglHauW17RO7D5813IRXBhqGXr15CVH3q1j8Ay
                R6C03J9BXcV508oekYfG2DdTjYHal7Eq5g7AiFhI6vIKUt2evHp1baupo6C00FR6cRJjhCbkNBkn
                G+GbDcufPBTPBvhBGSovrQrUJW1kR8ooBu1TpzGuoRlZgWSTqHuWoemXnX5AgGEJGKqpPyvU4P0C
                XnvzMBX4YYlb8AD8C+Q81FtVdsOAyhM3iitp6kq2omnu68j4+3OMsDFJR1nT0HzgWTvDMc0dAVbu
                /c2lGB81PEDT+vCvXSgxovLcG5m7vuv4q1FFu11He+GappRi0BCs+zdW/381iPL5iG7gDyhZdCLA
                FYLmmYtGQyn4GJ/5iWzDdZKwu/kSKAUn5VWVnZNXWd5gN3PJb08EGpqe+Z/bzX6Gq/49a4T+1kYJ
                vaCheS5MzT5ETZtfoLT2Np9qbIoK0b6L3Sq1WxQVTCyHgnSWwVE+b/TQLIP8TO+WUooBRwc/Vm41
                UA0gBQWdPdROwkDndOzyg0JQvbheofQtYHC04DisxRG2E3LDi38GpYA7rMoiCAI8Q2D/5szRhNE/
                CCJSt2LghbEePk0nrWiufb7bRmZUaNQRxQBP0TRXDMa6FEYfNDiFEaapxkIbDTK0olvKKQYNTXOX
                QjuYYxCsY4vyJk0w2DdtujGf342ww/GwEHzWrhDgISn44LfhYX5rJLz1oNxp5c9SnzUrPMExEF68
                T8mcSEOg9ir8fnkI8SoBBcZtRJ7xqOpRHT5N1opImSOKASwVaa0YlOT1ugQTbSwVNSUPNwafTXor
                JFbJqVcO3mdiTjRK4QlPBhoY3bpsog37snleqoVSGYBizy7rfK9mezL6XIQHxw2oOXDPWhG/0c2M
                ab9nRHsof9qoZhEllDJ1jcDw4WM94VD25VyhQwvHo1kgx+vIszoVoZb/7Vpi868ioucrUDUUP5+Q
                NDztNyJzEqKRpJ2HDpzSX/HwKCriNTCEAIlESxo2PLfZQF+huiR95sOu0ORmyZL8iXdgH9mIOahw
                O1GmgS4PU5EFCHxf8/7AMIteBS3yGjwgjfxg7MaxCfkpHlCU6OODpp68yW7m6cSPn4ZJosqmgb5y
                Ux3WeCIk4PgwHtRzXZ62m3DfXY/vtucbwT3/CaP05kZnct07c9w4VdPWYgCl4HbcZ4aecXjfTG9M
                AaWAP79S0mLAB1ZGytxr8w/g4SKH8O86SwSrzP+zc3WgUz5bmrfM9u+rqTxch10Gho6YNXUOtJFQ
                dvfWNlp3oK/c3NAxnYKkQ/MNM/0/wRnzb8MvYMXWCBttJeZINFOoutQbcS+ejcfWARbjixBWOEJS
                +iRSG7+Ez9BL7C0Bn78P9RC+8rT9Ga0xtSAdLWxFgycdRTXyL2DuMjDbnyM65SirHFENyJNQF9tv
                uoSk1dm5yFtxKlXYmzq7dTSn/2poHnJ8qkx0vBhwh8INM+t/pinsSjyTzkO/jHj7Otjuc2xvzPIW
                BV+i48YZcTx1UPTkZN08Y+HxiqLAvE4G8BFgtfQXb3FgnA340xJvxRGMar/Gi/tMsD6S8zehIJcC
                fQMawMss7Hlz5cY5jlqaOvD90IRx6SRBw7mVpVnpluCrYyH5CcAydj9Rrayhad5inWAL2zylFQOO
                OrYUXsdDa4yRGYA5+ncrmuseMtI32fo03fP33q5I5vl4xEMhMPjjsH/Q9Rpjs/Kqyt9OtweZ/VD/
                yDEws/40HID1Z1zpbNp/PLey7Ao75+LggoohKmNnIF7w53iYDcb6uhBaSiFk684Mr+Hl34y2/FCs
                dfi8ijLtDdJvQH1DwyNtP47S2U+h6vorGGFORGgs8VaVH+Ps6O3njlD1qXj21RjizMhLDYG5Yw31
                FbRTyisGQ3MnDlNclDsMGVn5blMV9/BV65/6RtD5S1is0OzFhxBVxUNImYQfhsBnGOwx1JcVjczO
                mV7+zz2uyi+WI8CjUXDeRR0Yde2fRInPW1l+h+WCxGDAc9xHSHSw4lYK8eLvoyl0vTviWj84tDJQ
                T+qjMbo7Xh2cWf84tsWm2C4II3/0Tiu/wna+DjIc6q0oURTGt52zDIjR6qb0kK+balcb6Ctsl65/
                3MKKq1+wlaG65cX5kx5FT+yV6y69XSz6R/Q6TXdPgTsw33xPMCP3TKzsrmCqVrZzGxNrJ7FLFBI+
                5yLq3TlVo/4ntqipKV2oxv9bbDU9jNF1v6BgxAdv+k1YdT7oJAodmQixPUCW7y7Hst2/iPyZsiOc
                EA9WCm5OT6dCoRTMwYCNKAXoRu9PNaWAT373P3BemyJlyICKAe5Mxh8QhrxNsUKa0BCoezbZ4Vjl
                82f1ySA8ThxOXIYOBnEAArodZusnFBq9HxEGaxwQIO1Zcr8TmLZvx31ze7xg4AyEh3KKgjfY4HMQ
                r0hJ0679d+qhLbDgZdsttKoohxdMLf2P3Xyd4leUX3Eptoy5YmCkrMvUth+0NLhgq5HOIvdJC8WA
                TwCsBhfjz5MGJyOkuMKHLF/3Qshgf8e7BWYuGgcLwb0QZD/HhYlPgEb+gw176NOFN5YnLe7xDVXc
                VsznU4Ke0ofxoLjKgJSvsTAZn+crT7kHpwEs4u4SqvafCeuY0dTucfPZuyHdnlsc6JcuytwhuRcO
                jrhc3Po4YG8s4rjCyIXwLXgujpZJ1yTlMh92NwPIaf406uq7q49xPVdTPY6aRmPI12N1cEb96VAK
                XkQj0ZUChInR+ZSxUUhbPCy3asTdUinocWotreRbTiHPSc8aVAq4bL9CyN37POzVUkFTjDgibM5x
                Zkjs3+miFHB8w26FbzEbUwooeStVlQKOTdooBhgr0zTKnXmMxrdfMLSgwlB0AwfaqdLuXKgwrtWK
                bB1qQCz8zWpGeF+cdPib3GkjFsq0xU7dMTv58iiVkMf7N9w24xOU5EjkwvhXsGbRUQnSSYvuXBlD
                VAU/itqJkjb+BSV5FWdTRpETw1DZplL35YZ6JkmndFIMyMpgLU91eafRucFK9slhheNzjfZ3oh9T
                VZ5Stq8TvGPw3GkdoNpIWAcO8k4ru6fgptGBGH1ktQ0IbPK9NUiJeN4Bq1PNYccQQkj/GZy56M4V
                D79h5Bhbc8RIAipBT+4oiOnMccuU/D0JIEpYxCHeigKcwvu4cUJ0eipHqnFc0kox4APet/mbe2A8
                +IJ/1luw5B6sqZlG/RT0sku4PXt8CUI0jeVwSJh59wT2tA5UjlwkrQPdg2V3TWjGwn3Cnsz3cK8f
                ZzJvNxIS3Tpga69PQ9WL+BHLsnSBAB7I53Zx2YZLdLO3LbjIBkZOs6BuF6mFEEYXeB8j8R2PzEnp
                IrJ52TLghw6ecLSiKf8EAyOpLxFezC5fEahLQOO0bGh7EEYsdDmEFeHHDusA+Qul2pyctvfrpSKw
                xzQJ8yU4w380USgSF7H9rRWKaViTPBgJb7m10Hf6dmt5JQ91bN/kuSKe1ZC4c+IoGwZB5/NtPBsY
                OcoCiYx+h/v7AYNCRDRCj1rZXJvyURtpZzHgN8TK9fOWYMfdsDMhDlW5/6DCyQcZvLls64bJdThP
                Bf0YJuTrd/oOlJ+XK60Dts29HkYd4YhXQCn40HqlgEtGcWuy6zM8ff8TqPafyyMf9Mibqm3dYc81
                GJsDSgGfEvJyquK6a1xD8ysOw303a9d3vX8RKTI7HZQCjktaWgz4wAsLp2Rnq21c8xvKv+sujHzW
                P5D5c36GvO6+NnVomrX4MJem8YxethXcUP/RCHsRuexfzK8ctdI2xpKRIQR2psL2cOvXBYYImNGJ
                ka8QNVOTE2YvUF951AySyUYjOPuDvkSNrIHcxrzkExtwxKVEval8EumQIRVZ7h3tyZt+YhCqr0nf
                fkeKlDbb4Dji6pa2mvq6dXO2KztPDYwLqL0aUfJ/3+e1zdjrukAXsrUIzwdvR2mAQjADGcR+kltV
                fnhe1YhqqRTYAXtiPBAvfzBM1/8CFeeUAj4ESg5Bxr26kIcsR9bEy9LSQTEa4RFTTigFfAYWp7JS
                wAeYsUO7G3+MKgWIaGOXpotSwPFKW4sBHzwvRXmTnkGWtor2L/r/0+DdOqqxqc6vv6s9PfCgfRGc
                rNg7XAu6L8KH4cXcqeWfYcUHS5ssyYJAoMb/G8wYd6TtI6DMbyFS5Zfp4ouyM1+El1vX9nFiLiih
                V+ZWlT3mBG87eBYVTDwNoYlvGOWFvBJ/bGyae4XR/snYL20tBrsmSw1TfoYCN+EZKQrVaN3wfS8e
                ZKSzHX1wU08HH7PMs9/g7f8oU8iJeHAfgHz4N3krR3wqlQI7ZtIcHu0voepFD0Mp4AqjeEoBJW8q
                4R2/SRelgM9qMNN7E/44ohSA71Ya3s7znKRkKcqfkAel4JkEBteYpW7n85NWJe0tBny2SwZPOgl+
                0nzVb0hRgtXgL7AaOJStLPb9isNvbmGMGHG6UUH9AzgQvo6zCl4fVDmS7wVLy0BsyIVssWHWO/ur
                mns+hBMyXBA31u+9YfK7dPIz2Dhj4QFRhafltf9chJ03KXvMWzXiSiFv2MSFoiX5E19jxkO2o5Ro
                J6xonse329KqSMWgY7pxlkI1PlYanX28MG9e0VSLHAlilo6zEmohXSyv5yCiLt4kmvZ6RoS+PdBX
                /r2YI5JS6UGgeeai0bhHn8MPPkdPP3vaMo0x5Xd508oesYefOFyw1cfPRDjTKYkUog5P1dNKi/Mm
                3YbN8juMYgtLw20rArV3Ge2fzP2kYtAxe0eRKRmb89s+xKrlGIMTqjKinNLY/Mwig/0t7xa8a9FB
                VKETsL3AH0TD8Q/DpUH8XY2E0X+Hr8XrOcWhJemUL91y0B1mwObPd4VWeG/FA/I2iCLi730rTi89
                zzttxOsOQ2U7+8DM+tNggDO8922CwH5sB44wgY5wJDr8Cl6DYIaswHgWfrCiaXsZIQu41TTtiogP
                CscmYai3ogSe9f+GAL0NChFkLuWoxnXPfGuwv23deNrbfiRzczqZbW0DVxBG6+7157rD3ErAThFE
                pM5irNUU9qv8qSMMZSLtTCyZvq/zvZqd4enDQ4mLnJJbo+zc/MoRSGiVWmVY/uShGlGXYFQDDY5s
                k6q4j0j1tMc9YWNIm+qJYDLXdZylcG0CY/BSVXupuPhq4fPB9/edukEqBQnMtOBdW2bWn5wRJv8W
                WClYQpjr2HRUCvit4/H0fhR/HFMKwPvbvKLQy1yWVCr77ju2F5QCruwYVQq4We2KdFYK+P0gFYNO
                vwocz/wU7oxEtOhj6ZbNKZ9LuxNs8qsgCMDBsH9wpv8JrAbfhkj7CiLWHmJwJ8Pv++w4wTvtpPV7
                VKTJFxwmdT4c4i5ycriM0XtSccswK5I9B7gemQC2z61onvtCAv1ToqtUDLqYxky3mycb+a6Lqrgu
                4cE3BTm5J8fVWDaSCJiEQKB60RhEHSyFYnuJSSTNJrMF6Zd/k1dV/tuSa8a0mU08Geg137WwCIdJ
                /dFZWelKb24fh2UwHwH4FfwWVC80ShnP7dUkEk3VCA1dsEgfg27gKsq/aARCVd5FtVGMWhHvf0Lj
                +rmfdsNCXpYImIIA9xdpy8x6AId7TTSFoDVEvmCqMjbv1tIV1pAXn2pHIqOPIOlRjkpL6fneyrKU
                WhUjUd0v4DDoB64ZBrFVEdJd2hiYi/NCZJEWg27uAR5dAI2AhzAaLVlUI38ZVjje6PGeRvnKfmmE
                ANIan4ljkpcKrRQwOqc1K/O4tFYKYLsPeXKfxK3prFJA6Ge5U0t5cquUKUO8FQVYvi3AgIwqBXz1
                55NKwY+3hNHV8I8UUvqTTynOX/UmhmjYqxta6Pu0X7+T0ynPdkrfEoIMjkccwLmQx/2fJ4hIXYmx
                DU/cy7yV5c91VZlO14I1i+5HojCeZdXRojB6Ss60snccFcJE5tzZEH4F9SB5bAJkX4FvGQ/hxm6C
                LBwBaTHo8T7waW43Ox/3yzc9NuuhEuatE9mWzc+giVTCesBJVsWHAD8imSerglKAbHlCKwWf44Y/
                WioFhMCqM1UEpQD3y7uppBRgka/0imRzpTMRpWCFFs7kW3BSKQAIu4pUDHYh0c3fr7+rayEu19mo
                bu2mSczLeECOhzOi0CcxxhyEbOA4As0z380P1ix+CRkM/wRhvI4L1LUAbbjfK3Nz+h6Lkza/7rpJ
                +lwNVPsvxhunRoARtyHLYSKh2AIMYU8RYM29D9ietedVXd+2MaKdvXLjnE26eqVBY7mKjXOSSwoq
                KrBa4yv/RMol7eGQiVCQfdMOAW4lCM2qPx+rToTBskHCAsDoe4RGL/VWjVourIw2Csb9P/Diegks
                XTay7ZJVu7JWVW7kvJQu6Tl9sSi/4mrk6EgoLBxHfZ/X2FzHlWxZOiEgFYNOgPT0tahg0mM4Qujy
                ntrEqIsi//YY5N9OmT2+GOOV1Qki0Dxr0RGKRh8EmbIESVnYnW6GwnIzTtx8Ip1ORewJ0GD1olLs
                Hr6FNlk9tbOnjn6cWxw4PlXyFsD6ejruN56cKRGL9wNYpF1vD/7Jx0UqBjrmbPjwsZ62UPZidPm5
                jm6dm27WCD1hZXPtfzpXyO8SgV0IrK9+z+tm6p2EMuTUoIk8AHeRtOgvfYVq6pW500d+ZxGDpCMb
                mOk/Ets9eE6wfgIIz7cQ/i9VDkoqGjzpKER78Wew0bT16EoX79u8elQ9qY8KMD9CiiAVA53TMixn
                4j6am36Gbnk6u+7e/FuX6vr5stDT63a/KD9LBNjjSzKCoS1XwmnVBzQGiIsIDTCmXY1DeBbgJQiL
                uSwcAZ7ASHEpH+JjvgiI4AFfCV+PlNhCGFo4cX9FpfwI5IIEsP1OZRlHrQo82ZwAjZTvKvBKREzs
                l7fUfUeoNg7SJaJt7qe61deGe8f2EXOUUionEAjU+E8NtWz5EkoB3zoQVimAfLWZJHpo3rQR86VS
                8OOdwk8vhVKwEFeEUAqwMv44pzh4z48SJu+noQOn9IdS8AZGkIhSEAYm50qlIPZ9IC0GsTHqskVx
                waSrEODCD0IxXLDMepf27fcrmePAMIQp0TFY/e4wQl2Icye/FHlAeFisho/MlNQKeTMH8ZYZ/p+r
                CnkNGOWYQzFhKkGXEj160NST1yRMyWEC7bkKwtlvIeD7pARFkc7fcQIoFYM4geqqWXH+pPtxPdGk
                Ja/s2/zNOXK/qyuEU/saP/BIZe5boRDwMDK3uKNlcIshD6nuyK0FN43eJq6czkgWnFF/OlEY927v
                5YwEe3GFNZON8laNWLxXTZJdaPfraun9CmFsdGKi0+qG5tppidFIn95SMUhorn1KSf6ql7DyTySW
                lmc+enFF84EXIGGHlpA4snNSIMDmz3eFGr0XQSHgKbdFzUfQjiXu7f8qmnYxnAs/TgpwbRYyWF1/
                KV7Cj4Gt4yGJu4aOrZ6rcyvLE7Jm7qLl5N8yUuZem38AT3V8ZiJy4B5+obF5Lp6v+MXJEhcC0scg
                Lpi6a+TTdmRs5zdcQg9N3K3nFeevfAJ0pKLWHdQpcJ35fEpzzaJzQg15X+IRxedbYKWAhnEK4G3e
                cPAoqRR0ffPheGsf3jX8mF+BlAL6dCooBTyr4dr8/ecC28SUAp6Svm+/i0BHKgUAId4iX0TxItVD
                u6L8CXmUKP9EkwN7aBazCnfuw9BsUyo7WcxBp0GD9gRFNfXcf+BO/Pup2ENmGhwK61yq5hs4feQ3
                YsvqjHTtFp+GXFgJKKwF4hRGyT839d5RlgJHWlNs03KFK7HjwylZnul2H7d07VMbxJml5JBEKgYm
                zdOwwoqDNZV9BHIDEyRZg8QbVQnSkN0FQIArBC2z6kfiIC2eDvtnAojUswiM/E1xsWk5U0cs7blh
                +tau872anZHZ50WsP5FkR6BCyTJNU0vzp41K+jA8ZDV8EFkNE10gBTFHxzUE5jYKNEtJI4pUDEyc
                quKCijI4yfwdJD2JkIXlYDosBzMToSH7OotAoLr+RDzc7oIUpc5KEgd3pDJWKJmaU1X2jzhap22T
                wF2LSxSX9mf8Pg8TCwS6EkmmTkqFJFMl+ZNmAN9pCeLbiufwiIZAnbyfDQIpFQODwHXXrTivYgKy
                1dV1Vx/vdbxUfreiue6heNvLdmIgEKqpPwYPpbvwcEvQi9qW8XwBo0alt6r0LZmPoGe8Ma9nwfJT
                i63qfj23tL322yjC+AZXlq+2nbPJDJHqeCrwrUmQLMPzd1xDUx0/o0IWgwhIxcAgcD11K86bdBvc
                CO/oqU08dXgQ3dgYmHtfPG1lG2cRCM1YeCxTXFjpsDOclSQe7nQl7s/puW31f5JnG/SM105/Ai/P
                HHhjzy0dqV3PVKU079bSFY5wN5FpSV7FrYwy7oOTUMEz8yY8M+9NiIjsLL3grboHTNong38TvaOh
                qdZnlZySrnEEuA9BcFb9aCQEvgVUyoxTsq1nM7IX35nTFnqS+sYhC5wsPSHAj7lWqIvnJxBxOyiI
                MxDKUuEMBFgKoHgx/htKtEj/rEQR7OgvLQYmAdkFGXM8a0EYccn3rmiae1MXPOQlBxBgPr87lMHG
                YWJuBvsjHBBBJ0u6GefOz9YyIg/JBEXxQReY5T8Bh/XMR+vB8fWwsRUlK0iUne69dcQyG7lawYrC
                uvoIlqdXJUocW6+PYOv1mkTpyP47EZCKgaV3gk8pyl/1LEAenzAbSh5raJrLf0DYvpbFCQS4R7on
                s89kzMANmIQhTsigk2cb2j+SSdRZ/apGtejsm5bNd4aW+q+DOj4bAIiYjfLdDOoeN6DyxI3JPUFj
                XUV52U9i0VOR+DjY0w3NdTy0UT4bEweznYJUDEwCsjsyO7N3DYEjDPt1d23ivk5JXUPT9smELFDj
                7iMbJoxAcPbbhSSaMQWErsLqJjdhgtYT2EYJfYpq9N6c6aXfWs8uNTi0n1nBXE9hjk8QcUR46z3q
                DZPrqK88kQPcHB/aUWRKxqb8tmchCD+MLqGCF5jMGpsQgl13lopB17iYerW4+OpMsmXzKyB6SsKE
                GXmpfyDz/E/JnEjCtCSBbhFoXznOqi+F/8BVeCCfhYbCZLfrVmhC18GH4GE3cc9J/hVl96M0u4Y7
                GLY0em+E45oPtLPMpm8CPf5b50dcP24CLUdJdDwLecTAr0wQRJ4zYwKIXZGQikFXqFhwrbBwSnav
                aBvCwsiJiZLHftobkV7KOatX17YmSkv23xOBFt8b/VhGrwmM0ith5Tl0z1phv30BC8F9OeEAogyk
                U6GeWWqetegIRaNPoc9RevrZ15ZuQPjdOd7K8nr7eFrD6fD8Cb13EOVvULRHJsoBNOTJtImC2EN/
                qRj0AI7ZVQflTu6rudSFuKmPSZg2I++FsyJnrlnzfJLvNSaMhCkE1tf4h7gZgzMhnQCCfUwhajkR
                +gal6n3IVOiXeQj0gc188z0tHu+t+C1yb/gMfb3tak3/p6nqGfm3jmy0i6NVfIYVjs/VVA+3mh6X
                KA8srj7YpmSOXrduzvZEacn+XSMgFYOucbHs6v77nz8wsy2jHg+kw01g8rWLaGOWNc9bZQKttCSx
                vvo9bwZVpyHy8ApYCBLKWGkTgG1wsZqnUPWBVAhVswmzPdi0zPD/XFO4lUBkixB9QwlvH5/jG7N5
                D+GT8MtQb0WJorA3IXqRCeJ/SiLREQ0bnkt6XEzAwjISUjGwDNruCbdrz5rnbTzgf9p9q7hrAgpl
                py9vqkvohMe4uaVQw8Dd/gIaJZ9gSPsKPyxGQgiP/IPGon9IhXz4TuDdfs6Bpw9SjTOEtVHFCRni
                4knJfblti29OheRTQ70TT1AU+jLGnRPX2Htu9HE4M3KqtJL2DJIZtVIxMANFAzSGDKgY4M5s16J/
                bqB75y47KKMXrgjU/qVzhfzeNQIrHn4js//WXn78ABI2bXbNwayrdDleZPe3ZmXW7Xf98TvMoppu
                dEI1C0cw5noCWA4VeOxbcD9enVtVPldgGeMWDecejIdl9Bl0yIy7U7cN6WKXqpy+LPT0lm6byArT
                EJCKgWlQ6ic03Du2T5uSzffdyvX33quHhhz9N+HgkPv3qpEX9kIgUOOfhoiDGXtViHEB+Qfon+E/
                8FRO2/v1qbBydArWDbPe6a+q7nsRgsjj3MUtlLzpotHLB009eY24QsYvWXH+RJwQS/nvK/F3DKV/
                b3VvO2vt2gVSMY5/ChJqmfikJcRedh4ypCIrYwc/sY2OMQUNRn7fENh+rcx10DOawWr/v9HiyJ5b
                2V1LP6NUe8pNMl6Q4YaJYx+cUX86UdhjoLRP4tSsoYAVdYtC6HW5VWXzrOFgL9WdeVsO4Jiboojh
                BfVXT+7285YuXSBTeNs4lVIxsBHs7lgNHz7W09aS/Tx8Ds7pro3O669lE+28L5vnbdPZLy2ab5yx
                8ICooqwWZLAbEX76rMbo03nTyj8XRKakFgNnHByOMw545sJTBR/In9SM8DVIUx0QXM64xCsedEE/
                kuFegMaJ52vZyfG5fZu/qagn9Umd0Cku8ARrJBUDYSZkrKu4oNczhLWHyyUuFSX/Vqn7rFXrn/om
                cWKpRSFY4y+DEuZ3cFTIpUPehZH1qW1t5G8H+splPgoTJgPbBvurmoubry8Q2rmQkO/g63Clt2oE
                30ZMiYIzD4pwP/8VgznMjAHhxTRnRfOBiBTyaWbQkzT0ISAVA314Wd2aFhVM+gP2vi83iVELnBLH
                wynxHZPopQSZULX/YLyYv3JgMN/g4fmMW9VqB04fKRU2kyZgk++tQeHMzCooe78FSRMc3UwSbG8y
                uO3Yky5FvQm+BJv2rk7OKyUFk34JTfdZSD/ApBE80NA893qTaEkyBhCQioEB0Kzugh/aPfihmXX+
                OzRudisOGamB3HgwybLR5x8Q9RC7EkOtx1bBSxpRFnjD9R9KR0Lz7r9VPn9WXw+7Bv45laBq1kvJ
                PAH3pNQIa+Cl3mll/j0vJ/U3WlwwyYenyq0YhSnvEkbZXY1NdbclNSopILwpk5kCOAg3BJxR/ju8
                x++DYGbFW7+MxCCTZGIQoIpsRsEavKStC1VsggaGfPB0vlQGzP9pMZ9PCXrKJkHhugPU9zOfg6kU
                25DS+OHWzKzbUyncdGeiNvcOwRvZAAAV20lEQVSzpjlNE6LCuvlbWDf/aCr6kpghBKRiYAg2ezoV
                5U08C6lunwO3XmZwxAtxGVVcZzc0PfM/M+glM43ArIUnUU1ZbOIYuDLwZ6Jo871DWz6k48apJtKW
                pDoQ4JEGTGHVeHD9RHBQVPx25yo0ckeqhCDuwntY3uQjNKrynClm5YTYCkvBOFgK3tzFQ/51FgGp
                GDiLf0zuwwomHguP9VfRMC9m4/gabEUGvckNTbXcezitS2Cm/y/Iu85PTjRWKFlBGXuLKwS5xaEP
                pDJgDMZYvfjph6HGvHEwWU+FvefwWO0drsftQBcQVbvNe+uIZQ7LYjp7OBlegE2DJ0DYlMUK6KzD
                8eC/XBGslRE5ps+WcYJSMTCOnW09D8qfcKBKlDfA8GCzmOKFeO+Kpu140C5I25Utz344YEuvR/Gg
                izfmegce+jiwiL2pRrU3U+FwG7PuJyvoMJ/fHfLQi6AM3AL6ZuTZt0LM3WjSN2CVm5aKYadHkSkZ
                m/Nb78PWwdW7DTihj3j5fMnc0V82fPfc2oQIyc6mIyAVA9MhtYYg39PztGVw812ZeRzYRy7CLkzn
                Q5i4v0GoZjFXDODR3tVqlC5vVwQ09ma4V9Z7qbRPbN59ZC6ldh+Qav9YqiBzHiMl5lK3hNpiTdOq
                8qeP/MgS6g4T5YcguRT2HEwhiZ8K++NY3naprnNliuMfARHpk1QMRJqNGLLsTITU60nTch3s5LcZ
                ERBXNwbm1sVgn/LVzTXvDqXMXQoFYQtcPptcUeWbnOml36b8wAUbYKim/ikoB5MFE6srcZYoVJuW
                Uzny7a4qU+EaUhtDaaYPYiy9zRsPe2Lf5jVXysRF5iFqNiWpGJiNqA30ECJ0B1ZSpob04EZ4UQ1n
                Xr5y45yUia+2YSokC5MRgN/Htdjm4i8iYQucCrll4N7cyjKe0Ccly/B9Lx7UGo08gUiBs00cIIwO
                ZBpyFPDQaVkERkAqBgJPTk+iWeAEBHbsG0VRJixfX/t+T7xlnUTACgQ6Ek/9F7RdVtBPjCZFrn7t
                T0SjD3unly9JjJbYvYvyLxpBicYtiPuYKOk2OD1fJJ2eTUTUQlJSMbAQXKtJl3grjkToFvc7ONBE
                XkiIRGft27z6dmnqMxFVSSomAoKeeNkE59Q/apr6x/xpo5pjDiKJG/CtynBL9kxsLd6AYZj3bqBk
                OdKxnCXDpJPn5jBv8pNnzCklabtTYmvGc/gZn2bywD5mmnpBY/DZBpPpSnISgS4RwImXH6PCTAe3
                LvnEeXEJUpM/lBMJzqe+cSl/st+wwoqDNY3xg9x+Gic+8TaTidXiRUqgdlIxEGgyjIviU4oLVt2O
                H7VpqUk7ZNmK8KSqxuYhv5eHmRifHdkzPgSC1fXwb2H94mttSasIqP4FxyA/lFNV9g9LOAhHdKyr
                KC/7d/DruBOiZZsonkzFbiKYdpOSioHdiFvIryR/4q/wIp8HFgNMZvMPQpVLpCnQZFQluT0QwKmX
                y50JT6QfIyR1XjiDvFh4Y3loD6FS+EtHBsMnMcSjTR5mC+bx/IbA3JSN1jAZL+HIScVAuClJTKAi
                74XFSHvM/Q5MOf50N2nC2K6YlZmzfebSpQtS3rS627jlR5sQwFbCe2B1ok3sVuHQjGcJ1Z71Vo3C
                Hnj6lCFDKrLcOxiParoJ/9ymjpyRz9wKPefrptrVptKVxGxFQCoGtsJtD7PCwinZvdS2JzG54y3g
                +D/GlEsbA8+kZDIXC/CSJONEIFi9CC8rekeczY00+x45QOYzF5vnvaXsQ4Qd8vC5tCrFBROQp0OZ
                gxX9MAsG/ky0F71y9eraVgtoS5I2IiAVAxvBtpsV8h1chQfAveCbZTJvhgfsYy5NmSozl5mMbBqT
                C/j8faiHNsLPwKxzQUCKhKhCXsPfv23ss+PNkmvGtKUjxEMHTumveFrvgeLFs3ya/dzfDqCvxdHu
                fFtClhRAwOwbJAUgSa0hQDkYjnXR81gaHW7ByL6F09IVK5rmvm4BbUkyDRGAn8HleIk/ltDQcbgV
                +r+CbNd/8xYHPkr3w634Ka3IIfB7POwHJ4Rr150/dblcFyxb9/Syrqvl1WREQCoGyThrOmUuLr46
                k2zZPAvdrsU/K+b8FYQ23iBDG3VOjGzeJQKh6vorYJJ6CJUZXTbY+yIOtyIfQUl9hyjKK7m3lH61
                d5P0u3JQ4eSDNDV6PxySx1gweg35Du4dEMic/imZw6M5ZEkhBKx4SaQQPKk1lOK8CaMRXVCLURVY
                MLIw8ts/RKPqjIYNz222gL4kmUYIwN8Ae+F0NoZ8LP51ek7xLITsX7AsLCKU+b/v0/rPdN0i6OqW
                GDKgYoA7k92OuqvwL17lqitSXV9jZC0Sq01sbKrzd91AXk12BDr94JJ9OFL+WAgMKxyfq6mep9Du
                jFhtDdYjOxyb3tA89GmZ+8AggrLbDwgEZ743mFF1jEJZJhSBJkqU9W3hLV8U+k7HvrYseyIw1lWc
                lz0FahTPSZC7Z51J3xh5KZwVmbJmzfMbTaIoyQiIgFQMBJwUO0Qqyau4nFF2H3iZmdTkR9Ep+bdC
                6bXy3IUfIZGfJAJWIdBxvgE/fMrsMOVdIm+F4QYOhrVQ+GVJdQSkYpDqM9zD+CxMg7o71/9v72xj
                4yjOOD4zd76L7UAKtuPgWq3tuA5tiNMUJCpCUSRolaTQ9kPDSyFRCCSoVYHSUBpVlZp+QS1NE5q0
                gJISEqdQJZYqFQQOVHyiRqVpJGpIFRLXNjQkdnwOeXPsO9/O9D+2yavt3PluX+7uv9Lq9mZnZ575
                zd7uczPPPE+zo8I/6Tzy/IfnJ/KYBEggcwIIpjYTIwR25dF3Mi9t3BLoHn1cNPl5gopBfvZryq26
                XqwqOl4ZfwI3gnWnHE35wvQyYl2zeToRTT7FIcj0wDE3CYxFwE4JGh35KQwAH8Z5t363A/D18IuD
                3f3rhWh2xpKDaflJgIpBfvZr2q2yFsxO0tmMfx+3pH1x6hecgLe5DSLpbKCBYurQmJMEPiVgg6ZF
                40WrsfzYrjCa+ml6tj/xYngTSsdDcGsMvxLcCo0AFYNC6/GJ2yu/MH3ZKiPlU8h25cRZMzp7DFev
                KxF6Y1vPjv6MSuLFJFAABGaVr7jCUc5jUNx/jOZOc7HJn2DZ52r4JnnBxTpYdMAJUDEIeAf5IR4e
                QlVOSD+D4f9vu1x/L/6V/DoeOfPMoUPNdi06NxIggfMINFYuLT0j5Q/hadTGNSg775Qbh7scU/RI
                59E/YmURt0ImQMWgkHv/Mm2vn7Hsu3ggbUI2N/wenK0dw6JHsB79ySllA5sZoOksFh4UMIHRQEff
                B4I12Ke7jOJjlP+D9p7tL7tcD4vPEQJUDHKko/wSc9RZirV6fsADGf6HG3JdsdDPc4rBA9qsInAE
                RqYMkivhwng1hKtyWUA4RRTPiURyDW1+XCadY8VTMcixDvNL3LqKZTfDL8Hv8CD5igcyWOcpzyW1
                3NjVu63bg/pYBQn4SqD+s/dWSyf8KKbWVkIQN20IRtsp35HCefRgz453fG04Kw8kASoGgeyWoAq1
                VtVXdi2H7cGTkLDSAynhZlm8hOh469q7t+/zoD5WQQKeEmiYvmKuls7jqPQu7Nl3X3xpaz7GyqA1
                7UebXsQpzOJxI4FLCVAxuJQJUy5DwA53JpXzc1gv/whZI5fJnp3TUuzWCNrS0bP9zewUyFJIwD8C
                Nm6JkepxPIBv80iKQWgB60qF/hWn6TwinsPVUDHI4c7zW3SPvK5d3Mx38T9nXbTiTDMNFS9Gw+9B
                JmCjnJrTJ+6WZth+wC3XxWMh2AXvo0/Q++hYaJg2FgEqBmNRYVpaBDzw0z6WPL2wd2gKqdAWxoIf
                Cw/TgkKgfsb9XxJGW9uBpdjdXnJ4rtmMV3KOBY/SIkDFIC1czDw+gbOR3X6JPBXj58v+GdghvCWF
                3JIsEc1dXdvgfpkbCfhLoKpqVUmpTtxphhUCeZPH0jDCqcfA8606Kgb51qM+t2d2xZKpcVVi/bdb
                hyxXeSzOcdT3J8eYLZ1Hm9o8rpvVkYCor1g2T4TkSkx3fQ84PFhdcAH0GGIbPNWvIn84fHgzw1Jf
                gIZf0iFAxSAdWsybMoG6q1ZNU9HEY7CAfgwXueleeTyZ/gmj6y0hJ7zzg9jWU+NlYjoJZErA3uuh
                osG74UrcThdcn2l5k7j+uDUsDDuhjbzXJ0GPl1xCgIrBJUiYkE0Cs6sfuDo+lLTLsR7BXprNslMs
                axA3eYsWclepcF6hRXaK1JhtQgKjsQu+BTsXu8zwG9jdinA4kRynjDRPO4NqfdfxbXa0jBsJZIUA
                FYOsYGQhlyMAAyzYHZg1GEGwbl6LL5ffpfN2ePVVacTOgciZ1xifwSXKeVqstRsodgbvgDJwJ1YW
                LEYzp/jUVNzHclM4rH+z/+OmPp9kYLV5TICKQR53bhCb9sXy+64ZCoV+BtlWYffGB8LYIE5j+PUV
                KcxOccW03e3tm+JjZ2NqIROwMQuKzojF+GduRwZux17iIw9rWPusgS+C//bsOOqjHKw6zwlQMcjz
                Dg5q80YjOGJ6wTwEGT/js5wnUD+UBPFaKGze4L8wn3vD5+qHR7e0AwdEcjHuCasMXOGzSMcgx7ND
                Wv6eLsJ97okCqZ6KQYF0dFCbObKKofRBITS8KMrPB0BODTn2YN15i5Rm98GemXuEWIs0bvlLAK6+
                p3fcaJRYhCmCRWinjQeiAtDeDoxUbBhQU7ZylUEAeqOARKBiUECdHeymLgnNrCxdgqF9a6joh2X3
                eHhiGNV4A8vPWoQKvd7e/ULveBmZnjsEaqc/WKlUYqE0CoqA+Tokvzo40st3hNSID1L3FyqlwemV
                QpKEikEh9XaOtLV+xvIFMFJcDXG/iT1I9yjMEsReiGTjNbTC+OttTjuARA5sDVX3lGunaD6cYc2H
                M6xbcVfNg9hBurfsqNTLWpvfdvQ2/T0HkFLEPCYQpB9GHmNm0yZDoKFq+bXaGVYQ7sX1fq1kmEh0
                qyjsx94KxzKtjiNaO3q3HZzoAp7zhsCsqhWzHEfPxxTViDIg5Sxvak67ln4jxQ7jyPW8d9Jmxwtc
                IkDFwCWwLDZ7BEacJQ3eK8ywA5kvZ69kV0o6ih9VKyJBDisLyWLxLt00u8L5bKHV1UuKo4mp85Qy
                w0oApgasC2JP3XKfFSb1g39Bq9wCp0R/plOi1KExpzcEqBh4w5m1ZIlA3TVLbwhptRIP1XtQpN/W
                4qm0ykEmO4rQhh/be5C7LSxl2/7ubV2pXMw8FxCQDZUrah2jG2EZOMcI0wgTwUbYf9QjVxCMBS8Q
                dowvJzF58aJ05OaDvdveHeM8k0ggEASoGASiGyhEugRGYzJgbbkdRTA3pnt9APKfhNzvY0lcm9Si
                zSoMUqkDNG4c6ZmZlUunGy0bVEjOhUOqRvCZgzPXYc8FZfCi28u8LaXaghgGu7i64CI0/BpIAlQM
                AtktFCodAnWVy+eEhMYogrwP13kduCkdUVPJ249MXXgRduHH2QljuS4lZKcJy65EON750UcvfZJK
                IUHPY11lDzrJWuWIGljd1aKtNVgeWos+rIHsdvfTkRCqz3jrQwk7BBQCKHv/ybg0FkACHhKgYuAh
                bFblLoH6+oej4tSJhXi53IUb+w7UNtXdGn0pHc6YDBQHeUhK0YdhdLyATAz/qvEpY0bpGJSJPkeH
                YmW9kb69YvOQF1LOnr0konuiZfFQuFxJUQajv3KMhJRpKcvRF2VCmnLIiHRZDaWnBjL5EVjLbRSn
                UMFf0cZd0fL+1/fta064XSHLJwE3CFAxcIMqy/SdgDVIK06UwJXtcJAbu+wx1/+BTpbpSbyIj2H5
                Z1xJGcexfVlZ988JIfFp8Gl3e4w08EIa1lgIY91VR3AuinMRIWUUZSDNIFiQjODBEdEGx0gffvHn
                5BA/Wpj51o/2v6KN3OmUiN00NM0cKEvwnwAVA//7gBK4TKCxcmlpv5C3Y0j+LrwYrWc7v4LfuNxS
                Fu8RgQEoTK8KZXYOhgdeZTAuj6izGs8IUDHwDDUrCgKB88Ll3gl5bsNeqCMJQeiOXJLhNB6Wf2P4
                7lzqMso6WQJUDCZLjtflPAFrkyBPnroF/ujtKILdr835RrEB2SSwD3MqLY4Ru4vLz7xFm4FsomVZ
                QSZAxSDIvUPZPCVw7YzlNY4WC0cVhVtReamnArAyvwlY48E3Md3UYkJmd8fhpo/8Foj1k4AfBKgY
                +EGddQaegLWyH4iVfA0W9oswn7wQAs8OvNAUcDIE3sMqjhapZMu07kirV6s4JiMoryEBrwhQMfCK
                NOvJaQL1M+6vEMa5aTgIj5Q3ozHXY7eW+9xyh0AcUwN7jJGtEJlBsHKn3yipxwSoGHgMnNXlB4Ga
                muVTVL++QYXEfCzvQ7AeYf3zY50+twARQMhsiZgViF2h8Xnl1L3t7ZvsskxuJEACExCgYjABHJ4i
                gTQISESDnIVokFZJ+Cp+WHMxV22nH7jqIQ2IGWSFx0j5Pvwv/Bt+F/7hJE1rR6zpQAbl8VISKFgC
                VAwKtuvZcPcJrFV1FV0zQ9I0GgT7gec/BP5B0B8h6rDztze5DoAHZdEBA9FzMSaEbGs/ur0D6cDL
                jQRIIFMCfDhlSpDXk0CaBEYCQJVeh7fYHPzDtYpCA/Za7J/DDs+C3EAgDtXpQ+hPndLoA2DVBkPQ
                ttNqyvsMRMT7gwTcJUDFwF2+LJ0E0iEgG8qWVSWVqMVLsEYKVWukrsHLsRYvxlr8WKtRWDidAgOc
                NwnZsBzQdA2//G3gKIOgUfgM61DnB7GtR3AeX7mRAAl4TYCKgdfEWR8JTJLAArEg3D2jptoxTiWi
                9pVrBCmCYR0MHmU53qA4NuV4lVoDyJHvI8aQXq2cSECGPjxQYPA3HNwphpALfQoBnmw6DDRjWom+
                sNCxIVnU03nk5CEhmp1JouBlJEACLhKgYuAiXBZNAn4TsC6g41KXqiIdEUMqqkIIhKRUVDj4lE5U
                aBWFQoFgSQrfTVTbY7sZFVc2uJIycaFlQoRM3NhPreMiJBPawXGRjushlSgV/af39Taf9rutrJ8E
                SIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAE
                SIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAE
                SIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAE
                SIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAE
                SIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAESIAE
                SIAESIAESIAESIAESIAESIAESIAESIAESIAESIAE0iPwfxKOnjvVcLCDAAAAAElFTkSuQmCC" transform="matrix(0.3333 0 0 0.3333 0 -3.11)">
                </image>
                </svg>
            """,
            "class": "only-light",
        },
        {
            "name": "GitHub",
            "url": "https://github.com/TissueImageAnalytics/tiatoolbox",
            "html": """
                <svg height="32" aria-hidden="true" viewBox="0 0 16 16" version="1.1" width="32" data-view-component="true" class="octicon octicon-mark-github v-align-middle">
                    <path fill-rule="evenodd" d="M8 0C3.58 0 0 3.58 0 8c0 3.54 2.29 6.53 5.47 7.59.4.07.55-.17.55-.38 0-.19-.01-.82-.01-1.49-2.01.37-2.53-.49-2.69-.94-.09-.23-.48-.94-.82-1.13-.28-.15-.68-.52-.01-.53.63-.01 1.08.58 1.23.82.72 1.21 1.87.87 2.33.66.07-.52.28-.87.51-1.07-1.78-.2-3.64-.89-3.64-3.95 0-.87.31-1.59.82-2.15-.08-.2-.36-1.02.08-2.12 0 0 .67-.21 2.2.82.64-.18 1.32-.27 2-.27.68 0 1.36.09 2 .27 1.53-1.04 2.2-.82 2.2-.82.44 1.1.16 1.92.08 2.12.51.56.82 1.27.82 2.15 0 3.07-1.87 3.75-3.65 3.95.29.25.54.73.54 1.48 0 1.07-.01 1.93-.01 2.2 0 .21.15.46.55.38A8.013 8.013 0 0016 8c0-4.42-3.58-8-8-8z"></path>
                </svg>
            """,
            "class": "only-light",
        },
        {
            "name": "GitHub",
            "url": "https://github.com/TissueImageAnalytics/tiatoolbox",
            "html": """
                <svg height="32" aria-hidden="true" viewBox="0 0 16 16" version="1.1" width="32" data-view-component="true" class="octicon octicon-mark-github v-align-middle">
                    <path fill="#ffffff" fill-rule="evenodd" d="M8 0C3.58 0 0 3.58 0 8c0 3.54 2.29 6.53 5.47 7.59.4.07.55-.17.55-.38 0-.19-.01-.82-.01-1.49-2.01.37-2.53-.49-2.69-.94-.09-.23-.48-.94-.82-1.13-.28-.15-.68-.52-.01-.53.63-.01 1.08.58 1.23.82.72 1.21 1.87.87 2.33.66.07-.52.28-.87.51-1.07-1.78-.2-3.64-.89-3.64-3.95 0-.87.31-1.59.82-2.15-.08-.2-.36-1.02.08-2.12 0 0 .67-.21 2.2.82.64-.18 1.32-.27 2-.27.68 0 1.36.09 2 .27 1.53-1.04 2.2-.82 2.2-.82.44 1.1.16 1.92.08 2.12.51.56.82 1.27.82 2.15 0 3.07-1.87 3.75-3.65 3.95.29.25.54.73.54 1.48 0 1.07-.01 1.93-.01 2.2 0 .21.15.46.55.38A8.013 8.013 0 0016 8c0-4.42-3.58-8-8-8z"></path>
                </svg>
            """,
            "class": "only-dark",
        },
    ],
    "announcement": "Paper available at "
    "<a href='https://doi.org/10.1038/s43856-022-00186-5'>"
    "https://doi.org/10.1038/s43856-022-00186-5</a>",
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = []

# These paths are either relative to html_static_path
# or fully qualified paths (eg. https://...)
# html_css_files = []

# -- Options for HTMLHelp output ---------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = "tiatoolboxdoc"


# -- Options for LaTeX output ------------------------------------------

latex_elements = {}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, documentclass
# [howto, manual, or own class]).
latex_documents = [
    (master_doc, "tiatoolbox.tex", "TIA Toolbox Documentation", "TIA Lab", "manual"),
]


# -- Options for manual page output ------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [(master_doc, "tiatoolbox", "TIA Toolbox Documentation", [author], 1)]


# -- Options for Tex info output ----------------------------------------

latex_engine = "xelatex"

# Grouping the document tree into Tex info files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (
        master_doc,
        "tiatoolbox",
        "TIA Toolbox Documentation",
        author,
        "tiatoolbox",
        "One line description of project.",
        "Miscellaneous",
    ),
]

# -- Options for InterSphinx (Reference Other Docs) --------------------

intersphinx_mapping = {
    "python": ("https://docs.python.org/3", None),
    "numpy": ("https://numpy.org/doc/stable/", None),
    "scipy": ("https://docs.scipy.org/doc/scipy/", None),
    "matplotlib": ("https://matplotlib.org/stable/", None),
    "sklearn": ("https://scikit-learn.org/stable/", None),
    "torch": ("https://pytorch.org/docs/stable/", None),
    "click": ("https://click.palletsprojects.com/", None),
    "h5py": ("https://docs.h5py.org/en/latest/", None),
    "pandas": ("https://pandas.pydata.org/docs/", None),
    "Sphinx": ("https://www.sphinx-doc.org/en/stable/", None),
}

# create latex preamble so that we can build arbitrary nested depth
fh = open("latex_preamble.tex", "r+")
PREAMBLE = fh.read()
fh.close()
latex_elements = {
    # Additional stuff for the LaTeX preamble.
    "preamble": PREAMBLE,
}

# -- Options for autodoc -----------------------------------------------

autodoc_typehints = "description"
autodoc_type_aliases = {
    "Iterable": "Iterable",
    "ArrayLike": "ArrayLike",
}

print("=" * 43)
print("Copy example notebooks into docs/_notebooks")
print("=" * 43)


def all_but_ipynb(dir_path, contents):
    """Helper to copy all .ipynb"""
    result = []
    for c in contents:
        flag = os.path.isfile(os.path.join(dir_path, c)) and (not c.endswith(".ipynb"))
        if flag:
            result += [c]
    return result


DOC_ROOT = os.path.dirname(os.path.realpath(__file__))
PROJ_ROOT = pathlib.Path(DOC_ROOT).parent
shutil.rmtree(os.path.join(PROJ_ROOT, "docs/_notebooks"), ignore_errors=True)
shutil.copytree(
    os.path.join(PROJ_ROOT, "examples"),
    os.path.join(PROJ_ROOT, "docs/_notebooks/jnb"),
    ignore=all_but_ipynb,
)

# shutil.copy(
#     os.path.join(PROJ_ROOT, "docs/notebooks.rst"),
#     os.path.join(PROJ_ROOT, "docs/_notebooks/notebooks.rst"),
# )

# Read in the file
with open("../examples/README.md", "r") as file:
    file_data = file.read()

# Replace the target string
file_data = file_data.replace(".rst", ".html")
file_data = file_data.replace(".ipynb", ".html")
file_data = file_data.replace("../docs/", "../")
file_data = file_data.replace("](./", "](./jnb/")

# Write the file out again
with open("_notebooks/README.md", "w") as file:
    file.write(file_data)
